#!/usr/bin/env node

import { createServer } from 'node:http';
import { resolve, join } from 'node:path';
import { existsSync, statSync, createReadStream } from 'node:fs';
import { createReadableStreamFromReadable, writeReadableStreamToWritable } from '@react-router/node';
import mime from 'mime/lite';
import { WebSocketServer } from 'ws';
import { createRequestHandler } from '/usr/share/headplane/node_modules/react-router/dist/development/index.mjs';
import { access, constants } from 'node:fs/promises';

var define_process_env_default$4 = {};
const log = {
  info: (category, message, ...args) => {
    defaultLog("INFO", category, message, ...args);
  },
  warn: (category, message, ...args) => {
    defaultLog("WARN", category, message, ...args);
  },
  error: (category, message, ...args) => {
    defaultLog("ERRO", category, message, ...args);
  },
  debug: (category, message, ...args) => {
    if (define_process_env_default$4.DEBUG === "true") {
      defaultLog("DEBG", category, message, ...args);
    }
  }
};
function defaultLog(level, category, message, ...args) {
  const date = (/* @__PURE__ */ new Date()).toISOString();
  console.log(`${date} (${level}) [${category}] ${message}`, ...args);
}

var define_process_env_default$3 = {};
const server$1 = new WebSocketServer({ noServer: true });
function initWebsocket() {
  return;
}
function appContext() {
  return {
    ws: server$1,
    wsAuthKey: define_process_env_default$3.LOCAL_AGENT_AUTHKEY
  };
}

var define_process_env_default$2 = {};
async function prodBuild() {
  const buildPath = define_process_env_default$2.BUILD_PATH ?? "./build";
  const server = resolve(join(buildPath, "server"));
  try {
    await access(server, constants.F_OK | constants.R_OK);
    log.info("SRVX", "Using build directory %s", resolve(buildPath));
  } catch (error) {
    log.error("SRVX", "No build found. Please refer to the documentation");
    log.error("SRVX", "https://github.com/tale/headplane/blob/main/docs/integration/Native.md");
    console.error(error);
    process.exit(1);
  }
  const build = await import(resolve(join(server, "index.js")));
  return createRequestHandler(build, "production");
}

var define_process_env_default$1 = {};
const prodHandler = await prodBuild() ;
const buildPath = define_process_env_default$1.BUILD_PATH ?? "./build";
const baseDir = resolve(join(buildPath, "client"));
const listener = async (req, res) => {
  const url = new URL(`http://${req.headers.host}${req.url}`);
  if (!url.pathname.startsWith("/admin")) {
    res.writeHead(404);
    res.end();
    return;
  }
  if (url.pathname === "/admin") {
    res.writeHead(301, {
      Location: `${"/admin"}/`
    });
    res.end();
    return;
  }
  if (url.pathname.startsWith(`${"/admin"}/assets/`)) {
    const filePath = join(baseDir, url.pathname.slice("/admin".length));
    const exists = existsSync(filePath);
    const stats = exists ? statSync(filePath) : null;
    if (exists && stats && stats.isFile()) {
      res.setHeader("Cache-Control", "public, max-age=31536000, immutable");
    }
    const fileStream = createReadStream(filePath);
    const type = mime.getType(filePath);
    res.writeHead(200, {
      "Content-Type": type || "application/octet-stream"
    });
    fileStream.pipe(res);
    return;
  }
  const controller = new AbortController();
  res.on("close", () => controller.abort());
  const headers = new Headers();
  for (const [key, value] of Object.entries(req.headers)) {
    if (!value) continue;
    if (Array.isArray(value)) {
      for (const v of value) {
        headers.append(key, v);
      }
      continue;
    }
    headers.append(key, value);
  }
  const frameworkReq = new Request(url.href, {
    headers,
    method: req.method,
    signal: controller.signal,
    // If we have a body, we set the duplex and load it
    ...req.method !== "GET" && req.method !== "HEAD" ? {
      body: createReadableStreamFromReadable(req),
      duplex: "half"
    } : {}
  });
  const response = await prodHandler?.(frameworkReq, appContext());
  res.statusCode = response.status;
  res.statusMessage = response.statusText;
  for (const [key, value] of response.headers.entries()) {
    res.appendHeader(key, value);
  }
  if (response.body) {
    await writeReadableStreamToWritable(response.body, res);
  }
  res.end();
};

var define_process_env_default = {};
log.info("SRVX", "Running Node.js %s", process.versions.node);
try {
  await access("./node_modules/react-router", constants.F_OK | constants.R_OK);
  log.info("SRVX", "Found dependencies");
} catch (error) {
  log.error("SRVX", "No dependencies found. Please run `npm install`");
  console.error(error);
  process.exit(1);
}
const server = createServer(listener);
const port = define_process_env_default.PORT || 3e3;
const host = define_process_env_default.HOST || "127.0.0.1";
const ws = initWebsocket();
if (ws) {
  server.on("upgrade", (req, socket, head) => {
    ws.handleUpgrade(req, socket, head, (ws2) => {
      ws2.emit("connection", ws2, req);
    });
  });
}
server.listen(Number(port), host, () => {
  log.info("SRVX", "Running on %s:%s", host, port);
});
