import path, { posix as posix$1, win32 as win32$1 } from 'node:path';

/**
 * Constant for path separator.
 *
 * Always equals to `"/"`.
 */
declare const sep = "/";
declare const normalize: typeof path.normalize;
declare const join: typeof path.join;
declare const resolve: typeof path.resolve;
/**
 * Resolves a string path, resolving '.' and '.' segments and allowing paths above the root.
 *
 * @param path - The path to normalise.
 * @param allowAboveRoot - Whether to allow the resulting path to be above the root directory.
 * @returns the normalised path string.
 */
declare function normalizeString(path: string, allowAboveRoot: boolean): string;
declare const isAbsolute: typeof path.isAbsolute;
declare const toNamespacedPath: typeof path.toNamespacedPath;
declare const extname: typeof path.extname;
declare const relative: typeof path.relative;
declare const dirname: typeof path.dirname;
declare const format: typeof path.format;
declare const basename: typeof path.basename;
declare const parse: typeof path.parse;
/**
 * The `path.matchesGlob()` method determines if `path` matches the `pattern`.
 * @param path The path to glob-match against.
 * @param pattern The glob to check the path against.
 */
declare const matchesGlob: (path: string, pattern: string | string[]) => boolean;

/**
 * The platform-specific file delimiter.
 *
 * Equals to `";"` in windows and `":"` in all other platforms.
 */
declare const delimiter: ";" | ":";
declare const posix: typeof posix$1;
declare const win32: typeof win32$1;

export { basename, posix as default, delimiter, dirname, extname, format, isAbsolute, join, matchesGlob, normalize, normalizeString, parse, posix, relative, resolve, sep, toNamespacedPath, win32 };
