var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
import { jsx, jsxs, Fragment } from "react/jsx-runtime";
import { PassThrough } from "node:stream";
import { createReadableStreamFromReadable } from "@react-router/node";
import { createCookieSessionStorage, ServerRouter, useParams, useLoaderData, useActionData, useMatches, useRouteError, isRouteErrorResponse, Meta, Links, ScrollRestoration, Scripts, useNavigation, Outlet, redirect, Form, data, NavLink, useRevalidator, useSubmit, useFetcher, Link as Link$2 } from "react-router";
import { isbot } from "isbot";
import { renderToPipeableStream } from "react-dom/server";
import { access, constants, readdir, readFile, writeFile } from "node:fs/promises";
import { join, resolve } from "node:path";
import { setTimeout as setTimeout$1 } from "node:timers/promises";
import { Client } from "undici";
import { platform } from "node:os";
import { kill } from "node:process";
import { Config, KubeConfig, CoreV1Api } from "@kubernetes/client-node";
import { parseDocument } from "yaml";
import { z } from "zod";
import * as client from "openid-client";
import { createElement, useRef, useState, useMemo, useEffect } from "react";
import { Button as Button$2, ProgressBar, TextField as TextField$1, Input, Popover, Menu as Menu$3, MenuItem, MenuTrigger, ModalOverlay, Modal as Modal$2, Dialog as Dialog$2, DialogTrigger, Select as Select$2, SelectValue, ListBox, ListBoxItem, Switch as Switch$1, TooltipTrigger, Tooltip as Tooltip$2, Tabs, TabList, Tab, TabPanel, NumberField as NumberField$1, Group } from "react-aria-components";
import { XIcon, CheckIcon, CopyIcon, AlertIcon, ServerIcon, PeopleIcon, LockIcon, GlobeIcon, GearIcon, LinkExternalIcon, XCircleFillIcon, ChevronDownIcon, PlusIcon, KebabHorizontalIcon, KeyIcon, InfoIcon, PersonIcon, CheckCircleIcon, SkipIcon, HomeIcon, PasskeyFillIcon, OrganizationIcon, PencilIcon, EyeIcon, BeakerIcon, IssueDraftIcon, ThreeBarsIcon, RepoForkedIcon, ArrowRightIcon, DashIcon } from "@primer/octicons-react";
import clsx$1, { clsx } from "clsx";
import { twMerge } from "tailwind-merge";
import { useToastRegion, useToast } from "@react-aria/toast";
import { ToastQueue, useToastQueue } from "@react-stately/toast";
import { createPortal } from "react-dom";
import { ClientOnly } from "remix-utils/client-only";
import { useButton } from "react-aria";
import { PlaneTakeoff, CircleUser, X, Pencil } from "lucide-react";
import { useInterval } from "usehooks-ts";
import { DndContext, useDroppable, useDraggable, closestCorners, DragOverlay } from "@dnd-kit/core";
import { restrictToVerticalAxis, restrictToParentElement } from "@dnd-kit/modifiers";
import { arrayMove, SortableContext, verticalListSortingStrategy, useSortable } from "@dnd-kit/sortable";
import { CSS } from "@dnd-kit/utilities";
const log = {
  info: (category, message, ...args) => {
    defaultLog("INFO", category, message, ...args);
  },
  warn: (category, message, ...args) => {
    defaultLog("WARN", category, message, ...args);
  },
  error: (category, message, ...args) => {
    defaultLog("ERRO", category, message, ...args);
  },
  debug: (category, message, ...args) => {
    if (process.env.DEBUG === "true") {
      defaultLog("DEBG", category, message, ...args);
    }
  }
};
function defaultLog(level, category, message, ...args) {
  const date = (/* @__PURE__ */ new Date()).toISOString();
  console.log(`${date} (${level}) [${category}] ${message}`, ...args);
}
class HeadscaleError extends Error {
  constructor(message, status) {
    super(message);
    __publicField(this, "status");
    this.name = "HeadscaleError";
    this.status = status;
  }
}
async function healthcheck() {
  const context2 = await loadContext();
  const prefix = context2.headscaleUrl;
  log.debug("APIC", "GET /health");
  const health = new URL("health", prefix);
  const response = await fetch(health.toString(), {
    headers: {
      Accept: "application/json"
    }
  });
  return response.status === 200;
}
async function pull(url, key) {
  if (!key || key === "undefined" || key.length === 0) {
    throw new Error("Missing API key, could this be a cookie setting issue?");
  }
  const context2 = await loadContext();
  const prefix = context2.headscaleUrl;
  log.debug("APIC", "GET %s", `${prefix}/api/${url}`);
  const response = await fetch(`${prefix}/api/${url}`, {
    headers: {
      Authorization: `Bearer ${key}`
    }
  });
  if (!response.ok) {
    log.debug(
      "APIC",
      "GET %s failed with status %d",
      `${prefix}/api/${url}`,
      response.status
    );
    throw new HeadscaleError(await response.text(), response.status);
  }
  return response.json();
}
async function post(url, key, body) {
  if (!key || key === "undefined" || key.length === 0) {
    throw new Error("Missing API key, could this be a cookie setting issue?");
  }
  const context2 = await loadContext();
  const prefix = context2.headscaleUrl;
  log.debug("APIC", "POST %s", `${prefix}/api/${url}`);
  const response = await fetch(`${prefix}/api/${url}`, {
    method: "POST",
    body: body ? JSON.stringify(body) : void 0,
    headers: {
      Authorization: `Bearer ${key}`
    }
  });
  if (!response.ok) {
    log.debug(
      "APIC",
      "POST %s failed with status %d",
      `${prefix}/api/${url}`,
      response.status
    );
    throw new HeadscaleError(await response.text(), response.status);
  }
  return response.json();
}
async function put(url, key, body) {
  if (!key || key === "undefined" || key.length === 0) {
    throw new Error("Missing API key, could this be a cookie setting issue?");
  }
  const context2 = await loadContext();
  const prefix = context2.headscaleUrl;
  log.debug("APIC", "PUT %s", `${prefix}/api/${url}`);
  const response = await fetch(`${prefix}/api/${url}`, {
    method: "PUT",
    body: body ? JSON.stringify(body) : void 0,
    headers: {
      Authorization: `Bearer ${key}`
    }
  });
  if (!response.ok) {
    log.debug(
      "APIC",
      "PUT %s failed with status %d",
      `${prefix}/api/${url}`,
      response.status
    );
    throw new HeadscaleError(await response.text(), response.status);
  }
  return response.json();
}
async function del(url, key) {
  if (!key || key === "undefined" || key.length === 0) {
    throw new Error("Missing API key, could this be a cookie setting issue?");
  }
  const context2 = await loadContext();
  const prefix = context2.headscaleUrl;
  log.debug("APIC", "DELETE %s", `${prefix}/api/${url}`);
  const response = await fetch(`${prefix}/api/${url}`, {
    method: "DELETE",
    headers: {
      Authorization: `Bearer ${key}`
    }
  });
  if (!response.ok) {
    log.debug(
      "APIC",
      "DELETE %s failed with status %d",
      `${prefix}/api/${url}`,
      response.status
    );
    throw new HeadscaleError(await response.text(), response.status);
  }
  return response.json();
}
function createIntegration(options) {
  return options;
}
const dockerIntegration = createIntegration({
  name: "Docker",
  context: {
    client: void 0,
    container: void 0,
    maxAttempts: 10
  },
  isAvailable: async (context2) => {
    var _a;
    log.debug("INTG", "Checking Docker integration availability");
    context2.container = (_a = process.env.HEADSCALE_CONTAINER) == null ? void 0 : _a.trim().toLowerCase();
    if (!context2.container || context2.container.length === 0) {
      log.error("INTG", "Missing HEADSCALE_CONTAINER variable");
      return false;
    }
    log.info("INTG", "Using container: %s", context2.container);
    const path = process.env.DOCKER_SOCK ?? "unix:///var/run/docker.sock";
    let url;
    try {
      url = new URL(path);
    } catch {
      log.error("INTG", "Invalid Docker socket path: %s", path);
      return false;
    }
    if (url.protocol !== "tcp:" && url.protocol !== "unix:") {
      log.error("INTG", "Invalid Docker socket protocol: %s", url.protocol);
      return false;
    }
    if (url.protocol === "tcp:") {
      const fetchU = url.href.replace(url.protocol, "http:");
      try {
        log.info("INTG", "Checking API: %s", fetchU);
        await fetch(new URL("/v1.30/version", fetchU).href);
      } catch (error) {
        log.debug("INTG", "Failed to connect to Docker API", error);
        log.error("INTG", "Failed to connect to Docker API");
        return false;
      }
      context2.client = new Client(fetchU);
    }
    if (url.protocol === "unix:") {
      try {
        log.info("INTG", "Checking socket: %s", url.pathname);
        await access(url.pathname, constants.R_OK);
      } catch (error) {
        log.debug("INTG", "Failed to access Docker socket: %s", error);
        log.error("INTG", "Failed to access Docker socket: %s", path);
        return false;
      }
      context2.client = new Client("http://localhost", {
        socketPath: url.pathname
      });
    }
    return context2.client !== void 0;
  },
  onConfigChange: async (context2) => {
    if (!context2.client || !context2.container) {
      return;
    }
    log.info("INTG", "Restarting Headscale via Docker");
    let attempts = 0;
    while (attempts <= context2.maxAttempts) {
      log.debug(
        "INTG",
        "Restarting container: %s (attempt %d)",
        context2.container,
        attempts
      );
      const response = await context2.client.request({
        method: "POST",
        path: `/v1.30/containers/${context2.container}/restart`
      });
      if (response.statusCode !== 204) {
        if (attempts < context2.maxAttempts) {
          attempts++;
          await setTimeout$1(1e3);
          continue;
        }
        const stringCode = response.statusCode.toString();
        const body = await response.body.text();
        throw new Error(`API request failed: ${stringCode} ${body}`);
      }
      break;
    }
    attempts = 0;
    while (attempts <= context2.maxAttempts) {
      try {
        log.debug("INTG", "Checking Headscale status (attempt %d)", attempts);
        await pull("v1", "");
        return;
      } catch (error) {
        if (error instanceof HeadscaleError && error.status === 401) {
          break;
        }
        if (error instanceof HeadscaleError && error.status === 404) {
          break;
        }
        if (attempts < context2.maxAttempts) {
          attempts++;
          await setTimeout$1(1e3);
          continue;
        }
        throw new Error(`Missed restart deadline for ${context2.container}`);
      }
    }
  }
});
const kubernetesIntegration = createIntegration({
  name: "Kubernetes (k8s)",
  context: {
    pid: void 0
  },
  isAvailable: async (context2) => {
    var _a;
    if (platform() !== "linux") {
      log.error("INTG", "Kubernetes is only available on Linux");
      return false;
    }
    const svcRoot = Config.SERVICEACCOUNT_ROOT;
    try {
      log.debug("INTG", "Checking Kubernetes service account at %s", svcRoot);
      const files = await readdir(svcRoot);
      if (files.length === 0) {
        log.error("INTG", "Kubernetes service account not found");
        return false;
      }
      const mappedFiles = new Set(files.map((file) => join(svcRoot, file)));
      const expectedFiles = [
        Config.SERVICEACCOUNT_CA_PATH,
        Config.SERVICEACCOUNT_TOKEN_PATH,
        Config.SERVICEACCOUNT_NAMESPACE_PATH
      ];
      log.debug("INTG", "Looking for %s", expectedFiles.join(", "));
      if (!expectedFiles.every((file) => mappedFiles.has(file))) {
        log.error("INTG", "Malformed Kubernetes service account");
        return false;
      }
    } catch (error) {
      log.error("INTG", "Failed to access %s: %s", svcRoot, error);
      return false;
    }
    log.debug("INTG", "Reading Kubernetes service account at %s", svcRoot);
    const namespace = await readFile(
      Config.SERVICEACCOUNT_NAMESPACE_PATH,
      "utf8"
    );
    if (process.env.HEADSCALE_INTEGRATION_UNSTRICT === "true") {
      log.warn("INTG", "Skipping strict Pod status check");
    } else {
      const pod = process.env.POD_NAME;
      if (!pod) {
        log.error("INTG", "Missing POD_NAME variable");
        return false;
      }
      if (pod.trim().length === 0) {
        log.error("INTG", "Pod name is empty");
        return false;
      }
      log.debug(
        "INTG",
        "Checking Kubernetes pod %s in namespace %s",
        pod,
        namespace
      );
      try {
        log.debug("INTG", "Attempgin to get cluster KubeConfig");
        const kc = new KubeConfig();
        kc.loadFromCluster();
        const cluster = kc.getCurrentCluster();
        if (!cluster) {
          log.error("INTG", "Malformed kubeconfig");
          return false;
        }
        log.info(
          "INTG",
          "Service account connected to %s (%s)",
          cluster.name,
          cluster.server
        );
        const kCoreV1Api = kc.makeApiClient(CoreV1Api);
        log.info(
          "INTG",
          "Checking pod %s in namespace %s (%s)",
          pod,
          namespace,
          kCoreV1Api.basePath
        );
        log.debug("INTG", "Reading pod info for %s", pod);
        const { response, body } = await kCoreV1Api.readNamespacedPod(
          pod,
          namespace
        );
        if (response.statusCode !== 200) {
          log.error(
            "INTG",
            "Failed to read pod info: http %d",
            response.statusCode
          );
          return false;
        }
        log.debug("INTG", "Got pod info: %o", body.spec);
        const shared = (_a = body.spec) == null ? void 0 : _a.shareProcessNamespace;
        if (shared === void 0) {
          log.error("INTG", "Pod does not have spec.shareProcessNamespace set");
          return false;
        }
        if (!shared) {
          log.error(
            "INTG",
            "Pod has set but disabled spec.shareProcessNamespace"
          );
          return false;
        }
        log.info("INTG", "Pod %s enabled shared processes", pod);
      } catch (error) {
        log.error("INTG", "Failed to read pod info: %s", error);
        return false;
      }
    }
    log.debug("INTG", "Looking for namespaced process in /proc");
    const dir = resolve("/proc");
    try {
      const subdirs = await readdir(dir);
      const promises = subdirs.map(async (dir2) => {
        const pid = Number.parseInt(dir2, 10);
        if (Number.isNaN(pid)) {
          return;
        }
        const path = join("/proc", dir2, "cmdline");
        try {
          log.debug("INTG", "Reading %s", path);
          const data2 = await readFile(path, "utf8");
          if (data2.includes("headscale")) {
            return pid;
          }
        } catch (error) {
          log.debug("INTG", "Failed to read %s: %s", path, error);
        }
      });
      const results = await Promise.allSettled(promises);
      const pids = [];
      for (const result of results) {
        if (result.status === "fulfilled" && result.value) {
          pids.push(result.value);
        }
      }
      log.debug("INTG", "Found Headscale processes: %o", pids);
      if (pids.length > 1) {
        log.error(
          "INTG",
          "Found %d Headscale processes: %s",
          pids.length,
          pids.join(", ")
        );
        return false;
      }
      if (pids.length === 0) {
        log.error("INTG", "Could not find Headscale process");
        return false;
      }
      context2.pid = pids[0];
      log.info("INTG", "Found Headscale process with PID: %d", context2.pid);
      return true;
    } catch {
      log.error("INTG", "Failed to read /proc");
      return false;
    }
  },
  onConfigChange: (context2) => {
    if (!context2.pid) {
      return;
    }
    log.info("INTG", "Sending SIGTERM to Headscale");
    kill(context2.pid, "SIGTERM");
  }
});
const procIntegration = createIntegration({
  name: "Native Linux (/proc)",
  context: {
    pid: void 0
  },
  isAvailable: async (context2) => {
    if (platform() !== "linux") {
      log.error("INTG", "/proc is only available on Linux");
      return false;
    }
    log.debug("INTG", "Checking /proc for Headscale process");
    const dir = resolve("/proc");
    try {
      const subdirs = await readdir(dir);
      const promises = subdirs.map(async (dir2) => {
        const pid = Number.parseInt(dir2, 10);
        if (Number.isNaN(pid)) {
          return;
        }
        const path = join("/proc", dir2, "cmdline");
        try {
          log.debug("INTG", "Reading %s", path);
          const data2 = await readFile(path, "utf8");
          if (data2.includes("headscale")) {
            return pid;
          }
        } catch (error) {
          log.error("INTG", "Failed to read %s: %s", path, error);
        }
      });
      const results = await Promise.allSettled(promises);
      const pids = [];
      for (const result of results) {
        if (result.status === "fulfilled" && result.value) {
          pids.push(result.value);
        }
      }
      log.debug("INTG", "Found Headscale processes: %o", pids);
      if (pids.length > 1) {
        log.error(
          "INTG",
          "Found %d Headscale processes: %s",
          pids.length,
          pids.join(", ")
        );
        return false;
      }
      if (pids.length === 0) {
        log.error("INTG", "Could not find Headscale process");
        return false;
      }
      context2.pid = pids[0];
      log.info("INTG", "Found Headscale process with PID: %d", context2.pid);
      return true;
    } catch {
      log.error("INTG", "Failed to read /proc");
      return false;
    }
  }
});
async function loadIntegration() {
  var _a;
  let integration = (_a = process.env.HEADSCALE_INTEGRATION) == null ? void 0 : _a.trim().toLowerCase();
  if (!integration && process.env.HEADSCALE_CONTAINER) {
    integration = "docker";
  }
  if (!integration) {
    log.info("INTG", "No integration set with HEADSCALE_INTEGRATION");
    return;
  }
  let integrationFactory;
  switch (integration.toLowerCase().trim()) {
    case "docker": {
      integrationFactory = dockerIntegration;
      break;
    }
    case "proc":
    case "native":
    case "linux": {
      integrationFactory = procIntegration;
      break;
    }
    case "kubernetes":
    case "k8s": {
      integrationFactory = kubernetesIntegration;
      break;
    }
    default: {
      log.error("INTG", "Unknown integration: %s", integration);
      throw new Error(`Unknown integration: ${integration}`);
    }
  }
  log.info("INTG", "Loading integration: %s", integration);
  try {
    const res = await integrationFactory.isAvailable(
      integrationFactory.context
    );
    if (!res) {
      log.error("INTG", "Integration %s is not available", integration);
      return;
    }
  } catch (error) {
    log.error("INTG", "Failed to load integration %s: %s", integration, error);
    return;
  }
  log.info("INTG", "Loaded integration: %s", integration);
  return integrationFactory;
}
const goBool = z.union([z.boolean(), z.literal("true"), z.literal("false")]).transform((value) => {
  if (typeof value === "boolean") {
    return value;
  }
  return value === "true";
});
const goDuration = z.union([z.literal(0), z.string()]);
const HeadscaleConfig = z.object({
  tls_letsencrypt_cache_dir: z.string().default("/var/www/cache"),
  tls_letsencrypt_challenge_type: z.enum(["HTTP-01", "TLS-ALPN-01"]).default("HTTP-01"),
  tls_letsencrypt_hostname: z.string().optional(),
  tls_letsencrypt_listen: z.string().optional(),
  tls_cert_path: z.string().nullish(),
  tls_key_path: z.string().nullish(),
  server_url: z.string().regex(/^https?:\/\//),
  listen_addr: z.string(),
  metrics_listen_addr: z.string().optional(),
  grpc_listen_addr: z.string().default(":50443"),
  grpc_allow_insecure: goBool.default(false),
  disable_check_updates: goBool.default(false),
  ephemeral_node_inactivity_timeout: goDuration.default("120s"),
  randomize_client_port: goBool.default(false),
  acme_email: z.string().optional(),
  acme_url: z.string().optional(),
  unix_socket: z.string().default("/var/run/headscale/headscale.sock"),
  unix_socket_permission: z.string().default("0o770"),
  policy: z.object({
    mode: z.enum(["file", "database"]).default("file"),
    path: z.string().optional()
  }).optional(),
  tuning: z.object({
    batch_change_delay: goDuration.default("800ms"),
    node_mapsession_buffered_chan_size: z.number().default(30)
  }).optional(),
  noise: z.object({
    private_key_path: z.string()
  }),
  log: z.object({
    level: z.string().default("info"),
    format: z.enum(["text", "json"]).default("text")
  }).default({ level: "info", format: "text" }),
  logtail: z.object({
    enabled: goBool.default(false)
  }).default({ enabled: false }),
  cli: z.object({
    address: z.string().optional(),
    api_key: z.string().optional(),
    timeout: goDuration.default("10s"),
    insecure: goBool.default(false)
  }).optional(),
  prefixes: z.object({
    allocation: z.enum(["sequential", "random"]).default("sequential"),
    v4: z.string(),
    v6: z.string()
  }),
  dns: z.object({
    magic_dns: goBool.default(true),
    base_domain: z.string().default("headscale.net"),
    nameservers: z.object({
      global: z.array(z.string()).default([]),
      split: z.record(z.array(z.string())).default({})
    }).default({ global: [], split: {} }),
    search_domains: z.array(z.string()).default([]),
    extra_records: z.array(
      z.object({
        name: z.string(),
        type: z.literal("A"),
        value: z.string()
      })
    ).default([])
  }),
  oidc: z.object({
    only_start_if_oidc_is_available: goBool.default(false),
    issuer: z.string().optional(),
    client_id: z.string().optional(),
    client_secret: z.string().optional(),
    client_secret_path: z.string().nullish(),
    scope: z.array(z.string()).default(["openid", "profile", "email"]),
    extra_params: z.record(z.unknown()).default({}),
    allowed_domains: z.array(z.string()).optional(),
    allowed_users: z.array(z.string()).optional(),
    allowed_groups: z.array(z.string()).optional(),
    strip_email_domain: goBool.default(false),
    expiry: goDuration.default("180d"),
    use_expiry_from_token: goBool.default(false)
  }).optional(),
  database: z.union([
    z.object({
      type: z.literal("sqlite"),
      debug: goBool.default(false),
      sqlite: z.object({
        path: z.string()
      })
    }),
    z.object({
      type: z.literal("sqlite3"),
      debug: goBool.default(false),
      sqlite: z.object({
        path: z.string()
      })
    }),
    z.object({
      type: z.literal("postgres"),
      debug: goBool.default(false),
      postgres: z.object({
        host: z.string(),
        port: z.number(),
        name: z.string(),
        user: z.string(),
        pass: z.string(),
        ssl: goBool.default(true),
        max_open_conns: z.number().default(10),
        max_idle_conns: z.number().default(10),
        conn_max_idle_time_secs: z.number().default(3600)
      })
    })
  ]),
  derp: z.object({
    server: z.object({
      enabled: goBool.default(true),
      region_id: z.number().optional(),
      region_code: z.string().optional(),
      region_name: z.string().optional(),
      stun_listen_addr: z.string().optional(),
      private_key_path: z.string().optional(),
      ipv4: z.string().optional(),
      ipv6: z.string().optional(),
      automatically_add_embedded_derp_region: goBool.default(true)
    }),
    urls: z.array(z.string()).optional(),
    paths: z.array(z.string()).optional(),
    auto_update_enabled: goBool.default(true),
    update_frequency: goDuration.default("24h")
  })
});
let configYaml;
let config;
async function loadConfig(path) {
  if (config) {
    return config;
  }
  if (!path) {
    throw new Error("Path is required to lazy load config");
  }
  log.debug("CFGX", "Loading Headscale configuration from %s", path);
  const data2 = await readFile(path, "utf8");
  configYaml = parseDocument(data2);
  if (process.env.HEADSCALE_CONFIG_UNSTRICT === "true") {
    log.debug("CFGX", "Loaded Headscale configuration in non-strict mode");
    const loaded = configYaml.toJSON();
    config = {
      ...loaded,
      tls_letsencrypt_cache_dir: loaded.tls_letsencrypt_cache_dir ?? "/var/www/cache",
      tls_letsencrypt_challenge_type: loaded.tls_letsencrypt_challenge_type ?? "HTTP-01",
      grpc_listen_addr: loaded.grpc_listen_addr ?? ":50443",
      grpc_allow_insecure: loaded.grpc_allow_insecure ?? false,
      randomize_client_port: loaded.randomize_client_port ?? false,
      unix_socket: loaded.unix_socket ?? "/var/run/headscale/headscale.sock",
      unix_socket_permission: loaded.unix_socket_permission ?? "0o770",
      tuning: loaded.tuning ?? {
        batch_change_delay: "800ms",
        node_mapsession_buffered_chan_size: 30
      },
      log: loaded.log ?? {
        level: "info",
        format: "text"
      },
      logtail: loaded.logtail ?? {
        enabled: false
      },
      cli: loaded.cli ?? {
        timeout: "10s",
        insecure: false
      },
      prefixes: loaded.prefixes ?? {
        allocation: "sequential",
        v4: "",
        v6: ""
      },
      dns: loaded.dns ?? {
        nameservers: {
          global: [],
          split: {}
        },
        search_domains: [],
        extra_records: [],
        magic_dns: false,
        base_domain: "headscale.net"
      }
    };
    log.warn("CFGX", "Loaded Headscale configuration in non-strict mode");
    log.warn("CFGX", "By using this mode you forfeit GitHub issue support");
    log.warn("CFGX", "This is very dangerous and comes with a few caveats:");
    log.warn("CFGX", "Headplane could very easily crash");
    log.warn("CFGX", "Headplane could break your Headscale installation");
    log.warn("CFGX", "The UI could throw random errors/show incorrect data");
    log.warn("CFGX", "");
    return config;
  }
  try {
    log.debug("CFGX", "Attempting to parse Headscale configuration");
    config = await HeadscaleConfig.parseAsync(configYaml.toJSON());
  } catch (error) {
    log.debug("CFGX", "Failed to load Headscale configuration");
    if (error instanceof z.ZodError) {
      log.error("CFGX", "Recieved invalid configuration file");
      log.error("CFGX", "The following schema issues were found:");
      for (const issue of error.issues) {
        const path2 = issue.path.map(String).join(".");
        const message = issue.message;
        log.error("CFGX", `  '${path2}': ${message}`);
      }
      log.error("CFGX", "");
      log.error("CFGX", "Resolve these issues and try again.");
      log.error("CFGX", "Headplane will operate without the config");
      log.error("CFGX", "");
    }
    throw error;
  }
  return config;
}
async function patchConfig(partial) {
  if (!configYaml || !config) {
    throw new Error("Config not loaded");
  }
  log.debug("CFGX", "Patching Headscale configuration");
  for (const [key, value] of Object.entries(partial)) {
    log.debug("CFGX", "Patching %s with %s", key, value);
    const path2 = [];
    let temp = "";
    let inQuote = false;
    for (const element of key) {
      if (element === '"') {
        inQuote = !inQuote;
      }
      if (element === "." && !inQuote) {
        path2.push(temp.replaceAll('"', ""));
        temp = "";
        continue;
      }
      temp += element;
    }
    path2.push(temp.replaceAll('"', ""));
    if (value === null) {
      configYaml.deleteIn(path2);
      continue;
    }
    configYaml.setIn(path2, value);
  }
  config = process.env.HEADSCALE_CONFIG_UNSTRICT === "true" ? configYaml.toJSON() : await HeadscaleConfig.parseAsync(configYaml.toJSON());
  const path = resolve(process.env.CONFIG_FILE ?? "/etc/headscale/config.yaml");
  log.debug("CFGX", "Writing patched configuration to %s", path);
  await writeFile(path, configYaml.toString(), "utf8");
}
z.object({
  issuer: z.string(),
  clientId: z.string(),
  clientSecret: z.string(),
  redirectUri: z.string().optional(),
  tokenEndpointAuthMethod: z.enum(["client_secret_post", "client_secret_basic", "client_secret_jwt"]).default("client_secret_basic")
});
function getRedirectUri(req) {
  const base = "/admin";
  const url = new URL(`${base}/oidc/callback`, req.url);
  let host = req.headers.get("Host");
  if (!host) {
    host = req.headers.get("X-Forwarded-Host");
  }
  if (!host) {
    log.error("OIDC", "Unable to find a host header");
    log.error("OIDC", "Ensure either Host or X-Forwarded-Host is set");
    throw new Error("Could not determine reverse proxy host");
  }
  const proto = req.headers.get("X-Forwarded-Proto");
  if (!proto) {
    log.warn("OIDC", "No X-Forwarded-Proto header found");
    log.warn("OIDC", "Assuming your Headplane instance runs behind HTTP");
  }
  url.protocol = proto ?? "http:";
  url.host = host;
  return url.href;
}
function clientAuthMethod(method) {
  switch (method) {
    case "client_secret_post":
      return client.ClientSecretPost;
    case "client_secret_basic":
      return client.ClientSecretBasic;
    case "client_secret_jwt":
      return client.ClientSecretJwt;
    default:
      throw new Error("Invalid client authentication method");
  }
}
async function beginAuthFlow(oidc, redirect_uri) {
  const config2 = await client.discovery(
    new URL(oidc.issuer),
    oidc.clientId,
    oidc.clientSecret,
    new clientAuthMethod(oidc.tokenEndpointAuthMethod)(oidc.clientSecret)
  );
  let codeVerifier, codeChallenge;
  codeVerifier = client.randomPKCECodeVerifier();
  codeChallenge = await client.calculatePKCECodeChallenge(codeVerifier);
  const params = {
    redirect_uri,
    scope: "openid profile email",
    code_challenge: codeChallenge,
    code_challenge_method: "S256",
    token_endpoint_auth_method: oidc.tokenEndpointAuthMethod,
    state: client.randomState()
  };
  if (!config2.serverMetadata().supportsPKCE()) {
    params.nonce = client.randomNonce();
  }
  const url = client.buildAuthorizationUrl(config2, params);
  return {
    url: url.href,
    codeVerifier,
    state: params.state,
    nonce: params.nonce ?? "<none>"
  };
}
async function finishAuthFlow(oidc, options) {
  const config2 = await client.discovery(
    new URL(oidc.issuer),
    oidc.clientId,
    oidc.clientSecret,
    new clientAuthMethod(oidc.tokenEndpointAuthMethod)(oidc.clientSecret)
  );
  const tokens = await client.authorizationCodeGrant(config2, new URL(options.redirect_uri), {
    pkceCodeVerifier: options.codeVerifier,
    expectedNonce: options.nonce,
    expectedState: options.state,
    idTokenExpected: true
  });
  const claims = tokens.claims();
  if (!(claims == null ? void 0 : claims.sub)) {
    throw new Error("No subject found in OIDC claims");
  }
  await client.fetchUserInfo(
    config2,
    tokens.access_token,
    claims.sub
  );
  return {
    subject: claims.sub,
    name: claims.name ? String(claims.name) : "Anonymous",
    email: claims.email ? String(claims.email) : void 0,
    username: claims.preferred_username ? String(claims.preferred_username) : void 0
  };
}
function formatError(error) {
  if (error instanceof client.ResponseBodyError) {
    return {
      code: error.code,
      error: {
        name: error.error,
        description: error.error_description
      }
    };
  }
  if (error instanceof client.AuthorizationResponseError) {
    return {
      code: error.code,
      error: {
        name: error.error,
        description: error.error_description
      }
    };
  }
  if (error instanceof client.WWWAuthenticateChallengeError) {
    return {
      code: error.code,
      error: {
        name: error.name,
        description: error.message,
        challenges: error.cause
      }
    };
  }
  log.error("OIDC", "Unknown error: %s", error);
  return {
    code: 500,
    error: {
      name: "Internal Server Error",
      description: "An unknown error occurred"
    }
  };
}
async function testOidc(oidc) {
  log.debug("OIDC", "Discovering OIDC configuration from %s", oidc.issuer);
  const config2 = await client.discovery(
    new URL(oidc.issuer),
    oidc.clientId,
    oidc.clientSecret,
    new clientAuthMethod(oidc.tokenEndpointAuthMethod)(oidc.clientSecret)
  );
  const meta2 = config2.serverMetadata();
  if (meta2.authorization_endpoint === void 0) {
    return false;
  }
  log.debug("OIDC", "Authorization endpoint: %s", meta2.authorization_endpoint);
  log.debug("OIDC", "Token endpoint: %s", meta2.token_endpoint);
  if (meta2.response_types_supported.includes("code") === false) {
    log.error("OIDC", "OIDC server does not support code flow");
    return false;
  }
  if (meta2.token_endpoint_auth_methods_supported.includes(oidc.tokenEndpointAuthMethod) === false) {
    log.error("OIDC", "OIDC server does not support %s", oidc.tokenEndpointAuthMethod);
    return false;
  }
  log.debug("OIDC", "OIDC configuration is valid");
  return true;
}
let sessionStorage = null;
function initSessionManager() {
  if (sessionStorage) {
    return;
  }
  sessionStorage = createCookieSessionStorage({
    cookie: {
      name: "hp_sess",
      httpOnly: true,
      maxAge: 60 * 60 * 24,
      // 24 hours
      path: "/",
      sameSite: "lax",
      secrets: [process.env.COOKIE_SECRET],
      secure: process.env.COOKIE_SECURE !== "false"
    }
  });
}
function getSession(cookie) {
  if (!sessionStorage) {
    throw new Error("Session manager not initialized");
  }
  return sessionStorage.getSession(cookie);
}
function destroySession(session) {
  if (!sessionStorage) {
    throw new Error("Session manager not initialized");
  }
  return sessionStorage.destroySession(session);
}
function commitSession(session, opts) {
  if (!sessionStorage) {
    throw new Error("Session manager not initialized");
  }
  return sessionStorage.commitSession(session, opts);
}
let context;
let loadLock = false;
async function loadContext() {
  var _a;
  if (context) {
    return context;
  }
  if (loadLock) {
    return new Promise((resolve2) => {
      const interval = setInterval(() => {
        if (context) {
          clearInterval(interval);
          resolve2(context);
        }
      }, 100);
    });
  }
  loadLock = true;
  const envFile = process.env.LOAD_ENV_FILE === "true";
  if (envFile) {
    log.info("CTXT", "Loading environment variables from .env");
    await import("dotenv/config");
  }
  const debug = process.env.DEBUG === "true";
  if (debug) {
    log.info("CTXT", "Debug mode is enabled! Logs will spam a lot.");
    log.info("CTXT", "Please disable debug mode in production.");
  }
  const path = resolve(process.env.CONFIG_FILE ?? "/etc/headscale/config.yaml");
  const { config: config2, contextData } = await checkConfig(path);
  let headscaleUrl = process.env.HEADSCALE_URL;
  let headscalePublicUrl = process.env.HEADSCALE_PUBLIC_URL;
  if (!headscaleUrl && !config2) {
    throw new Error("HEADSCALE_URL not set");
  }
  if (config2) {
    headscaleUrl = headscaleUrl ?? config2.server_url;
    if (!headscalePublicUrl) {
      headscalePublicUrl = config2.server_url;
    }
  }
  if (!headscaleUrl) {
    throw new Error("Missing server_url in headscale config");
  }
  const cookieSecret = process.env.COOKIE_SECRET;
  if (!cookieSecret) {
    throw new Error("COOKIE_SECRET not set");
  }
  initSessionManager();
  const cacheEnabled = process.env.AGENT_CACHE_DISABLED !== "true";
  const cachePath = process.env.AGENT_CACHE_PATH ?? "/etc/headplane/agent.cache";
  const cacheTTL = 300 * 1e3;
  context = {
    debug,
    headscaleUrl,
    headscalePublicUrl,
    cookieSecret,
    integration: await loadIntegration(),
    config: contextData,
    cache: {
      enabled: cacheEnabled,
      path: cachePath,
      defaultTTL: cacheTTL
    },
    oidc: await checkOidc(config2)
  };
  log.info("CTXT", "Starting Headplane with Context");
  log.info("CTXT", "HEADSCALE_URL: %s", headscaleUrl);
  if (headscalePublicUrl) {
    log.info("CTXT", "HEADSCALE_PUBLIC_URL: %s", headscalePublicUrl);
  }
  log.info("CTXT", "Integration: %s", ((_a = context.integration) == null ? void 0 : _a.name) ?? "None");
  log.info(
    "CTXT",
    "Config: %s",
    contextData.read ? `Found ${contextData.write ? "" : "(Read Only)"}` : "Unavailable"
  );
  log.info("CTXT", "OIDC: %s", context.oidc ? "Configured" : "Unavailable");
  loadLock = false;
  return context;
}
async function checkConfig(path) {
  log.debug("CTXT", "Checking config at %s", path);
  let config2;
  try {
    config2 = await loadConfig(path);
  } catch {
    log.debug("CTXT", "Config at %s failed to load", path);
    return {
      config: void 0,
      contextData: {
        read: false,
        write: false
      }
    };
  }
  let write = false;
  try {
    log.debug("CTXT", "Checking write access to %s", path);
    await access(path, constants.W_OK);
    write = true;
  } catch {
    log.debug("CTXT", "No write access to %s", path);
  }
  return {
    config: config2,
    contextData: {
      read: true,
      write
    }
  };
}
async function checkOidc(config2) {
  var _a, _b, _c, _d, _e;
  log.debug("CTXT", "Checking OIDC configuration");
  const disableKeyLogin = process.env.DISABLE_API_KEY_LOGIN === "true";
  log.debug("CTXT", "API Key Login Enabled: %s", !disableKeyLogin);
  log.debug("CTXT", "Checking ROOT_API_KEY and falling back to API_KEY");
  const rootKey = process.env.ROOT_API_KEY ?? process.env.API_KEY;
  if (!rootKey) {
    throw new Error("ROOT_API_KEY or API_KEY not set");
  }
  let issuer = process.env.OIDC_ISSUER;
  let client2 = process.env.OIDC_CLIENT_ID;
  let secret = process.env.OIDC_CLIENT_SECRET;
  const method = process.env.OIDC_CLIENT_SECRET_METHOD ?? "client_secret_basic";
  const skip = process.env.OIDC_SKIP_CONFIG_VALIDATION === "true";
  const redirectUri = process.env.OIDC_REDIRECT_URI;
  log.debug("CTXT", "Checking OIDC environment variables");
  log.debug("CTXT", "Issuer: %s", issuer);
  log.debug("CTXT", "Client: %s", client2);
  log.debug("CTXT", "Token Auth Method: %s", method);
  if (redirectUri) {
    log.debug("CTXT", "Redirect URI: %s", redirectUri);
  }
  if ((issuer ?? client2 ?? secret) && !(issuer && client2 && secret) && !config2) {
    throw new Error("OIDC environment variables are incomplete");
  }
  if (issuer && client2 && secret) {
    if (!skip) {
      log.debug(
        "CTXT",
        "Validating OIDC configuration from environment variables"
      );
      const oidcConfig = {
        issuer,
        clientId: client2,
        clientSecret: secret,
        tokenEndpointAuthMethod: method
      };
      const result = await testOidc(oidcConfig);
      if (!result) {
        return;
      }
    } else {
      log.debug("CTXT", "OIDC_SKIP_CONFIG_VALIDATION is set");
      log.debug("CTXT", "Skipping OIDC configuration validation");
    }
    return {
      issuer,
      client: client2,
      secret,
      redirectUri,
      method,
      rootKey,
      disableKeyLogin
    };
  }
  if ((!issuer || !client2 || !secret) && config2) {
    issuer = (_a = config2.oidc) == null ? void 0 : _a.issuer;
    client2 = (_b = config2.oidc) == null ? void 0 : _b.client_id;
    secret = (_c = config2.oidc) == null ? void 0 : _c.client_secret;
    if (!secret && ((_d = config2.oidc) == null ? void 0 : _d.client_secret_path)) {
      log.debug(
        "CTXT",
        "Trying to read OIDC client secret from %s",
        config2.oidc.client_secret_path
      );
      try {
        const data2 = await readFile(config2.oidc.client_secret_path, "utf8");
        if (data2 && data2.length > 0) {
          secret = data2.trim();
        }
      } catch {
        log.error(
          "CTXT",
          "Failed to read OIDC client secret from %s",
          config2.oidc.client_secret_path
        );
      }
    }
  }
  if ((issuer ?? client2 ?? secret) && !(issuer && client2 && secret)) {
    throw new Error("OIDC configuration is incomplete");
  }
  if (!issuer || !client2 || !secret) {
    return;
  }
  if ((_e = config2 == null ? void 0 : config2.oidc) == null ? void 0 : _e.only_start_if_oidc_is_available) {
    log.debug("CTXT", "Validating OIDC configuration from headscale config");
    const oidcConfig = {
      issuer,
      clientId: client2,
      clientSecret: secret,
      tokenEndpointAuthMethod: method
    };
    const result = await testOidc(oidcConfig);
    if (!result) {
      return;
    }
  } else {
    log.debug("CTXT", "OIDC validation is disabled in headscale config");
    log.debug("CTXT", "Skipping OIDC configuration validation");
  }
  return {
    issuer,
    client: client2,
    secret,
    redirectUri,
    rootKey,
    method,
    disableKeyLogin
  };
}
loadContext();
const streamTimeout = 5e3;
function handleRequest(request, responseStatusCode, responseHeaders, routerContext, loadContext2) {
  return new Promise((resolve2, reject) => {
    let shellRendered = false;
    const userAgent = request.headers.get("user-agent");
    const readyOption = userAgent && isbot(userAgent) || routerContext.isSpaMode ? "onAllReady" : "onShellReady";
    const { pipe, abort } = renderToPipeableStream(
      /* @__PURE__ */ jsx(ServerRouter, { context: routerContext, url: request.url }),
      {
        [readyOption]() {
          shellRendered = true;
          const body = new PassThrough();
          const stream = createReadableStreamFromReadable(body);
          responseHeaders.set("Content-Type", "text/html");
          resolve2(
            new Response(stream, {
              headers: responseHeaders,
              status: responseStatusCode
            })
          );
          pipe(body);
        },
        onShellError(error) {
          reject(error);
        },
        onError(error) {
          responseStatusCode = 500;
          if (shellRendered) {
            console.error(error);
          }
        }
      }
    );
    setTimeout(abort, streamTimeout + 1e3);
  });
}
const entryServer = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: handleRequest,
  streamTimeout
}, Symbol.toStringTag, { value: "Module" }));
function withComponentProps(Component) {
  return function Wrapped() {
    const props = {
      params: useParams(),
      loaderData: useLoaderData(),
      actionData: useActionData(),
      matches: useMatches()
    };
    return createElement(Component, props);
  };
}
function withErrorBoundaryProps(ErrorBoundary5) {
  return function Wrapped() {
    const props = {
      params: useParams(),
      loaderData: useLoaderData(),
      actionData: useActionData(),
      error: useRouteError()
    };
    return createElement(ErrorBoundary5, props);
  };
}
const cn = (...inputs) => twMerge(clsx(inputs));
function Title({ children, className }) {
  return /* @__PURE__ */ jsx("h3", { className: cn("text-2xl font-bold mb-6", className), children });
}
function Text({ children, className }) {
  return /* @__PURE__ */ jsx("p", { className: cn("text-md my-0", className), children });
}
function Card({ variant = "raised", ...props }) {
  return /* @__PURE__ */ jsx(
    "div",
    {
      ...props,
      className: cn(
        "w-full max-w-md overflow-hidden rounded-3xl p-5",
        variant === "flat" ? "bg-transparent shadow-none" : "bg-headplane-50/50 dark:bg-headplane-950/50 shadow-sm",
        "border border-headplane-100 dark:border-headplane-800",
        props.className
      ),
      children: props.children
    }
  );
}
const Card$1 = Object.assign(Card, { Title, Text });
function Toast({ state, ...properties }) {
  const reference = useRef(null);
  const { toastProps, titleProps, closeButtonProps } = useToast(
    properties,
    state,
    reference
  );
  return /* @__PURE__ */ jsxs(
    "div",
    {
      ...toastProps,
      ref: reference,
      className: cn(
        "bg-main-700 dark:bg-main-800 rounded-lg",
        "text-main-100 dark:text-main-200 z-50",
        "border border-main-600 dark:border-main-700",
        "flex items-center justify-between p-3 pl-4 w-80"
      ),
      children: [
        /* @__PURE__ */ jsx("div", { ...titleProps, children: properties.toast.content }),
        /* @__PURE__ */ jsx(
          Button$2,
          {
            ...closeButtonProps,
            className: cn(
              "outline-none rounded-full p-1",
              "hover:bg-main-600 dark:hover:bg-main-700"
            ),
            children: /* @__PURE__ */ jsx(XIcon, { className: "w-4 h-4" })
          }
        )
      ]
    }
  );
}
const toasts = new ToastQueue({
  maxVisibleToasts: 5
});
function toast(text) {
  return toasts.add(text, { timeout: 5e3 });
}
function Toaster() {
  const reference = useRef(null);
  const state = useToastQueue(toasts);
  const { regionProps } = useToastRegion({}, state, reference);
  return /* @__PURE__ */ jsx(ClientOnly, { children: () => createPortal(
    state.visibleToasts.length >= 0 ? /* @__PURE__ */ jsx(
      "div",
      {
        className: cn("fixed bottom-20 right-4", "flex flex-col gap-4"),
        ...regionProps,
        ref: reference,
        children: state.visibleToasts.map((toast2) => /* @__PURE__ */ jsx(Toast, { toast: toast2, state }, toast2.key))
      }
    ) : void 0,
    document.body
  ) });
}
function Code(props) {
  const [isCopied, setIsCopied] = useState(false);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(
      "code",
      {
        className: cn(
          "bg-ui-100 dark:bg-ui-800 p-0.5 rounded-md",
          props.className
        ),
        children: props.children
      }
    ),
    props.isCopyable ? /* @__PURE__ */ jsx(
      "button",
      {
        className: cn(
          "ml-1 p-1 rounded-md",
          "bg-ui-100 dark:bg-ui-800",
          "text-ui-500 dark:text-ui-400",
          "inline-flex items-center justify-center"
        ),
        onClick: () => {
          if (!props.children) {
            throw new Error("Made copyable without children");
          }
          navigator.clipboard.writeText(props.children.join(""));
          toast("Copied to clipboard");
          setIsCopied(true);
          setTimeout(() => setIsCopied(false), 1e3);
        },
        children: isCopied ? /* @__PURE__ */ jsx(CheckIcon, { className: "h-3 w-3" }) : /* @__PURE__ */ jsx(CopyIcon, { className: "h-3 w-3" })
      }
    ) : void 0
  ] });
}
function getMessage(error) {
  if (!(error instanceof Error)) {
    return "An unknown error occurred";
  }
  let rootError = error;
  if (error.cause) {
    rootError = error.cause;
    while (rootError.cause) {
      rootError = rootError.cause;
    }
  }
  if (rootError instanceof AggregateError) {
    return rootError.errors.map((error2) => error2.message).join("\n");
  }
  return rootError.message;
}
function ErrorPopup({ type = "full" }) {
  const error = useRouteError();
  const routing = isRouteErrorResponse(error);
  const message = getMessage(error);
  return /* @__PURE__ */ jsx(
    "div",
    {
      className: cn(
        "flex items-center justify-center",
        type === "embedded" ? "pointer-events-none mt-24" : "fixed inset-0 h-screen w-screen z-50"
      ),
      children: /* @__PURE__ */ jsxs(Card$1, { children: [
        /* @__PURE__ */ jsxs("div", { className: "flex items-center justify-between", children: [
          /* @__PURE__ */ jsx(Card$1.Title, { className: "text-3xl mb-0", children: routing ? error.status : "Error" }),
          /* @__PURE__ */ jsx(AlertIcon, { className: "w-12 h-12 text-red-500" })
        ] }),
        /* @__PURE__ */ jsx(Card$1.Text, { className: "mt-4 text-lg", children: routing ? error.statusText : /* @__PURE__ */ jsx(Code, { children: message }) })
      ] })
    }
  );
}
const stylesheet = "/admin/assets/tailwind-D5tCdekT.css";
const meta = () => [{
  title: "Headplane"
}, {
  name: "description",
  content: "A frontend for the headscale coordination server"
}];
const links = () => [{
  rel: "stylesheet",
  href: stylesheet
}];
function Layout({
  children
}) {
  return /* @__PURE__ */ jsxs("html", {
    lang: "en",
    children: [/* @__PURE__ */ jsxs("head", {
      children: [/* @__PURE__ */ jsx("meta", {
        charSet: "utf-8"
      }), /* @__PURE__ */ jsx("meta", {
        name: "viewport",
        content: "width=device-width, initial-scale=1"
      }), /* @__PURE__ */ jsx(Meta, {}), /* @__PURE__ */ jsx(Links, {})]
    }), /* @__PURE__ */ jsxs("body", {
      className: "overscroll-none dark:bg-headplane-900 dark:text-headplane-50",
      children: [children, /* @__PURE__ */ jsx(Toaster, {}), /* @__PURE__ */ jsx(ScrollRestoration, {}), /* @__PURE__ */ jsx(Scripts, {})]
    })]
  });
}
const ErrorBoundary$2 = withErrorBoundaryProps(function ErrorBoundary() {
  return /* @__PURE__ */ jsx(ErrorPopup, {});
});
const root = withComponentProps(function App() {
  const nav = useNavigation();
  return /* @__PURE__ */ jsxs(Fragment, {
    children: [/* @__PURE__ */ jsx(ProgressBar, {
      "aria-label": "Loading...",
      children: /* @__PURE__ */ jsx("div", {
        className: cn("fixed top-0 left-0 z-50 w-1/2 h-1", "bg-blue-500 dark:bg-blue-400 opacity-0", nav.state === "loading" && "animate-loading opacity-100")
      })
    }), /* @__PURE__ */ jsx(Outlet, {})]
  });
});
const route0 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  ErrorBoundary: ErrorBoundary$2,
  Layout,
  default: root,
  links,
  meta
}, Symbol.toStringTag, { value: "Module" }));
async function loader$d() {
  return redirect("/machines");
}
const route1 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  loader: loader$d
}, Symbol.toStringTag, { value: "Module" }));
async function loader$c() {
  let healthy = false;
  try {
    healthy = await healthcheck();
  } catch (error) {
    log.debug("APIC", "Healthcheck failed %o", error);
  }
  return new Response(JSON.stringify({
    status: healthy ? "OK" : "ERROR"
  }), {
    status: healthy ? 200 : 500,
    headers: {
      "Content-Type": "application/json"
    }
  });
}
const route2 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  loader: loader$c
}, Symbol.toStringTag, { value: "Module" }));
function Button$1({ variant = "light", ...props }) {
  const ref = useRef(null);
  const { buttonProps } = useButton(props, ref);
  return /* @__PURE__ */ jsx(
    "button",
    {
      ref,
      ...buttonProps,
      className: cn(
        "w-fit text-sm rounded-xl px-3 py-2",
        "focus:outline-none focus:ring",
        props.isDisabled && "opacity-60 cursor-not-allowed",
        ...variant === "heavy" ? [
          "bg-headplane-900 dark:bg-headplane-50 font-semibold",
          "hover:bg-headplane-900/90 dark:hover:bg-headplane-50/90",
          "text-headplane-200 dark:text-headplane-800"
        ] : [
          "bg-headplane-100 dark:bg-headplane-700/30 font-medium",
          "hover:bg-headplane-200/90 dark:hover:bg-headplane-800/30"
        ],
        props.className
      ),
      children: props.children
    }
  );
}
function TextField(props) {
  var _a;
  return /* @__PURE__ */ jsx(TextField$1, { ...props, "aria-label": props.label, className: "w-full", children: /* @__PURE__ */ jsx(
    Input,
    {
      placeholder: props.placeholder,
      value: (_a = props.state) == null ? void 0 : _a[0],
      name: props.name,
      className: cn(
        "block px-2.5 py-1.5 w-full rounded-lg my-1",
        "border border-ui-200 dark:border-ui-600",
        "dark:bg-ui-800 dark:text-ui-300",
        props.className
      ),
      onChange: (event) => {
        var _a2;
        (_a2 = props.state) == null ? void 0 : _a2[1](event.target.value);
      }
    }
  ) });
}
async function loader$b({
  request
}) {
  var _a, _b, _c;
  const session = await getSession(request.headers.get("Cookie"));
  if (session.has("hsApiKey")) {
    return redirect("/machines", {
      headers: {
        "Set-Cookie": await commitSession(session)
      }
    });
  }
  const context2 = await loadContext();
  if ((_a = context2.oidc) == null ? void 0 : _a.disableKeyLogin) {
    return redirect("/oidc/start");
  }
  return {
    oidc: (_b = context2.oidc) == null ? void 0 : _b.issuer,
    apiKey: !((_c = context2.oidc) == null ? void 0 : _c.disableKeyLogin)
  };
}
async function action$7({
  request
}) {
  const formData = await request.formData();
  const oidcStart = formData.get("oidc-start");
  const session = await getSession(request.headers.get("Cookie"));
  if (oidcStart) {
    const context2 = await loadContext();
    if (!context2.oidc) {
      throw new Error("An invalid OIDC configuration was provided");
    }
    return redirect("/oidc/start");
  }
  const apiKey = String(formData.get("api-key"));
  try {
    const apiKeys = await pull("v1/apikey", apiKey);
    const key = apiKeys.apiKeys.find((k) => apiKey.startsWith(k.prefix));
    if (!key) {
      throw new Error("Invalid API key");
    }
    const expiry = new Date(key.expiration);
    const expiresIn = expiry.getTime() - Date.now();
    const expiresDays = Math.round(expiresIn / 1e3 / 60 / 60 / 24);
    session.set("hsApiKey", apiKey);
    session.set("user", {
      subject: "unknown-non-oauth",
      name: key.prefix,
      email: `${expiresDays.toString()} days`
    });
    return redirect("/machines", {
      headers: {
        "Set-Cookie": await commitSession(session, {
          maxAge: expiresIn
        })
      }
    });
  } catch {
    return {
      error: "Invalid API key"
    };
  }
}
const login = withComponentProps(function Page() {
  const data2 = useLoaderData();
  const actionData = useActionData();
  const showOr = useMemo(() => data2.oidc && data2.apiKey, [data2]);
  return /* @__PURE__ */ jsx("div", {
    className: "flex min-h-screen items-center justify-center",
    children: /* @__PURE__ */ jsxs(Card$1, {
      className: "max-w-sm m-4 sm:m-0",
      variant: "raised",
      children: [/* @__PURE__ */ jsx(Card$1.Title, {
        children: "Welcome to Headplane"
      }), data2.apiKey ? /* @__PURE__ */ jsxs(Form, {
        method: "post",
        children: [/* @__PURE__ */ jsxs(Card$1.Text, {
          className: "mb-8 text-sm",
          children: ["Enter an API key to authenticate with Headplane. You can generate one by running ", /* @__PURE__ */ jsx(Code, {
            children: "headscale apikeys create"
          }), " in your terminal."]
        }), (actionData == null ? void 0 : actionData.error) ? /* @__PURE__ */ jsx("p", {
          className: "text-red-500 text-sm mb-2",
          children: actionData.error
        }) : void 0, /* @__PURE__ */ jsx(TextField, {
          isRequired: true,
          label: "API Key",
          name: "api-key",
          placeholder: "API Key",
          type: "password"
        }), /* @__PURE__ */ jsx(Button$1, {
          className: "w-full mt-2.5",
          variant: "heavy",
          type: "submit",
          children: "Sign In"
        })]
      }) : void 0, showOr ? /* @__PURE__ */ jsxs("div", {
        className: "flex items-center gap-x-1.5 py-1",
        children: [/* @__PURE__ */ jsx("hr", {
          className: "flex-1 border-ui-300 dark:border-ui-800"
        }), /* @__PURE__ */ jsx("span", {
          className: "text-gray-500 text-sm",
          children: "or"
        }), /* @__PURE__ */ jsx("hr", {
          className: "flex-1 border-ui-300 dark:border-ui-800"
        })]
      }) : void 0, data2.oidc ? /* @__PURE__ */ jsxs(Form, {
        method: "POST",
        children: [/* @__PURE__ */ jsx("input", {
          type: "hidden",
          name: "oidc-start",
          value: "true"
        }), /* @__PURE__ */ jsx(Button$1, {
          className: "w-full",
          type: "submit",
          children: "Single Sign-On"
        })]
      }) : void 0]
    })
  });
});
const route3 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action: action$7,
  default: login,
  loader: loader$b
}, Symbol.toStringTag, { value: "Module" }));
async function loader$a() {
  return redirect("/machines");
}
async function action$6({
  request
}) {
  const session = await getSession(request.headers.get("Cookie"));
  return redirect("/login", {
    headers: {
      "Set-Cookie": await destroySession(session)
    }
  });
}
const route4 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action: action$6,
  loader: loader$a
}, Symbol.toStringTag, { value: "Module" }));
function send(payload, init) {
  return data(payload, init);
}
async function loader$9({
  request
}) {
  const url = new URL(request.url);
  if (url.searchParams.toString().length === 0) {
    return redirect("/machines");
  }
  const session = await getSession(request.headers.get("Cookie"));
  if (session.has("hsApiKey")) {
    return redirect("/machines");
  }
  const {
    oidc
  } = await loadContext();
  if (!oidc) {
    throw new Error("An invalid OIDC configuration was provided");
  }
  const oidcConfig = {
    issuer: oidc.issuer,
    clientId: oidc.client,
    clientSecret: oidc.secret,
    redirectUri: oidc.redirectUri,
    tokenEndpointAuthMethod: oidc.method
  };
  const codeVerifier = session.get("oidc_code_verif");
  const state = session.get("oidc_state");
  const nonce = session.get("oidc_nonce");
  const redirectUri = session.get("oidc_redirect_uri");
  if (!codeVerifier || !state || !nonce) {
    return send({
      error: "Missing OIDC state"
    }, {
      status: 400
    });
  }
  const flowRedirectUri = new URL(redirectUri);
  flowRedirectUri.search = url.search;
  const flowOptions = {
    redirect_uri: flowRedirectUri.toString(),
    codeVerifier,
    state,
    nonce: nonce === "<none>" ? void 0 : nonce
  };
  try {
    const user = await finishAuthFlow(oidcConfig, flowOptions);
    session.set("user", user);
    session.unset("oidc_code_verif");
    session.unset("oidc_state");
    session.unset("oidc_nonce");
    session.set("hsApiKey", oidc.rootKey);
    return redirect("/machines", {
      headers: {
        "Set-Cookie": await commitSession(session)
      }
    });
  } catch (error) {
    return new Response(JSON.stringify(formatError(error)), {
      status: 500,
      headers: {
        "Content-Type": "application/json"
      }
    });
  }
}
const route5 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  loader: loader$9
}, Symbol.toStringTag, { value: "Module" }));
async function loader$8({
  request
}) {
  const session = await getSession(request.headers.get("Cookie"));
  if (session.has("hsApiKey")) {
    return redirect("/machines");
  }
  const {
    oidc
  } = await loadContext();
  if (!oidc) {
    throw new Error("An invalid OIDC configuration was provided");
  }
  const oidcConfig = {
    issuer: oidc.issuer,
    clientId: oidc.client,
    clientSecret: oidc.secret,
    redirectUri: oidc.redirectUri,
    tokenEndpointAuthMethod: oidc.method
  };
  const redirectUri = oidcConfig.redirectUri ?? getRedirectUri(request);
  const data2 = await beginAuthFlow(oidcConfig, redirectUri);
  session.set("oidc_code_verif", data2.codeVerifier);
  session.set("oidc_state", data2.state);
  session.set("oidc_nonce", data2.nonce);
  session.set("oidc_redirect_uri", redirectUri);
  return redirect(data2.url, {
    status: 302,
    headers: {
      "Set-Cookie": await commitSession(session)
    }
  });
}
const route6 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  loader: loader$8
}, Symbol.toStringTag, { value: "Module" }));
function IconButton({ variant = "light", ...props }) {
  const ref = useRef(null);
  const { buttonProps } = useButton(props, ref);
  return /* @__PURE__ */ jsx(
    "button",
    {
      ref,
      ...buttonProps,
      "aria-label": props.label,
      className: cn(
        "rounded-full flex items-center justify-center p-1",
        "focus:outline-none focus:ring",
        props.isDisabled && "opacity-60 cursor-not-allowed",
        ...variant === "heavy" ? [
          "bg-headplane-900 dark:bg-headplane-50 font-semibold",
          "hover:bg-headplane-900/90 dark:hover:bg-headplane-50/90",
          "text-headplane-200 dark:text-headplane-800"
        ] : [
          "bg-headplane-100 dark:bg-headplane-700/30 font-medium",
          "hover:bg-headplane-200/90 dark:hover:bg-headplane-800/30"
        ],
        props.className
      ),
      children: props.children
    }
  );
}
function Items(props) {
  return /* @__PURE__ */ jsx(
    Popover,
    {
      className: cn(
        "mt-2 rounded-md",
        "bg-ui-50 dark:bg-ui-800",
        "overflow-hidden z-50",
        "border border-ui-200 dark:border-ui-600",
        "entering:animate-in exiting:animate-out",
        "entering:fade-in entering:zoom-in-95",
        "exiting:fade-out exiting:zoom-out-95",
        "fill-mode-forwards origin-left-right"
      ),
      children: /* @__PURE__ */ jsx(
        Menu$3,
        {
          ...props,
          className: cn(
            "outline-none",
            "divide-y divide-ui-200 dark:divide-ui-600",
            props.className
          ),
          children: props.children
        }
      )
    }
  );
}
function ItemButton(props) {
  return /* @__PURE__ */ jsx(MenuItem, { className: "outline-none", children: /* @__PURE__ */ jsx(
    Button$2,
    {
      ...props,
      className: cn(
        "px-4 py-2 w-full outline-none text-left",
        "hover:bg-ui-200 dark:hover:bg-ui-700",
        props.className
      ),
      "aria-label": "Menu Dialog",
      onPress: (event) => {
        var _a, _b;
        (_a = props.onPress) == null ? void 0 : _a.call(props, event);
        (_b = props.control) == null ? void 0 : _b[1](true);
      }
    }
  ) });
}
function Item$2(props) {
  return /* @__PURE__ */ jsx(
    MenuItem,
    {
      ...props,
      className: cn(
        "px-4 py-2 w-full outline-none",
        "hover:bg-ui-200 dark:hover:bg-ui-700",
        props.className
      )
    }
  );
}
function Menu$1({ children }) {
  return /* @__PURE__ */ jsx(MenuTrigger, { children });
}
const Menu$2 = Object.assign(Menu$1, {
  IconButton,
  Button: Button$1,
  Item: Item$2,
  ItemButton,
  Items
});
function TabLink({ name, to, icon }) {
  return /* @__PURE__ */ jsx("div", { className: "relative py-2", children: /* @__PURE__ */ jsxs(
    NavLink,
    {
      to,
      prefetch: "intent",
      className: ({ isActive }) => cn(
        "px-3 py-2 flex items-center rounded-md text-nowrap gap-x-2",
        "after:absolute after:bottom-0 after:left-3 after:right-3",
        "after:h-0.5 after:bg-headplane-900 dark:after:bg-headplane-200",
        "hover:bg-headplane-200 dark:hover:bg-headplane-900",
        isActive ? "after:visible" : "after:invisible"
      ),
      children: [
        icon,
        " ",
        name
      ]
    }
  ) });
}
function Link$1({ href, text }) {
  return /* @__PURE__ */ jsx(
    "a",
    {
      href,
      target: "_blank",
      rel: "noreferrer",
      className: "hidden sm:block hover:underline text-sm",
      children: text
    }
  );
}
function Header(data2) {
  return /* @__PURE__ */ jsxs("header", { className: cn(
    "bg-headplane-100 dark:bg-headplane-950",
    "text-headplane-800 dark:text-headplane-200",
    "dark:border-b dark:border-headplane-800",
    "shadow-inner"
  ), children: [
    /* @__PURE__ */ jsxs("div", { className: "container flex items-center justify-between py-4", children: [
      /* @__PURE__ */ jsxs("div", { className: "flex items-center gap-x-2", children: [
        /* @__PURE__ */ jsx(PlaneTakeoff, {}),
        /* @__PURE__ */ jsx("h1", { className: "text-2xl font-semibold", children: "headplane" })
      ] }),
      /* @__PURE__ */ jsxs("div", { className: "flex items-center gap-x-4", children: [
        /* @__PURE__ */ jsx(Link$1, { href: "https://tailscale.com/download", text: "Download" }),
        /* @__PURE__ */ jsx(Link$1, { href: "https://github.com/tale/headplane", text: "GitHub" }),
        /* @__PURE__ */ jsx(Link$1, { href: "https://github.com/juanfont/headscale", text: "Headscale" }),
        data2.user ? /* @__PURE__ */ jsxs(Menu$2, { children: [
          /* @__PURE__ */ jsx(Menu$2.IconButton, { className: "p-0", children: /* @__PURE__ */ jsx(CircleUser, {}) }),
          /* @__PURE__ */ jsxs(Menu$2.Items, { children: [
            /* @__PURE__ */ jsxs(Menu$2.Item, { className: "text-right", children: [
              /* @__PURE__ */ jsx("p", { className: "font-bold", children: data2.user.name }),
              /* @__PURE__ */ jsx("p", { children: data2.user.email })
            ] }),
            /* @__PURE__ */ jsx(Menu$2.Item, { className: "text-right sm:hidden", children: /* @__PURE__ */ jsx(
              Link$1,
              {
                isMenu: true,
                href: "https://tailscale.com/download",
                text: "Download"
              }
            ) }),
            /* @__PURE__ */ jsx(Menu$2.Item, { className: "text-right sm:hidden", children: /* @__PURE__ */ jsx(
              Link$1,
              {
                isMenu: true,
                href: "https://github.com/tale/headplane",
                text: "GitHub"
              }
            ) }),
            /* @__PURE__ */ jsx(Menu$2.Item, { className: "text-right sm:hidden", children: /* @__PURE__ */ jsx(
              Link$1,
              {
                isMenu: true,
                href: "https://github.com/juanfont/headscale",
                text: "Headscale"
              }
            ) }),
            /* @__PURE__ */ jsx(Menu$2.Item, { className: "text-red-500 dark:text-red-400", children: /* @__PURE__ */ jsx(Form, { method: "POST", action: "/logout", children: /* @__PURE__ */ jsx("button", { type: "submit", className: "w-full text-right", children: "Logout" }) }) })
          ] })
        ] }) : void 0
      ] })
    ] }),
    /* @__PURE__ */ jsxs("nav", { className: "container flex items-center gap-x-4 overflow-x-auto font-semibold", children: [
      /* @__PURE__ */ jsx(
        TabLink,
        {
          to: "/machines",
          name: "Machines",
          icon: /* @__PURE__ */ jsx(ServerIcon, { className: "w-4 h-4" })
        }
      ),
      /* @__PURE__ */ jsx(
        TabLink,
        {
          to: "/users",
          name: "Users",
          icon: /* @__PURE__ */ jsx(PeopleIcon, { className: "w-4 h-4" })
        }
      ),
      /* @__PURE__ */ jsx(
        TabLink,
        {
          to: "/acls",
          name: "Access Control",
          icon: /* @__PURE__ */ jsx(LockIcon, { className: "w-4 h-4" })
        }
      ),
      data2.config.read ? /* @__PURE__ */ jsxs(Fragment, { children: [
        /* @__PURE__ */ jsx(
          TabLink,
          {
            to: "/dns",
            name: "DNS",
            icon: /* @__PURE__ */ jsx(GlobeIcon, { className: "w-4 h-4" })
          }
        ),
        /* @__PURE__ */ jsx(
          TabLink,
          {
            to: "/settings",
            name: "Settings",
            icon: /* @__PURE__ */ jsx(GearIcon, { className: "w-4 h-4" })
          }
        )
      ] }) : void 0
    ] })
  ] });
}
function Link({ to, name: alt, children, className }) {
  return /* @__PURE__ */ jsxs(
    "a",
    {
      href: to,
      "aria-label": alt,
      target: "_blank",
      rel: "noreferrer",
      className: cn(
        "inline-flex items-center gap-x-1",
        "text-blue-500 hover:text-blue-700",
        "dark:text-blue-400 dark:hover:text-blue-300",
        className
      ),
      children: [
        children,
        /* @__PURE__ */ jsx(LinkExternalIcon, { className: "h-3 w-3" })
      ]
    }
  );
}
function Footer({ url, debug }) {
  return /* @__PURE__ */ jsxs(
    "footer",
    {
      className: cn(
        "fixed bottom-0 left-0 z-40 w-full h-14",
        "flex flex-col justify-center gap-1 shadow-inner",
        "bg-headplane-100 dark:bg-headplane-950",
        "text-headplane-800 dark:text-headplane-200",
        "dark:border-t dark:border-headplane-800"
      ),
      children: [
        /* @__PURE__ */ jsxs("p", { className: "container text-xs", children: [
          "Headplane is entirely free to use. If you find it useful, consider",
          " ",
          /* @__PURE__ */ jsx(
            Link,
            {
              to: "https://github.com/sponsors/tale",
              name: "Aarnav's GitHub Sponsors",
              children: "donating"
            }
          ),
          " ",
          "to support development.",
          " "
        ] }),
        /* @__PURE__ */ jsxs("p", { className: "container text-xs opacity-75", children: [
          "Version: ",
          "0.4.1-8-g2d47f1b",
          " — ",
          "Connecting to",
          " ",
          /* @__PURE__ */ jsx("strong", { className: "blur-xs hover:blur-none", children: url }),
          debug && " (Debug mode enabled)"
        ] })
      ]
    }
  );
}
async function loader$7({
  request
}) {
  const session = await getSession(request.headers.get("Cookie"));
  if (!session.has("hsApiKey")) {
    return redirect("/login");
  }
  const context2 = await loadContext();
  return {
    config: context2.config,
    url: context2.headscalePublicUrl ?? context2.headscaleUrl,
    debug: context2.debug,
    user: session.get("user")
  };
}
const shell = withComponentProps(function Shell() {
  const data2 = useLoaderData();
  return /* @__PURE__ */ jsxs(Fragment, {
    children: [/* @__PURE__ */ jsx(Header, {
      ...data2
    }), /* @__PURE__ */ jsx(Outlet, {}), /* @__PURE__ */ jsx(Footer, {
      ...data2
    })]
  });
});
const route7 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: shell,
  loader: loader$7
}, Symbol.toStringTag, { value: "Module" }));
function useLiveData({ interval }) {
  const revalidator = useRevalidator();
  useInterval(() => {
    if (revalidator.state === "idle") {
      revalidator.revalidate();
    }
  }, interval);
  useEffect(() => {
    const handler = () => {
      if (revalidator.state === "idle") {
        revalidator.revalidate();
      }
    };
    window.addEventListener("online", handler);
    document.addEventListener("focus", handler);
    return () => {
      window.removeEventListener("online", handler);
      document.removeEventListener("focus", handler);
    };
  }, [revalidator]);
  return revalidator;
}
async function loader$6({
  request
}) {
  let healthy = false;
  try {
    healthy = await healthcheck();
  } catch (error) {
    log.debug("APIC", "Healthcheck failed %o", error);
  }
  if (healthy) {
    const session = await getSession(request.headers.get("Cookie"));
    const apiKey = session.get("hsApiKey");
    try {
      await pull("v1/apikey", apiKey);
    } catch (error) {
      if (error instanceof HeadscaleError) {
        log.debug("APIC", "API Key validation failed %o", error);
        return redirect("/login", {
          headers: {
            "Set-Cookie": await destroySession(session)
          }
        });
      }
    }
  }
  return {
    healthy
  };
}
const dashboard = withComponentProps(function Layout2() {
  useLiveData({
    interval: 3e3
  });
  const {
    healthy
  } = useLoaderData();
  return /* @__PURE__ */ jsxs(Fragment, {
    children: [!healthy ? /* @__PURE__ */ jsx("div", {
      className: cn("fixed bottom-0 right-0 z-50 w-fit h-14", "flex flex-col justify-center gap-1"),
      children: /* @__PURE__ */ jsxs("div", {
        className: cn("flex items-center gap-1.5 mr-1.5 py-2 px-1.5", "border rounded-lg text-white bg-red-500", "border-red-600 dark:border-red-400 shadow-sm"),
        children: [/* @__PURE__ */ jsx(XCircleFillIcon, {
          className: "w-4 h-4 text-white"
        }), "Headscale is unreachable"]
      })
    }) : void 0, /* @__PURE__ */ jsx("main", {
      className: "container mx-auto overscroll-contain mt-4 mb-24",
      children: /* @__PURE__ */ jsx(Outlet, {})
    })]
  });
});
const route8 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: dashboard,
  loader: loader$6
}, Symbol.toStringTag, { value: "Module" }));
function initAgentSocket(context2) {
  if (!context2.ws) {
    return;
  }
  context2.ws.clients.values().next().value;
}
async function queryAgent(nodes) {
  return;
}
async function menuAction(request) {
  var _a, _b, _c, _d;
  const session = await getSession(request.headers.get("Cookie"));
  if (!session.has("hsApiKey")) {
    return send(
      { message: "Unauthorized" },
      {
        status: 401
      }
    );
  }
  const data2 = await request.formData();
  if (!data2.has("_method") || !data2.has("id")) {
    return send(
      { message: "No method or ID provided" },
      {
        status: 400
      }
    );
  }
  const id = String(data2.get("id"));
  const method = String(data2.get("_method"));
  switch (method) {
    case "delete": {
      await del(`v1/node/${id}`, session.get("hsApiKey"));
      return { message: "Machine removed" };
    }
    case "expire": {
      await post(`v1/node/${id}/expire`, session.get("hsApiKey"));
      return { message: "Machine expired" };
    }
    case "rename": {
      if (!data2.has("name")) {
        return send(
          { message: "No name provided" },
          {
            status: 400
          }
        );
      }
      const name = String(data2.get("name"));
      await post(`v1/node/${id}/rename/${name}`, session.get("hsApiKey"));
      return { message: "Machine renamed" };
    }
    case "routes": {
      if (!data2.has("route") || !data2.has("enabled")) {
        return send(
          { message: "No route or enabled provided" },
          {
            status: 400
          }
        );
      }
      const route = String(data2.get("route"));
      const enabled = data2.get("enabled") === "true";
      const postfix = enabled ? "enable" : "disable";
      await post(`v1/routes/${route}/${postfix}`, session.get("hsApiKey"));
      return { message: "Route updated" };
    }
    case "exit-node": {
      if (!data2.has("routes") || !data2.has("enabled")) {
        return send(
          { message: "No route or enabled provided" },
          {
            status: 400
          }
        );
      }
      const routes2 = ((_a = data2.get("routes")) == null ? void 0 : _a.toString().split(",")) ?? [];
      const enabled = data2.get("enabled") === "true";
      const postfix = enabled ? "enable" : "disable";
      await Promise.all(
        routes2.map(async (route) => {
          await post(`v1/routes/${route}/${postfix}`, session.get("hsApiKey"));
        })
      );
      return { message: "Exit node updated" };
    }
    case "move": {
      if (!data2.has("to")) {
        return send(
          { message: "No destination provided" },
          {
            status: 400
          }
        );
      }
      const to = String(data2.get("to"));
      try {
        await post(`v1/node/${id}/user?user=${to}`, session.get("hsApiKey"));
        return { message: `Moved node ${id} to ${to}` };
      } catch {
        return send(
          { message: `Failed to move node ${id} to ${to}` },
          {
            status: 500
          }
        );
      }
    }
    case "tags": {
      const tags = ((_b = data2.get("tags")) == null ? void 0 : _b.toString().split(",").filter((tag) => tag.trim() !== "")) ?? [];
      try {
        await post(`v1/node/${id}/tags`, session.get("hsApiKey"), {
          tags
        });
        return { message: "Tags updated" };
      } catch (error) {
        log.debug("APIC", "Failed to update tags: %s", error);
        return send(
          { message: "Failed to update tags" },
          {
            status: 500
          }
        );
      }
    }
    case "register": {
      const key = (_c = data2.get("mkey")) == null ? void 0 : _c.toString();
      const user = (_d = data2.get("user")) == null ? void 0 : _d.toString();
      if (!key) {
        return send(
          { message: "No machine key provided" },
          {
            status: 400
          }
        );
      }
      if (!user) {
        return send(
          { message: "No user provided" },
          {
            status: 400
          }
        );
      }
      try {
        const qp = new URLSearchParams();
        qp.append("user", user);
        qp.append("key", key);
        const url = `v1/node/register?${qp.toString()}`;
        await post(url, session.get("hsApiKey"), {
          user,
          key
        });
        return {
          success: true,
          message: "Machine registered"
        };
      } catch {
        return send(
          {
            success: false,
            message: "Failed to register machine"
          },
          {
            status: 500
          }
        );
      }
    }
    default: {
      return send(
        { message: "Invalid method" },
        {
          status: 400
        }
      );
    }
  }
}
function StatusCircle({ isOnline, className }) {
  return /* @__PURE__ */ jsx(
    "svg",
    {
      className: clsx$1(
        className,
        isOnline ? "text-green-700 dark:text-green-400" : "text-gray-300 dark:text-gray-500"
      ),
      viewBox: "0 0 24 24",
      fill: "currentColor",
      children: /* @__PURE__ */ jsx("circle", { cx: "12", cy: "12", r: "8" })
    }
  );
}
function Action(props) {
  return /* @__PURE__ */ jsx(
    Button$1,
    {
      ...props,
      type: props.variant === "confirm" ? "submit" : "button",
      variant: props.variant === "cancel" ? "light" : "heavy"
    }
  );
}
function Gutter({ children }) {
  return /* @__PURE__ */ jsx("div", { className: "mt-6 flex justify-end gap-4 mt-6", children });
}
function Panel({ children, control, className }) {
  return /* @__PURE__ */ jsx(
    ModalOverlay,
    {
      "aria-hidden": "true",
      className: cn(
        "fixed inset-0 h-screen w-screen z-50",
        "flex items-center justify-center",
        "bg-headplane-900/15 dark:bg-headplane-900/30",
        "entering:animate-in exiting:animate-out",
        "entering:fade-in entering:duration-100 entering:ease-out",
        "exiting:fade-out exiting:duration-50 exiting:ease-in",
        className
      ),
      isOpen: control ? control[0] : void 0,
      onOpenChange: control ? control[1] : void 0,
      children: /* @__PURE__ */ jsx(Modal$2, { className: cn(
        "bg-white dark:bg-headplane-900 rounded-3xl w-full max-w-lg",
        "entering:animate-in exiting:animate-out",
        "entering:zoom-in-95 entering:ease-out entering:duration-100",
        "exiting:zoom-out-95 exiting:ease-in exiting:duration-50"
      ), children: /* @__PURE__ */ jsx(Card$1, { variant: "flat", className: "w-full max-w-lg", children: /* @__PURE__ */ jsx(Dialog$2, { role: "alertdialog", className: "outline-none", children: ({ close }) => children(close) }) }) })
    }
  );
}
function Dialog({ children, control }) {
  if (control) {
    return children;
  }
  return /* @__PURE__ */ jsx(DialogTrigger, { children });
}
const Dialog$1 = Object.assign(Dialog, {
  Action,
  Button: Button$1,
  Gutter,
  Panel,
  Title,
  Text
});
function Delete({ machine: machine2, state }) {
  const submit = useSubmit();
  return /* @__PURE__ */ jsx(Dialog$1, { children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: state, children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
      "Remove ",
      machine2.givenName
    ] }),
    /* @__PURE__ */ jsx(Dialog$1.Text, { children: "This machine will be permanently removed from your network. To re-add it, you will need to reauthenticate to your tailnet from the device." }),
    /* @__PURE__ */ jsxs(
      Form,
      {
        method: "POST",
        onSubmit: (e) => {
          submit(e.currentTarget);
        },
        children: [
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "delete" }),
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "id", value: machine2.id }),
          /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
            /* @__PURE__ */ jsx(
              Dialog$1.Action,
              {
                variant: "confirm",
                className: cn(
                  "bg-red-500 hover:border-red-700",
                  "dark:bg-red-600 dark:hover:border-red-700",
                  "pressed:bg-red-600 hover:bg-red-600",
                  "text-white dark:text-white"
                ),
                onPress: close,
                children: "Remove"
              }
            )
          ] })
        ]
      }
    )
  ] }) }) });
}
function Expire({ machine: machine2, state }) {
  const submit = useSubmit();
  return /* @__PURE__ */ jsx(Dialog$1, { children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: state, children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
      "Expire ",
      machine2.givenName
    ] }),
    /* @__PURE__ */ jsx(Dialog$1.Text, { children: "This will disconnect the machine from your Tailnet. In order to reconnect, you will need to re-authenticate from the device." }),
    /* @__PURE__ */ jsxs(
      Form,
      {
        method: "POST",
        onSubmit: (e) => {
          submit(e.currentTarget);
        },
        children: [
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "expire" }),
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "id", value: machine2.id }),
          /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
            /* @__PURE__ */ jsx(
              Dialog$1.Action,
              {
                variant: "confirm",
                className: cn(
                  "bg-red-500 hover:border-red-700",
                  "dark:bg-red-600 dark:hover:border-red-700",
                  "pressed:bg-red-600 hover:bg-red-600",
                  "text-white dark:text-white"
                ),
                onPress: close,
                children: "Expire"
              }
            )
          ] })
        ]
      }
    )
  ] }) }) });
}
function Select(props) {
  var _a;
  return /* @__PURE__ */ jsxs(
    Select$2,
    {
      ...props,
      "aria-label": props.label,
      selectedKey: (_a = props.state) == null ? void 0 : _a[0],
      onSelectionChange: (key) => {
        var _a2;
        (_a2 = props.state) == null ? void 0 : _a2[1](key.toString());
      },
      className: cn(
        "block w-full rounded-lg my-1",
        "border border-ui-200 dark:border-ui-600",
        "bg-white dark:bg-ui-800 dark:text-ui-300",
        "focus-within:outline-6",
        props.className
      ),
      children: [
        /* @__PURE__ */ jsxs(
          Button$2,
          {
            className: cn(
              "w-full flex items-center justify-between",
              "px-2.5 py-1.5 rounded-lg"
            ),
            children: [
              /* @__PURE__ */ jsx(SelectValue, {}),
              /* @__PURE__ */ jsx(ChevronDownIcon, { className: "w-4 h-4", "aria-hidden": "true" })
            ]
          }
        ),
        /* @__PURE__ */ jsx(
          Popover,
          {
            className: cn(
              "mt-2 rounded-md w-[var(--trigger-width)]",
              "bg-ui-100 dark:bg-ui-800 shadow-sm",
              "z-50 overflow-y-auto",
              "border border-ui-200 dark:border-ui-600",
              "entering:animate-in exiting:animate-out",
              "entering:fade-in entering:zoom-in-95",
              "exiting:fade-out exiting:zoom-out-95",
              "fill-mode-forwards origin-left-right"
            ),
            children: /* @__PURE__ */ jsx(ListBox, { orientation: "vertical", children: props.children })
          }
        )
      ]
    }
  );
}
function Item$1(props) {
  return /* @__PURE__ */ jsx(
    ListBoxItem,
    {
      ...props,
      className: cn(
        "px-4 py-2 w-full outline-none w-full",
        "hover:bg-ui-200 dark:hover:bg-ui-700",
        props.className
      ),
      children: props.children
    }
  );
}
const Select$1 = Object.assign(Select, { Item: Item$1 });
function Move({ machine: machine2, state, magic, users }) {
  const [owner, setOwner] = useState(machine2.user.name);
  const submit = useSubmit();
  return /* @__PURE__ */ jsx(Dialog$1, { children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: state, children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
      "Change the owner of ",
      machine2.givenName
    ] }),
    /* @__PURE__ */ jsx(Dialog$1.Text, { children: "The owner of the machine is the user associated with it." }),
    /* @__PURE__ */ jsxs(
      Form,
      {
        method: "POST",
        onSubmit: (e) => {
          submit(e.currentTarget);
        },
        children: [
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "move" }),
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "id", value: machine2.id }),
          /* @__PURE__ */ jsx(
            Select$1,
            {
              label: "Owner",
              name: "to",
              placeholder: "Select a user",
              state: [owner, setOwner],
              children: users.map((user) => /* @__PURE__ */ jsx(Select$1.Item, { id: user.name, children: user.name }, user.id))
            }
          ),
          magic ? /* @__PURE__ */ jsxs("p", { className: "text-sm text-gray-500 dark:text-gray-300 leading-tight", children: [
            "This machine is accessible by the hostname",
            " ",
            /* @__PURE__ */ jsxs(Code, { className: "text-sm", children: [
              machine2.givenName,
              ".",
              magic
            ] }),
            "."
          ] }) : void 0,
          /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "confirm", onPress: close, children: "Change owner" })
          ] })
        ]
      }
    )
  ] }) }) });
}
function Rename$1({ machine: machine2, state, magic }) {
  const [name, setName] = useState(machine2.givenName);
  const submit = useSubmit();
  return /* @__PURE__ */ jsx(Dialog$1, { children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: state, children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
      "Edit machine name for ",
      machine2.givenName
    ] }),
    /* @__PURE__ */ jsx(Dialog$1.Text, { children: "This name is shown in the admin panel, in Tailscale clients, and used when generating MagicDNS names." }),
    /* @__PURE__ */ jsxs(
      Form,
      {
        method: "POST",
        onSubmit: (e) => {
          submit(e.currentTarget);
        },
        children: [
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "rename" }),
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "id", value: machine2.id }),
          /* @__PURE__ */ jsx(
            TextField,
            {
              label: "Machine name",
              placeholder: "Machine name",
              name: "name",
              state: [name, setName],
              className: "my-2"
            }
          ),
          magic ? name.length > 0 && name !== machine2.givenName ? /* @__PURE__ */ jsxs("p", { className: "text-sm text-gray-500 dark:text-gray-300 leading-tight", children: [
            "This machine will be accessible by the hostname",
            " ",
            /* @__PURE__ */ jsx(Code, { className: "text-sm", children: name.toLowerCase().replaceAll(/\s+/g, "-") }),
            ". ",
            "The hostname",
            " ",
            /* @__PURE__ */ jsx(Code, { className: "text-sm", children: machine2.givenName }),
            " will no longer point to this machine."
          ] }) : /* @__PURE__ */ jsxs("p", { className: "text-sm text-gray-500 dark:text-gray-300 leading-tight", children: [
            "This machine is accessible by the hostname",
            " ",
            /* @__PURE__ */ jsx(Code, { className: "text-sm", children: machine2.givenName }),
            "."
          ] }) : void 0,
          /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "confirm", onPress: close, children: "Rename" })
          ] })
        ]
      }
    )
  ] }) }) });
}
function Switch(props) {
  return /* @__PURE__ */ jsx(
    Switch$1,
    {
      ...props,
      "aria-label": props.label,
      className: "group flex gap-2 items-center",
      children: /* @__PURE__ */ jsx(
        "div",
        {
          className: cn(
            "flex h-[26px] w-[44px] p-[4px] shrink-0",
            "rounded-full outline-none group-focus-visible:ring-2",
            "bg-main-600/50 dark:bg-main-600/20 group-selected:bg-main-700",
            props.isDisabled && "opacity-50 cursor-not-allowed",
            props.className
          ),
          children: /* @__PURE__ */ jsx(
            "span",
            {
              className: cn(
                "h-[18px] w-[18px] transform rounded-full",
                "bg-white transition duration-100 ease-in-out",
                "translate-x-0 group-selected:translate-x-[100%]"
              )
            }
          )
        }
      )
    }
  );
}
function Routes({ machine: machine2, routes: routes2, state }) {
  const fetcher = useFetcher();
  const { exit, subnet } = routes2.reduce(
    (acc, route) => {
      if (route.prefix === "::/0" || route.prefix === "0.0.0.0/0") {
        acc.exit.push(route);
        return acc;
      }
      acc.subnet.push(route);
      return acc;
    },
    { exit: [], subnet: [] }
  );
  const exitEnabled = useMemo(() => {
    if (exit.length !== 2) return false;
    return exit[0].enabled && exit[1].enabled;
  }, [exit]);
  return /* @__PURE__ */ jsx(Dialog$1, { children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: state, children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
      "Edit route settings of ",
      machine2.givenName
    ] }),
    /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-bold", children: "Subnet routes" }),
    /* @__PURE__ */ jsxs(Dialog$1.Text, { children: [
      "Connect to devices you can't install Tailscale on by advertising IP ranges as subnet routes.",
      " ",
      /* @__PURE__ */ jsx(
        Link,
        {
          to: "https://tailscale.com/kb/1019/subnets",
          name: "Tailscale Subnets Documentation",
          children: "Learn More"
        }
      )
    ] }),
    /* @__PURE__ */ jsxs(
      "div",
      {
        className: cn(
          "rounded-lg overflow-y-auto my-2",
          "divide-y divide-zinc-200 dark:divide-zinc-700 align-top",
          "border border-zinc-200 dark:border-zinc-700"
        ),
        children: [
          subnet.length === 0 ? /* @__PURE__ */ jsx(
            "div",
            {
              className: cn(
                "flex py-4 px-4 bg-ui-100 dark:bg-ui-800",
                "items-center justify-center",
                "text-ui-600 dark:text-ui-300"
              ),
              children: /* @__PURE__ */ jsx("p", { children: "No routes are advertised on this machine." })
            }
          ) : void 0,
          subnet.map((route) => /* @__PURE__ */ jsxs(
            "div",
            {
              className: cn(
                "flex py-2 px-4 bg-ui-100 dark:bg-ui-800",
                "items-center justify-between"
              ),
              children: [
                /* @__PURE__ */ jsx("p", { children: route.prefix }),
                /* @__PURE__ */ jsx(
                  Switch,
                  {
                    defaultSelected: route.enabled,
                    label: "Enabled",
                    onChange: (checked) => {
                      const form = new FormData();
                      form.set("id", machine2.id);
                      form.set("_method", "routes");
                      form.set("route", route.id);
                      form.set("enabled", String(checked));
                      fetcher.submit(form, {
                        method: "POST"
                      });
                    }
                  }
                )
              ]
            },
            route.id
          ))
        ]
      }
    ),
    /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-bold mt-8", children: "Exit nodes" }),
    /* @__PURE__ */ jsxs(Dialog$1.Text, { children: [
      "Allow your network to route internet traffic through this machine.",
      " ",
      /* @__PURE__ */ jsx(
        Link,
        {
          to: "https://tailscale.com/kb/1103/exit-nodes",
          name: "Tailscale Exit-node Documentation",
          children: "Learn More"
        }
      )
    ] }),
    /* @__PURE__ */ jsx(
      "div",
      {
        className: cn(
          "rounded-lg overflow-y-auto my-2",
          "divide-y divide-zinc-200 dark:divide-zinc-700 align-top",
          "border border-zinc-200 dark:border-zinc-700"
        ),
        children: exit.length === 0 ? /* @__PURE__ */ jsx(
          "div",
          {
            className: cn(
              "flex py-4 px-4 bg-ui-100 dark:bg-ui-800",
              "items-center justify-center",
              "text-ui-600 dark:text-ui-300"
            ),
            children: /* @__PURE__ */ jsx("p", { children: "This machine is not an exit node." })
          }
        ) : /* @__PURE__ */ jsxs(
          "div",
          {
            className: cn(
              "flex py-2 px-4 bg-ui-100 dark:bg-ui-800",
              "items-center justify-between"
            ),
            children: [
              /* @__PURE__ */ jsx("p", { children: "Use as exit node" }),
              /* @__PURE__ */ jsx(
                Switch,
                {
                  defaultSelected: exitEnabled,
                  label: "Enabled",
                  onChange: (checked) => {
                    const form = new FormData();
                    form.set("id", machine2.id);
                    form.set("_method", "exit-node");
                    form.set(
                      "routes",
                      exit.map((route) => route.id).join(",")
                    );
                    form.set("enabled", String(checked));
                    fetcher.submit(form, {
                      method: "POST"
                    });
                  }
                }
              )
            ]
          }
        )
      }
    ),
    /* @__PURE__ */ jsx(Dialog$1.Gutter, { children: /* @__PURE__ */ jsx(
      Dialog$1.Action,
      {
        variant: "cancel",
        isDisabled: fetcher.state === "submitting",
        onPress: close,
        children: "Close"
      }
    ) })
  ] }) }) });
}
function Tags({ machine: machine2, state }) {
  const [tags, setTags] = useState(machine2.forcedTags);
  const [tag, setTag] = useState("");
  const submit = useSubmit();
  return /* @__PURE__ */ jsx(Dialog$1, { children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: state, children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
      "Edit ACL tags for ",
      machine2.givenName
    ] }),
    /* @__PURE__ */ jsxs(Dialog$1.Text, { children: [
      "ACL tags can be used to reference machines in your ACL policies. See the",
      " ",
      /* @__PURE__ */ jsx(
        Link,
        {
          to: "https://tailscale.com/kb/1068/acl-tags",
          name: "Tailscale documentation",
          children: "Tailscale documentation"
        }
      ),
      " ",
      "for more information."
    ] }),
    /* @__PURE__ */ jsxs(
      Form,
      {
        method: "POST",
        onSubmit: (e) => {
          submit(e.currentTarget);
        },
        children: [
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "tags" }),
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "id", value: machine2.id }),
          /* @__PURE__ */ jsx("input", { type: "hidden", name: "tags", value: tags.join(",") }),
          /* @__PURE__ */ jsxs(
            "div",
            {
              className: cn(
                "border border-ui-300 rounded-lg overflow-visible",
                "dark:border-ui-700 dark:text-ui-300 mt-4"
              ),
              children: [
                /* @__PURE__ */ jsx("div", { className: "divide-y divide-ui-200 dark:divide-ui-600", children: tags.length === 0 ? /* @__PURE__ */ jsx(
                  "div",
                  {
                    className: cn(
                      "flex py-4 px-4 bg-ui-100 dark:bg-ui-800",
                      "items-center justify-center rounded-t-lg",
                      "text-ui-600 dark:text-ui-300"
                    ),
                    children: /* @__PURE__ */ jsx("p", { children: "No tags are set on this machine." })
                  }
                ) : tags.map((item) => /* @__PURE__ */ jsxs(
                  "div",
                  {
                    id: item,
                    className: cn(
                      "px-2.5 py-1.5 flex",
                      "items-center justify-between",
                      "font-mono text-sm"
                    ),
                    children: [
                      item,
                      /* @__PURE__ */ jsx(
                        Button$2,
                        {
                          className: "rounded-full p-0 w-6 h-6",
                          onPress: () => {
                            setTags(tags.filter((tag2) => tag2 !== item));
                          },
                          children: /* @__PURE__ */ jsx(XIcon, { className: "w-4 h-4" })
                        }
                      )
                    ]
                  },
                  item
                )) }),
                /* @__PURE__ */ jsxs(
                  "div",
                  {
                    className: cn(
                      "flex px-2.5 py-1.5 w-full",
                      "border-t border-ui-300 dark:border-ui-700",
                      "rounded-b-lg justify-between items-center",
                      "dark:bg-ui-800 dark:text-ui-300",
                      "focus-within:ring-2 focus-within:ring-blue-600",
                      tag.length > 0 && !tag.startsWith("tag:") && "outline outline-red-500"
                    ),
                    children: [
                      /* @__PURE__ */ jsx(
                        Input,
                        {
                          placeholder: "tag:example",
                          className: cn(
                            "bg-transparent w-full",
                            "border-none focus:ring-0",
                            "focus:outline-none font-mono text-sm",
                            "dark:bg-transparent dark:text-ui-300"
                          ),
                          value: tag,
                          onChange: (e) => {
                            setTag(e.currentTarget.value);
                          }
                        }
                      ),
                      /* @__PURE__ */ jsx(
                        Button$2,
                        {
                          className: cn(
                            "rounded-lg p-0 h-6 w-6",
                            !tag.startsWith("tag:") && "opacity-50 cursor-not-allowed"
                          ),
                          isDisabled: tag.length === 0 || !tag.startsWith("tag:") || tags.includes(tag),
                          onPress: () => {
                            setTags([...tags, tag]);
                            setTag("");
                          },
                          children: /* @__PURE__ */ jsx(PlusIcon, { className: "w-4 h-4" })
                        }
                      )
                    ]
                  }
                )
              ]
            }
          ),
          /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
            /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "confirm", onPress: close, children: "Save" })
          ] })
        ]
      }
    )
  ] }) }) });
}
function Menu({
  machine: machine2,
  routes: routes2,
  magic,
  users,
  buttonChild
}) {
  const renameState = useState(false);
  const expireState = useState(false);
  const removeState = useState(false);
  const routesState = useState(false);
  const moveState = useState(false);
  const tagsState = useState(false);
  const expired = machine2.expiry === "0001-01-01 00:00:00" || machine2.expiry === "0001-01-01T00:00:00Z" || machine2.expiry === null ? false : new Date(machine2.expiry).getTime() < Date.now();
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(Rename$1, { machine: machine2, state: renameState, magic }),
    /* @__PURE__ */ jsx(Delete, { machine: machine2, state: removeState }),
    expired ? void 0 : /* @__PURE__ */ jsx(Expire, { machine: machine2, state: expireState }),
    /* @__PURE__ */ jsx(Routes, { machine: machine2, routes: routes2, state: routesState }),
    /* @__PURE__ */ jsx(Tags, { machine: machine2, state: tagsState }),
    /* @__PURE__ */ jsx(Move, { machine: machine2, state: moveState, users, magic }),
    /* @__PURE__ */ jsxs(Menu$2, { children: [
      buttonChild ?? /* @__PURE__ */ jsx(
        Menu$2.Button,
        {
          className: cn(
            "flex items-center justify-center",
            "border border-transparent rounded-lg py-0.5 w-10",
            "group-hover:border-gray-200 dark:group-hover:border-zinc-700"
          ),
          children: /* @__PURE__ */ jsx(KebabHorizontalIcon, { className: "w-5" })
        }
      ),
      /* @__PURE__ */ jsxs(Menu$2.Items, { children: [
        /* @__PURE__ */ jsx(Menu$2.ItemButton, { control: renameState, children: "Edit machine name" }),
        /* @__PURE__ */ jsx(Menu$2.ItemButton, { control: routesState, children: "Edit route settings" }),
        /* @__PURE__ */ jsx(Menu$2.ItemButton, { control: tagsState, children: "Edit ACL tags" }),
        /* @__PURE__ */ jsx(Menu$2.ItemButton, { control: moveState, children: "Change owner" }),
        expired ? void 0 : /* @__PURE__ */ jsx(Menu$2.ItemButton, { control: expireState, children: "Expire" }),
        /* @__PURE__ */ jsx(
          Menu$2.ItemButton,
          {
            className: "text-red-500 dark:text-red-400",
            control: removeState,
            children: "Remove"
          }
        )
      ] })
    ] })
  ] });
}
function MachineRow({ machine: machine2, routes: routes2, magic, users, stats }) {
  const expired = machine2.expiry === "0001-01-01 00:00:00" || machine2.expiry === "0001-01-01T00:00:00Z" || machine2.expiry === null ? false : new Date(machine2.expiry).getTime() < Date.now();
  const tags = [...machine2.forcedTags, ...machine2.validTags];
  if (expired) {
    tags.unshift("Expired");
  }
  const prefix = (magic == null ? void 0 : magic.startsWith("[user]")) ? magic.replace("[user]", machine2.user.name) : magic;
  const { exit, subnet, subnetApproved } = routes2.reduce(
    (acc, route) => {
      if (route.prefix === "::/0" || route.prefix === "0.0.0.0/0") {
        acc.exit.push(route);
        return acc;
      }
      if (route.enabled) {
        acc.subnetApproved.push(route);
        return acc;
      }
      acc.subnet.push(route);
      return acc;
    },
    { exit: [], subnetApproved: [], subnet: [] }
  );
  const exitEnabled = useMemo(() => {
    if (exit.length !== 2) return false;
    return exit[0].enabled && exit[1].enabled;
  }, [exit]);
  if (exitEnabled) {
    tags.unshift("Exit Node");
  }
  if (subnetApproved.length > 0) {
    tags.unshift("Subnets");
  }
  return /* @__PURE__ */ jsxs(
    "tr",
    {
      className: "hover:bg-zinc-100 dark:hover:bg-zinc-800 group",
      children: [
        /* @__PURE__ */ jsx("td", { className: "pl-0.5 py-2", children: /* @__PURE__ */ jsxs(Link$2, { to: `/machines/${machine2.id}`, className: "group/link h-full", children: [
          /* @__PURE__ */ jsx(
            "p",
            {
              className: cn(
                "font-semibold leading-snug",
                "group-hover/link:text-blue-600",
                "group-hover/link:dark:text-blue-400"
              ),
              children: machine2.givenName
            }
          ),
          /* @__PURE__ */ jsx("p", { className: "text-sm text-gray-500 dark:text-gray-300 font-mono", children: machine2.name }),
          /* @__PURE__ */ jsx("div", { className: "flex gap-1 mt-1", children: tags.map((tag) => /* @__PURE__ */ jsx(
            "span",
            {
              className: cn(
                "text-xs rounded-md px-1.5 py-0.5",
                "bg-ui-200 dark:bg-ui-800",
                "text-ui-600 dark:text-ui-300"
              ),
              children: tag
            },
            tag
          )) })
        ] }) }),
        /* @__PURE__ */ jsx("td", { className: "py-2", children: /* @__PURE__ */ jsxs("div", { className: "flex items-center gap-x-1", children: [
          machine2.ipAddresses[0],
          /* @__PURE__ */ jsxs(Menu$2, { children: [
            /* @__PURE__ */ jsx(
              Menu$2.IconButton,
              {
                className: "bg-transparent",
                label: "IP Addresses",
                children: /* @__PURE__ */ jsx(ChevronDownIcon, { className: "w-4 h-4" })
              }
            ),
            /* @__PURE__ */ jsxs(Menu$2.Items, { children: [
              machine2.ipAddresses.map((ip) => /* @__PURE__ */ jsxs(
                Menu$2.ItemButton,
                {
                  type: "button",
                  className: cn(
                    "flex items-center gap-x-1.5 text-sm",
                    "justify-between w-full"
                  ),
                  onPress: async () => {
                    await navigator.clipboard.writeText(ip);
                    toast("Copied IP address to clipboard");
                  },
                  children: [
                    ip,
                    /* @__PURE__ */ jsx(CopyIcon, { className: "w-3 h-3" })
                  ]
                },
                ip
              )),
              magic ? /* @__PURE__ */ jsxs(
                Menu$2.ItemButton,
                {
                  type: "button",
                  className: cn(
                    "flex items-center gap-x-1.5 text-sm",
                    "justify-between w-full break-keep"
                  ),
                  onPress: async () => {
                    const ip = `${machine2.givenName}.${prefix}`;
                    await navigator.clipboard.writeText(ip);
                    toast("Copied hostname to clipboard");
                  },
                  children: [
                    machine2.givenName,
                    ".",
                    prefix,
                    /* @__PURE__ */ jsx(CopyIcon, { className: "w-3 h-3" })
                  ]
                }
              ) : void 0
            ] })
          ] })
        ] }) }),
        /* @__PURE__ */ jsx("td", { className: "py-2", children: /* @__PURE__ */ jsxs(
          "span",
          {
            className: cn(
              "flex items-center gap-x-1 text-sm",
              "text-gray-500 dark:text-gray-400"
            ),
            children: [
              /* @__PURE__ */ jsx(
                StatusCircle,
                {
                  isOnline: machine2.online && !expired,
                  className: "w-4 h-4"
                }
              ),
              /* @__PURE__ */ jsx("p", { children: machine2.online && !expired ? "Connected" : new Date(machine2.lastSeen).toLocaleString() })
            ]
          }
        ) }),
        /* @__PURE__ */ jsx("td", { className: "py-2 pr-0.5", children: /* @__PURE__ */ jsx(
          Menu,
          {
            machine: machine2,
            routes: routes2,
            users,
            magic
          }
        ) })
      ]
    },
    machine2.id
  );
}
function Spinner({ className }) {
  return /* @__PURE__ */ jsx("div", { className: clsx$1("mr-1.5 inline-block align-middle mb-0.5", className), children: /* @__PURE__ */ jsx(
    "div",
    {
      className: clsx$1(
        "animate-spin rounded-full w-full h-full",
        "border-2 border-current border-t-transparent",
        className
      ),
      role: "status",
      children: /* @__PURE__ */ jsx("span", { className: "sr-only", children: "Loading..." })
    }
  ) });
}
function New(data2) {
  const fetcher = useFetcher();
  const mkeyState = useState(false);
  const [mkey, setMkey] = useState("");
  const [user, setUser] = useState("");
  const [toasted, setToasted] = useState(false);
  useEffect(() => {
    if (!fetcher.data || toasted) {
      return;
    }
    if (fetcher.data.success) {
      toast("Registered new machine");
    } else {
      toast("Failed to register machine due to an invalid key");
    }
    setToasted(true);
  }, [fetcher.data, toasted, mkey]);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(Dialog$1, { children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: mkeyState, children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsx(Dialog$1.Title, { children: "Register Machine Key" }),
      /* @__PURE__ */ jsxs(Dialog$1.Text, { className: "mb-4", children: [
        "The machine key is given when you run",
        " ",
        /* @__PURE__ */ jsxs(Code, { isCopyable: true, children: [
          "tailscale up --login-server=",
          data2.server
        ] }),
        " ",
        "on your device."
      ] }),
      /* @__PURE__ */ jsxs(
        fetcher.Form,
        {
          method: "POST",
          onSubmit: (e) => {
            fetcher.submit(e.currentTarget);
            close();
          },
          children: [
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "register" }),
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "id", value: "_" }),
            /* @__PURE__ */ jsx(
              TextField,
              {
                label: "Machine Key",
                placeholder: "mkey:ff.....",
                name: "mkey",
                state: [mkey, setMkey],
                className: "my-2 font-mono"
              }
            ),
            /* @__PURE__ */ jsx(
              Select$1,
              {
                label: "Owner",
                name: "user",
                placeholder: "Select a user",
                state: [user, setUser],
                children: data2.users.map((user2) => /* @__PURE__ */ jsx(Select$1.Item, { id: user2.name, children: user2.name }, user2.id))
              }
            ),
            /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsxs(
                Dialog$1.Action,
                {
                  variant: "confirm",
                  isDisabled: !mkey || !mkey.trim().startsWith("mkey:") || !user,
                  children: [
                    fetcher.state === "idle" ? void 0 : /* @__PURE__ */ jsx(Spinner, { className: "w-3 h-3" }),
                    "Register"
                  ]
                }
              )
            ] })
          ]
        }
      )
    ] }) }) }),
    /* @__PURE__ */ jsxs(Menu$2, { children: [
      /* @__PURE__ */ jsx(Menu$2.Button, { variant: "heavy", children: "Add Device" }),
      /* @__PURE__ */ jsxs(Menu$2.Items, { children: [
        /* @__PURE__ */ jsxs(Menu$2.ItemButton, { control: mkeyState, children: [
          /* @__PURE__ */ jsx(ServerIcon, { className: "w-4 h-4 mr-2" }),
          "Register Machine Key"
        ] }),
        /* @__PURE__ */ jsx(Menu$2.ItemButton, { children: /* @__PURE__ */ jsxs(Link$2, { to: "/settings/auth-keys", children: [
          /* @__PURE__ */ jsx(KeyIcon, { className: "w-4 h-4 mr-2" }),
          "Generate Pre-auth Key"
        ] }) })
      ] })
    ] })
  ] });
}
async function loader$5({
  request,
  context: lC
}) {
  const session = await getSession(request.headers.get("Cookie"));
  const [machines, routes2, users] = await Promise.all([pull("v1/node", session.get("hsApiKey")), pull("v1/routes", session.get("hsApiKey")), pull("v1/user", session.get("hsApiKey"))]);
  initAgentSocket(lC);
  const stats = await queryAgent(machines.nodes.map((node) => node.nodeKey));
  const context2 = await loadContext();
  let magic;
  if (context2.config.read) {
    const config2 = await loadConfig();
    if (config2.dns.magic_dns) {
      magic = config2.dns.base_domain;
    }
  }
  return {
    nodes: machines.nodes,
    routes: routes2.routes,
    users: users.users,
    magic,
    stats,
    server: context2.headscaleUrl,
    publicServer: context2.headscalePublicUrl
  };
}
async function action$5({
  request
}) {
  return menuAction(request);
}
const overview$3 = withComponentProps(function Page2() {
  useLiveData({
    interval: 3e3
  });
  const data2 = useLoaderData();
  return /* @__PURE__ */ jsxs(Fragment, {
    children: [/* @__PURE__ */ jsxs("div", {
      className: "flex justify-between items-center mb-8",
      children: [/* @__PURE__ */ jsxs("div", {
        className: "flex flex-col w-2/3",
        children: [/* @__PURE__ */ jsx("h1", {
          className: "text-2xl font-medium mb-4",
          children: "Machines"
        }), /* @__PURE__ */ jsxs("p", {
          className: "text-gray-700 dark:text-gray-300",
          children: ["Manage the devices connected to your Tailnet.", " ", /* @__PURE__ */ jsx(Link, {
            to: "https://tailscale.com/kb/1372/manage-devices",
            name: "Tailscale Manage Devices Documentation",
            children: "Learn more"
          })]
        })]
      }), /* @__PURE__ */ jsx(New, {
        server: data2.publicServer ?? data2.server,
        users: data2.users
      })]
    }), /* @__PURE__ */ jsxs("table", {
      className: "table-auto w-full rounded-lg",
      children: [/* @__PURE__ */ jsx("thead", {
        className: "text-gray-500 dark:text-gray-400",
        children: /* @__PURE__ */ jsxs("tr", {
          className: "text-left uppercase text-xs font-bold px-0.5",
          children: [/* @__PURE__ */ jsx("th", {
            className: "pb-2",
            children: "Name"
          }), /* @__PURE__ */ jsx("th", {
            className: "pb-2 w-1/4",
            children: /* @__PURE__ */ jsxs("div", {
              className: "flex items-center gap-x-1",
              children: ["Addresses", data2.magic ? /* @__PURE__ */ jsxs(TooltipTrigger, {
                delay: 0,
                children: [/* @__PURE__ */ jsx(Button$2, {
                  children: /* @__PURE__ */ jsx(InfoIcon, {
                    className: "w-4 h-4"
                  })
                }), /* @__PURE__ */ jsxs(Tooltip$2, {
                  className: cn("text-sm max-w-xs p-2 rounded-lg mb-2", "bg-white dark:bg-zinc-800", "border border-gray-200 dark:border-zinc-700"),
                  children: ["Since MagicDNS is enabled, you can access devices based on their name and also at", " ", /* @__PURE__ */ jsxs(Code, {
                    children: ["[name].", data2.magic]
                  })]
                })]
              }) : void 0]
            })
          }), /* @__PURE__ */ jsx("th", {
            className: "pb-2",
            children: "Last Seen"
          })]
        })
      }), /* @__PURE__ */ jsx("tbody", {
        className: cn("divide-y divide-zinc-200 dark:divide-zinc-700 align-top", "border-t border-zinc-200 dark:border-zinc-700"),
        children: data2.nodes.map((machine2) => {
          var _a;
          return /* @__PURE__ */ jsx(MachineRow, {
            machine: machine2,
            routes: data2.routes.filter((route) => route.node.id === machine2.id),
            users: data2.users,
            magic: data2.magic,
            stats: (_a = data2.stats) == null ? void 0 : _a[machine2.nodeKey]
          }, machine2.id);
        })
      })]
    })]
  });
});
const ErrorBoundary$1 = withErrorBoundaryProps(function ErrorBoundary2() {
  return /* @__PURE__ */ jsx(ErrorPopup, {
    type: "embedded"
  });
});
const route9 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  ErrorBoundary: ErrorBoundary$1,
  action: action$5,
  default: overview$3,
  loader: loader$5
}, Symbol.toStringTag, { value: "Module" }));
function Attribute({ name, value, link, isCopyable }) {
  const canCopy = isCopyable ?? false;
  return /* @__PURE__ */ jsxs("dl", { className: "flex gap-1 text-sm w-full", children: [
    /* @__PURE__ */ jsx("dt", { className: "w-1/2 shrink-0 min-w-0 truncate text-gray-700 dark:text-gray-300 py-1", children: link ? /* @__PURE__ */ jsx("a", { className: "hover:underline", href: link, children: name }) : name }),
    canCopy ? /* @__PURE__ */ jsxs(
      "button",
      {
        type: "button",
        className: "focus:outline-none flex items-center gap-x-1 truncate hover:bg-zinc-100 dark:hover:bg-zinc-800 rounded-md",
        onClick: async () => {
          await navigator.clipboard.writeText(value);
          toast(`Copied ${name}`);
        },
        children: [
          /* @__PURE__ */ jsx("dd", { className: "min-w-0 truncate px-2 py-1", children: value }),
          /* @__PURE__ */ jsx(CopyIcon, { className: "text-gray-600 dark:text-gray-200 pr-2 w-max h-3" })
        ]
      }
    ) : /* @__PURE__ */ jsx("dd", { className: "min-w-0 truncate px-2 py-1", children: value })
  ] });
}
function Tooltip({ children }) {
  return /* @__PURE__ */ jsx(TooltipTrigger, { delay: 0, children });
}
function Button(props) {
  return /* @__PURE__ */ jsx(Button$2, { ...props });
}
function Body({ children, className }) {
  return /* @__PURE__ */ jsx(
    Tooltip$2,
    {
      className: cn(
        "text-sm max-w-xs p-2 rounded-lg mb-2",
        "bg-white dark:bg-ui-900 drop-shadow-sm",
        "border border-gray-200 dark:border-zinc-700",
        className
      ),
      children
    }
  );
}
const Tooltip$1 = Object.assign(Tooltip, { Button, Body });
async function loader$4({
  request,
  params
}) {
  const session = await getSession(request.headers.get("Cookie"));
  if (!params.id) {
    throw new Error("No machine ID provided");
  }
  const context2 = await loadContext();
  let magic;
  if (context2.config.read) {
    const config2 = await loadConfig();
    if (config2.dns.magic_dns) {
      magic = config2.dns.base_domain;
    }
  }
  const [machine2, routes2, users] = await Promise.all([pull(`v1/node/${params.id}`, session.get("hsApiKey")), pull("v1/routes", session.get("hsApiKey")), pull("v1/user", session.get("hsApiKey"))]);
  return {
    machine: machine2.node,
    routes: routes2.routes.filter((route) => route.node.id === params.id),
    users: users.users,
    magic
  };
}
async function action$4({
  request
}) {
  return menuAction(request);
}
const machine = withComponentProps(function Page3() {
  const {
    machine: machine2,
    magic,
    routes: routes2,
    users
  } = useLoaderData();
  const [showRouting, setShowRouting] = useState(false);
  useLiveData({
    interval: 1e3
  });
  const expired = machine2.expiry === "0001-01-01 00:00:00" || machine2.expiry === "0001-01-01T00:00:00Z" || machine2.expiry === null ? false : new Date(machine2.expiry).getTime() < Date.now();
  const tags = [...machine2.forcedTags, ...machine2.validTags];
  if (expired) {
    tags.unshift("Expired");
  }
  const {
    exit,
    subnet,
    subnetApproved
  } = routes2.reduce((acc, route) => {
    if (route.prefix === "::/0" || route.prefix === "0.0.0.0/0") {
      acc.exit.push(route);
      return acc;
    }
    if (route.enabled) {
      acc.subnetApproved.push(route);
      return acc;
    }
    acc.subnet.push(route);
    return acc;
  }, {
    exit: [],
    subnetApproved: [],
    subnet: []
  });
  const exitEnabled = useMemo(() => {
    if (exit.length !== 2) return false;
    return exit[0].enabled && exit[1].enabled;
  }, [exit]);
  if (exitEnabled) {
    tags.unshift("Exit Node");
  }
  if (subnetApproved.length > 0) {
    tags.unshift("Subnets");
  }
  return /* @__PURE__ */ jsxs("div", {
    children: [/* @__PURE__ */ jsxs("p", {
      className: "mb-8 text-md",
      children: [/* @__PURE__ */ jsx(Link$2, {
        to: "/machines",
        className: "font-medium",
        children: "All Machines"
      }), /* @__PURE__ */ jsx("span", {
        className: "mx-2",
        children: "/"
      }), machine2.givenName]
    }), /* @__PURE__ */ jsxs("div", {
      className: cn("flex justify-between items-center", "border-b border-ui-100 dark:border-ui-800"),
      children: [/* @__PURE__ */ jsxs("span", {
        className: "flex items-baseline gap-x-4 text-sm mb-4",
        children: [/* @__PURE__ */ jsx("h1", {
          className: "text-2xl font-medium",
          children: machine2.givenName
        }), /* @__PURE__ */ jsx(StatusCircle, {
          isOnline: machine2.online,
          className: "w-4 h-4"
        })]
      }), /* @__PURE__ */ jsx(Menu, {
        machine: machine2,
        routes: routes2,
        users,
        magic,
        buttonChild: /* @__PURE__ */ jsxs(Menu$2.Button, {
          className: cn("flex items-center justify-center gap-x-2", "bg-main-200 dark:bg-main-700/30", "hover:bg-main-300 dark:hover:bg-main-600/30", "text-ui-700 dark:text-ui-300 mb-2", "w-fit text-sm rounded-lg px-3 py-2"),
          children: [/* @__PURE__ */ jsx(GearIcon, {
            className: "w-5"
          }), "Machine Settings"]
        })
      })]
    }), /* @__PURE__ */ jsxs("div", {
      className: "flex gap-1 mb-4",
      children: [/* @__PURE__ */ jsxs("div", {
        className: "border-r border-ui-100 dark:border-ui-800 p-2 pr-4",
        children: [/* @__PURE__ */ jsxs("span", {
          className: "text-sm text-ui-600 dark:text-ui-300 flex items-center gap-x-1",
          children: ["Managed by", /* @__PURE__ */ jsxs(Tooltip$1, {
            children: [/* @__PURE__ */ jsx(Tooltip$1.Button, {
              children: /* @__PURE__ */ jsx(InfoIcon, {
                className: "w-3.5 h-3.5"
              })
            }), /* @__PURE__ */ jsx(Tooltip$1.Body, {
              children: "By default, a machine’s permissions match its creator’s."
            })]
          })]
        }), /* @__PURE__ */ jsxs("div", {
          className: "flex items-center gap-x-2.5 mt-1",
          children: [/* @__PURE__ */ jsx("div", {
            className: cn("rounded-full h-7 w-7 flex items-center justify-center", "border border-ui-200 dark:border-ui-700"),
            children: /* @__PURE__ */ jsx(PersonIcon, {
              className: "w-4 h-4"
            })
          }), machine2.user.name]
        })]
      }), /* @__PURE__ */ jsxs("div", {
        className: "p-2 pl-4",
        children: [/* @__PURE__ */ jsx("p", {
          className: "text-sm text-ui-600 dark:text-ui-300",
          children: "Status"
        }), /* @__PURE__ */ jsx("div", {
          className: "flex gap-1 mt-1 mb-8",
          children: tags.map((tag) => /* @__PURE__ */ jsx("span", {
            className: cn("text-xs rounded-md px-1.5 py-0.5", "bg-ui-200 dark:bg-ui-800", "text-ui-600 dark:text-ui-300"),
            children: tag
          }, tag))
        })]
      })]
    }), /* @__PURE__ */ jsx("h2", {
      className: "text-xl font-medium mb-4 mt-8",
      children: "Subnets & Routing"
    }), /* @__PURE__ */ jsx(Routes, {
      machine: machine2,
      routes: routes2,
      state: [showRouting, setShowRouting]
    }), /* @__PURE__ */ jsxs("div", {
      className: "flex items-center justify-between mb-4",
      children: [/* @__PURE__ */ jsxs("p", {
        children: ["Subnets let you expose physical network routes onto Tailscale.", " ", /* @__PURE__ */ jsx(Link, {
          to: "https://tailscale.com/kb/1019/subnets",
          name: "Tailscale Subnets Documentation",
          children: "Learn More"
        })]
      }), /* @__PURE__ */ jsx(Button$1, {
        onPress: () => setShowRouting(true),
        children: "Review"
      })]
    }), /* @__PURE__ */ jsxs(Card$1, {
      variant: "flat",
      className: cn("w-full max-w-full grid sm:grid-cols-2", "md:grid-cols-4 gap-8 mr-2 text-sm mb-8"),
      children: [/* @__PURE__ */ jsxs("div", {
        children: [/* @__PURE__ */ jsxs("span", {
          className: "text-ui-600 dark:text-ui-300 flex items-center gap-x-1",
          children: ["Approved", /* @__PURE__ */ jsxs(Tooltip$1, {
            children: [/* @__PURE__ */ jsx(Tooltip$1.Button, {
              children: /* @__PURE__ */ jsx(InfoIcon, {
                className: "w-3.5 h-3.5"
              })
            }), /* @__PURE__ */ jsx(Tooltip$1.Body, {
              children: "Traffic to these routes are being routed through this machine."
            })]
          })]
        }), /* @__PURE__ */ jsx("div", {
          className: "mt-1",
          children: subnetApproved.length === 0 ? /* @__PURE__ */ jsx("span", {
            className: "text-ui-400 dark:text-ui-300",
            children: "—"
          }) : /* @__PURE__ */ jsx("ul", {
            className: "leading-normal",
            children: subnetApproved.map((route) => /* @__PURE__ */ jsx("li", {
              children: route.prefix
            }, route.id))
          })
        }), /* @__PURE__ */ jsx(Button$1, {
          onPress: () => setShowRouting(true),
          className: cn("px-1.5 py-0.5 rounded-md mt-1.5", "text-blue-500 dark:text-blue-400"),
          children: "Edit"
        })]
      }), /* @__PURE__ */ jsxs("div", {
        children: [/* @__PURE__ */ jsxs("span", {
          className: "text-ui-600 dark:text-ui-300 flex items-center gap-x-1",
          children: ["Awaiting Approval", /* @__PURE__ */ jsxs(Tooltip$1, {
            children: [/* @__PURE__ */ jsx(Tooltip$1.Button, {
              children: /* @__PURE__ */ jsx(InfoIcon, {
                className: "w-3.5 h-3.5"
              })
            }), /* @__PURE__ */ jsx(Tooltip$1.Body, {
              children: "This machine is advertising these routes, but they must be approved before traffic will be routed to them."
            })]
          })]
        }), /* @__PURE__ */ jsx("div", {
          className: "mt-1",
          children: subnet.length === 0 ? /* @__PURE__ */ jsx("span", {
            className: "text-ui-400 dark:text-ui-300",
            children: "—"
          }) : /* @__PURE__ */ jsx("ul", {
            className: "leading-normal",
            children: subnet.map((route) => /* @__PURE__ */ jsx("li", {
              children: route.prefix
            }, route.id))
          })
        }), /* @__PURE__ */ jsx(Button$1, {
          onPress: () => setShowRouting(true),
          className: cn("px-1.5 py-0.5 rounded-md mt-1.5", "text-blue-500 dark:text-blue-400"),
          children: "Edit"
        })]
      }), /* @__PURE__ */ jsxs("div", {
        children: [/* @__PURE__ */ jsxs("span", {
          className: "text-ui-600 dark:text-ui-300 flex items-center gap-x-1",
          children: ["Exit Node", /* @__PURE__ */ jsxs(Tooltip$1, {
            children: [/* @__PURE__ */ jsx(Tooltip$1.Button, {
              children: /* @__PURE__ */ jsx(InfoIcon, {
                className: "w-3.5 h-3.5"
              })
            }), /* @__PURE__ */ jsx(Tooltip$1.Body, {
              children: "Whether this machine can act as an exit node for your tailnet."
            })]
          })]
        }), /* @__PURE__ */ jsx("div", {
          className: "mt-1",
          children: exit.length === 0 ? /* @__PURE__ */ jsx("span", {
            className: "text-ui-400 dark:text-ui-300",
            children: "—"
          }) : exitEnabled ? /* @__PURE__ */ jsxs("span", {
            className: "flex items-center gap-x-1",
            children: [/* @__PURE__ */ jsx(CheckCircleIcon, {
              className: "w-3.5 h-3.5 text-green-700"
            }), "Allowed"]
          }) : /* @__PURE__ */ jsxs("span", {
            className: "flex items-center gap-x-1",
            children: [/* @__PURE__ */ jsx(SkipIcon, {
              className: "w-3.5 h-3.5 text-red-700"
            }), "Awaiting Approval"]
          })
        }), /* @__PURE__ */ jsx(Button$1, {
          onPress: () => setShowRouting(true),
          className: cn("px-1.5 py-0.5 rounded-md mt-1.5", "text-blue-500 dark:text-blue-400"),
          children: "Edit"
        })]
      })]
    }), /* @__PURE__ */ jsx("h2", {
      className: "text-xl font-medium mb-4",
      children: "Machine Details"
    }), /* @__PURE__ */ jsxs(Card$1, {
      variant: "flat",
      className: "w-full max-w-full",
      children: [/* @__PURE__ */ jsx(Attribute, {
        name: "Creator",
        value: machine2.user.name
      }), /* @__PURE__ */ jsx(Attribute, {
        name: "Node ID",
        value: machine2.id
      }), /* @__PURE__ */ jsx(Attribute, {
        name: "Node Name",
        value: machine2.givenName
      }), /* @__PURE__ */ jsx(Attribute, {
        name: "Hostname",
        value: machine2.name
      }), /* @__PURE__ */ jsx(Attribute, {
        isCopyable: true,
        name: "Node Key",
        value: machine2.nodeKey
      }), /* @__PURE__ */ jsx(Attribute, {
        name: "Created",
        value: new Date(machine2.createdAt).toLocaleString()
      }), /* @__PURE__ */ jsx(Attribute, {
        name: "Last Seen",
        value: new Date(machine2.lastSeen).toLocaleString()
      }), /* @__PURE__ */ jsx(Attribute, {
        name: "Expiry",
        value: expired ? new Date(machine2.expiry).toLocaleString() : "Never"
      }), magic ? /* @__PURE__ */ jsx(Attribute, {
        isCopyable: true,
        name: "Domain",
        value: `${machine2.givenName}.${magic}`
      }) : void 0]
    })]
  });
});
const route10 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action: action$4,
  default: machine,
  loader: loader$4
}, Symbol.toStringTag, { value: "Module" }));
function Add({ magic }) {
  const [username, setUsername] = useState("");
  const submit = useSubmit();
  return /* @__PURE__ */ jsxs(Dialog$1, { children: [
    /* @__PURE__ */ jsx(Dialog$1.Button, { children: "Add a new user" }),
    /* @__PURE__ */ jsx(Dialog$1.Panel, { children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsx(Dialog$1.Title, { children: "Add a new user" }),
      /* @__PURE__ */ jsxs(Dialog$1.Text, { className: "mb-8", children: [
        "Enter a username to create a new user.",
        " ",
        magic ? /* @__PURE__ */ jsxs(Fragment, { children: [
          "Since Magic DNS is enabled, machines will be accessible via",
          " ",
          /* @__PURE__ */ jsxs(Code, { children: [
            "[machine]. .",
            magic
          ] }),
          "."
        ] }) : void 0
      ] }),
      /* @__PURE__ */ jsxs(
        Form,
        {
          method: "POST",
          onSubmit: (event) => {
            submit(event.currentTarget);
            setUsername("");
          },
          children: [
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "create" }),
            /* @__PURE__ */ jsx(
              TextField,
              {
                label: "Username",
                placeholder: "my-new-user",
                name: "username",
                state: [username, setUsername],
                className: "my-2"
              }
            ),
            /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "confirm", onPress: close, children: "Create" })
            ] })
          ]
        }
      )
    ] }) })
  ] });
}
function Auth({ magic }) {
  return /* @__PURE__ */ jsx(Card$1, { variant: "flat", className: "mb-8 w-full max-w-full p-0", children: /* @__PURE__ */ jsxs("div", { className: "flex flex-col md:flex-row", children: [
    /* @__PURE__ */ jsxs("div", { className: "w-full p-4 border-b md:border-b-0 border-ui-200 dark:border-ui-700", children: [
      /* @__PURE__ */ jsx(HomeIcon, { className: "w-5 h-5 mb-2" }),
      /* @__PURE__ */ jsx("h2", { className: "font-medium mb-1", children: "Basic Authentication" }),
      /* @__PURE__ */ jsxs("p", { className: "text-sm text-ui-600 dark:text-ui-300", children: [
        "Users are not managed externally. Using OpenID Connect can create a better experience when using Headscale.",
        " ",
        /* @__PURE__ */ jsx(
          Link,
          {
            to: "https://headscale.net/stable/ref/oidc",
            name: "Headscale OIDC Documentation",
            children: "Learn more"
          }
        )
      ] })
    ] }),
    /* @__PURE__ */ jsxs("div", { className: "w-full p-4 md:border-l border-ui-200 dark:border-ui-700", children: [
      /* @__PURE__ */ jsx(PasskeyFillIcon, { className: "w-5 h-5 mb-2" }),
      /* @__PURE__ */ jsx("h2", { className: "font-medium mb-1", children: "User Management" }),
      /* @__PURE__ */ jsx("p", { className: "text-sm text-ui-600 dark:text-ui-300", children: "You can add, remove, and rename users here." }),
      /* @__PURE__ */ jsx("div", { className: "flex items-center gap-2 mt-4", children: /* @__PURE__ */ jsx(Add, { magic }) })
    ] })
  ] }) });
}
function Oidc({ oidc, magic }) {
  return /* @__PURE__ */ jsx(Card$1, { variant: "flat", className: "mb-8 w-full max-w-full p-0", children: /* @__PURE__ */ jsxs("div", { className: "flex flex-col md:flex-row", children: [
    /* @__PURE__ */ jsxs("div", { className: "w-full p-4 border-b md:border-b-0 border-ui-200 dark:border-ui-700", children: [
      /* @__PURE__ */ jsx(OrganizationIcon, { className: "w-5 h-5 mb-2" }),
      /* @__PURE__ */ jsx("h2", { className: "font-medium mb-1", children: "OpenID Connect" }),
      /* @__PURE__ */ jsxs("p", { className: "text-sm text-ui-600 dark:text-ui-300", children: [
        "Users are managed through your",
        " ",
        /* @__PURE__ */ jsx(Link, { to: oidc.issuer, name: "OIDC Provider", children: "OpenID Connect provider" }),
        ". ",
        "Groups and user information do not automatically sync.",
        " ",
        /* @__PURE__ */ jsx(
          Link,
          {
            to: "https://headscale.net/stable/ref/oidc",
            name: "Headscale OIDC Documentation",
            children: "Learn more"
          }
        )
      ] })
    ] }),
    /* @__PURE__ */ jsxs("div", { className: "w-full p-4 md:border-l border-ui-200 dark:border-ui-700", children: [
      /* @__PURE__ */ jsx(PasskeyFillIcon, { className: "w-5 h-5 mb-2" }),
      /* @__PURE__ */ jsx("h2", { className: "font-medium mb-1", children: "User Management" }),
      /* @__PURE__ */ jsx("p", { className: "text-sm text-ui-600 dark:text-ui-300", children: "You can still add users manually, however it is recommended that you manage users through your OIDC provider." }),
      /* @__PURE__ */ jsx("div", { className: "flex items-center gap-2 mt-4", children: /* @__PURE__ */ jsx(Add, { magic }) })
    ] })
  ] }) });
}
function Remove({ username }) {
  const submit = useSubmit();
  const [dialog, setDialog] = useState(false);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(
      IconButton,
      {
        label: `Delete ${username}`,
        onPress: () => setDialog(true),
        children: /* @__PURE__ */ jsx(X, { className: "p-0.5" })
      }
    ),
    /* @__PURE__ */ jsx(Dialog$1, { control: [dialog, setDialog], children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: [dialog, setDialog], children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
        "Delete ",
        username,
        "?"
      ] }),
      /* @__PURE__ */ jsxs(Dialog$1.Text, { className: "mb-8", children: [
        "Are you sure you want to delete ",
        username,
        "? A deleted user cannot be recovered."
      ] }),
      /* @__PURE__ */ jsxs(
        Form,
        {
          method: "POST",
          onSubmit: (event) => {
            submit(event.currentTarget);
          },
          children: [
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "delete" }),
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "username", value: username }),
            /* @__PURE__ */ jsxs("div", { className: "mt-6 flex justify-end gap-2 mt-6", children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "confirm", onPress: close, children: "Delete" })
            ] })
          ]
        }
      )
    ] }) }) })
  ] });
}
function Rename({ username, magic }) {
  const submit = useSubmit();
  const [dialog, setDialog] = useState(false);
  const [newName, setNewName] = useState(username);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx(
      IconButton,
      {
        label: `Rename ${username}`,
        onPress: () => setDialog(true),
        children: /* @__PURE__ */ jsx(Pencil, { className: "p-1" })
      }
    ),
    /* @__PURE__ */ jsx(Dialog$1, { control: [dialog, setDialog], children: /* @__PURE__ */ jsx(Dialog$1.Panel, { control: [dialog, setDialog], children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
        "Rename ",
        username,
        "?"
      ] }),
      /* @__PURE__ */ jsxs(Dialog$1.Text, { className: "mb-8", children: [
        "Enter a new username for ",
        username
      ] }),
      /* @__PURE__ */ jsxs(
        Form,
        {
          method: "POST",
          onSubmit: (event) => {
            submit(event.currentTarget);
          },
          children: [
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "_method", value: "rename" }),
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "old", value: username }),
            /* @__PURE__ */ jsx(
              TextField,
              {
                label: "Username",
                placeholder: "my-new-name",
                name: "new",
                state: [newName, setNewName],
                className: "my-2"
              }
            ),
            /* @__PURE__ */ jsxs("div", { className: "mt-6 flex justify-end gap-2 mt-6", children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "confirm", onPress: close, children: "Rename" })
            ] })
          ]
        }
      )
    ] }) }) })
  ] });
}
async function loader$3({
  request
}) {
  const session = await getSession(request.headers.get("Cookie"));
  const [machines, apiUsers] = await Promise.all([pull("v1/node", session.get("hsApiKey")), pull("v1/user", session.get("hsApiKey"))]);
  const users = apiUsers.users.map((user) => ({
    ...user,
    machines: machines.nodes.filter((machine2) => machine2.user.id === user.id)
  }));
  const context2 = await loadContext();
  let magic;
  if (context2.config.read) {
    const config2 = await loadConfig();
    if (config2.dns.magic_dns) {
      magic = config2.dns.base_domain;
    }
  }
  return {
    oidc: context2.oidc,
    magic,
    users
  };
}
async function action$3({
  request
}) {
  const session = await getSession(request.headers.get("Cookie"));
  if (!session.has("hsApiKey")) {
    return send({
      message: "Unauthorized"
    }, 401);
  }
  const data2 = await request.formData();
  if (!data2.has("_method")) {
    return send({
      message: "No method provided"
    }, 400);
  }
  const method = String(data2.get("_method"));
  switch (method) {
    case "create": {
      if (!data2.has("username")) {
        return send({
          message: "No name provided"
        }, 400);
      }
      const username = String(data2.get("username"));
      await post("v1/user", session.get("hsApiKey"), {
        name: username
      });
      return {
        message: `User ${username} created`
      };
    }
    case "delete": {
      if (!data2.has("username")) {
        return send({
          message: "No name provided"
        }, 400);
      }
      const username = String(data2.get("username"));
      await del(`v1/user/${username}`, session.get("hsApiKey"));
      return {
        message: `User ${username} deleted`
      };
    }
    case "rename": {
      if (!data2.has("old") || !data2.has("new")) {
        return send({
          message: "No old or new name provided"
        }, 400);
      }
      const old = String(data2.get("old"));
      const newName = String(data2.get("new"));
      await post(`v1/user/${old}/rename/${newName}`, session.get("hsApiKey"));
      return {
        message: `User ${old} renamed to ${newName}`
      };
    }
    case "move": {
      if (!data2.has("id") || !data2.has("to") || !data2.has("name")) {
        return send({
          message: "No ID or destination provided"
        }, 400);
      }
      const id = String(data2.get("id"));
      const to = String(data2.get("to"));
      const name = String(data2.get("name"));
      try {
        await post(`v1/node/${id}/user?user=${to}`, session.get("hsApiKey"));
        return {
          message: `Moved ${name} to ${to}`
        };
      } catch {
        return send({
          message: `Failed to move ${name} to ${to}`
        }, 500);
      }
    }
    default: {
      return send({
        message: "Invalid method"
      }, 400);
    }
  }
}
const overview$2 = withComponentProps(function Page4() {
  const data2 = useLoaderData();
  const [users, setUsers] = useState(data2.users);
  const actionData = useActionData();
  useLiveData({
    interval: 3e3
  });
  useEffect(() => {
    if (!actionData) {
      return;
    }
    toast(actionData.message);
    if (actionData.message.startsWith("Failed")) {
      setUsers(data2.users);
    }
  }, [actionData]);
  useEffect(() => {
    setUsers(data2.users);
  }, [data2.users]);
  return /* @__PURE__ */ jsxs(Fragment, {
    children: [/* @__PURE__ */ jsx("h1", {
      className: "text-2xl font-medium mb-1.5",
      children: "Users"
    }), /* @__PURE__ */ jsx("p", {
      className: "mb-8 text-md",
      children: "Manage the users in your network and their permissions. Tip: You can drag machines between users to change ownership."
    }), data2.oidc ? /* @__PURE__ */ jsx(Oidc, {
      oidc: data2.oidc,
      magic: data2.magic
    }) : /* @__PURE__ */ jsx(Auth, {
      magic: data2.magic
    }), /* @__PURE__ */ jsx(ClientOnly, {
      fallback: /* @__PURE__ */ jsx(Users, {
        users
      }),
      children: () => /* @__PURE__ */ jsx(InteractiveUsers, {
        users,
        setUsers,
        magic: data2.magic
      })
    })]
  });
});
function Users({
  users,
  magic
}) {
  return /* @__PURE__ */ jsx("div", {
    className: "grid grid-cols-1 md:grid-cols-2 gap-4 auto-rows-min",
    children: users.map((user) => /* @__PURE__ */ jsx(UserCard, {
      user,
      magic
    }, user.id))
  });
}
function InteractiveUsers({
  users,
  setUsers,
  magic
}) {
  const submit = useSubmit();
  return /* @__PURE__ */ jsx(DndContext, {
    onDragEnd: (event) => {
      const {
        over,
        active
      } = event;
      if (!over) {
        return;
      }
      const newUsers = new Array();
      const reference = active.data;
      if (!reference.current) {
        return;
      }
      if (reference.current.user.name === over.id) {
        return;
      }
      for (const user of users) {
        newUsers.push({
          ...user,
          machines: over.id === user.name ? [...user.machines, reference.current] : user.machines.filter((m) => m.id !== active.id)
        });
      }
      setUsers == null ? void 0 : setUsers(newUsers);
      const data2 = new FormData();
      data2.append("_method", "move");
      data2.append("id", active.id.toString());
      data2.append("to", over.id.toString());
      data2.append("name", reference.current.givenName);
      submit(data2, {
        method: "POST"
      });
    },
    children: /* @__PURE__ */ jsx("div", {
      className: "grid grid-cols-1 md:grid-cols-2 gap-4 auto-rows-min",
      children: users.map((user) => /* @__PURE__ */ jsx(UserCard, {
        user,
        magic
      }, user.id))
    })
  });
}
function MachineChip({
  machine: machine2
}) {
  const {
    attributes,
    listeners,
    setNodeRef,
    transform
  } = useDraggable({
    id: machine2.id,
    data: machine2
  });
  return /* @__PURE__ */ jsxs("div", {
    ref: setNodeRef,
    className: cn("flex items-center w-full gap-2 py-1", "hover:bg-ui-100 dark:hover:bg-ui-800 rounded-lg"),
    style: {
      transform: transform ? `translate3d(${transform.x.toString()}px, ${transform.y.toString()}px, 0)` : void 0
    },
    ...listeners,
    ...attributes,
    children: [/* @__PURE__ */ jsx(StatusCircle, {
      isOnline: machine2.online,
      className: "w-4 h-4 px-1 w-fit"
    }), /* @__PURE__ */ jsx(Attribute, {
      name: machine2.givenName,
      link: `machines/${machine2.id}`,
      value: machine2.ipAddresses[0]
    })]
  });
}
function UserCard({
  user,
  magic
}) {
  const {
    isOver,
    setNodeRef
  } = useDroppable({
    id: user.name
  });
  return /* @__PURE__ */ jsx("div", {
    ref: setNodeRef,
    children: /* @__PURE__ */ jsxs(Card$1, {
      variant: "flat",
      className: cn("max-w-full w-full overflow-visible h-full", isOver ? "bg-ui-100 dark:bg-ui-800" : ""),
      children: [/* @__PURE__ */ jsxs("div", {
        className: "flex items-center justify-between",
        children: [/* @__PURE__ */ jsxs("div", {
          className: "flex items-center gap-4",
          children: [/* @__PURE__ */ jsx(PersonIcon, {
            className: "w-6 h-6"
          }), /* @__PURE__ */ jsx("span", {
            className: "text-lg font-mono",
            children: user.name
          })]
        }), /* @__PURE__ */ jsxs("div", {
          className: "flex items-center gap-2",
          children: [/* @__PURE__ */ jsx(Rename, {
            username: user.name,
            magic
          }), user.machines.length === 0 ? /* @__PURE__ */ jsx(Remove, {
            username: user.name
          }) : void 0]
        })]
      }), /* @__PURE__ */ jsx("div", {
        className: "mt-4",
        children: user.machines.map((machine2) => /* @__PURE__ */ jsx(MachineChip, {
          machine: machine2
        }, machine2.id))
      })]
    })
  });
}
const ErrorBoundary3 = withErrorBoundaryProps(function ErrorBoundary4() {
  return /* @__PURE__ */ jsx(ErrorPopup, {
    type: "embedded"
  });
});
const route11 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  ErrorBoundary: ErrorBoundary3,
  action: action$3,
  default: overview$2,
  loader: loader$3
}, Symbol.toStringTag, { value: "Module" }));
function Notice({ children, className }) {
  return /* @__PURE__ */ jsxs(
    "div",
    {
      className: cn(
        "p-4 rounded-md w-full flex items-center gap-3",
        "bg-ui-200 dark:bg-ui-800",
        className
      ),
      children: [
        /* @__PURE__ */ jsx(InfoIcon, { className: "h-6 w-6 text-ui-700 dark:text-ui-200" }),
        children
      ]
    }
  );
}
const Editor = void 0;
const Differ = void 0;
function Unavailable({ mode }) {
  return /* @__PURE__ */ jsxs(Card$1, { variant: "flat", className: "max-w-prose mt-12", children: [
    /* @__PURE__ */ jsxs("div", { className: "flex items-center justify-between", children: [
      /* @__PURE__ */ jsx(Card$1.Title, { className: "text-xl mb-0", children: "ACL Policy Unavailable" }),
      /* @__PURE__ */ jsx(AlertIcon, { className: "w-8 h-8 text-red-500" })
    ] }),
    /* @__PURE__ */ jsx(Card$1.Text, { className: "mt-4", children: "Unable to load a valid ACL policy configuration. This is most likely due to a misconfiguration in your Headscale configuration file." }),
    mode !== "file" ? /* @__PURE__ */ jsxs("p", { className: "mt-4 text-sm", children: [
      "According to your configuration, the ACL policy mode is set to",
      " ",
      /* @__PURE__ */ jsx(Code, { children: "file" }),
      " but the ACL file is not available. Ensure that the",
      " ",
      /* @__PURE__ */ jsx(Code, { children: "policy.path" }),
      " is set to a valid path in your Headscale configuration."
    ] }) : /* @__PURE__ */ jsxs("p", { className: "mt-4 text-sm", children: [
      "In order to fully utilize the ACL management features of Headplane, please set ",
      /* @__PURE__ */ jsx(Code, { children: "policy.mode" }),
      " to either ",
      /* @__PURE__ */ jsx(Code, { children: "file" }),
      " or",
      " ",
      /* @__PURE__ */ jsx(Code, { children: "database" }),
      " in your Headscale configuration."
    ] })
  ] });
}
function ErrorView({ message }) {
  return /* @__PURE__ */ jsxs(Card$1, { variant: "flat", className: "max-w-full mb-4", children: [
    /* @__PURE__ */ jsxs("div", { className: "flex items-center justify-between", children: [
      /* @__PURE__ */ jsx(Card$1.Title, { className: "text-xl mb-0", children: "Error" }),
      /* @__PURE__ */ jsx(AlertIcon, { className: "w-8 h-8 text-red-500" })
    ] }),
    /* @__PURE__ */ jsxs(Card$1.Text, { className: "mt-4", children: [
      "Could not apply changes to your ACL policy due to the following error:",
      /* @__PURE__ */ jsx("br", {}),
      /* @__PURE__ */ jsx(Code, { children: message })
    ] })
  ] });
}
async function loader$2({
  request
}) {
  var _a;
  const session = await getSession(request.headers.get("Cookie"));
  const context2 = await loadContext();
  let modeGuess = "database";
  if (context2.config.read) {
    const config2 = await loadConfig();
    modeGuess = ((_a = config2.policy) == null ? void 0 : _a.mode) ?? "database";
  }
  try {
    const {
      policy
    } = await pull("v1/policy", session.get("hsApiKey"));
    let write = false;
    if (modeGuess === "database" && policy.length > 0) {
      try {
        await put("v1/policy", session.get("hsApiKey"), {
          policy
        });
        write = true;
      } catch (error) {
        write = false;
        log.debug("APIC", "Failed to write to ACL policy with error %s", error);
      }
    }
    return {
      read: true,
      write,
      mode: modeGuess,
      policy
    };
  } catch {
    if (modeGuess === "file") {
      return {
        read: false,
        write: false,
        mode: modeGuess,
        policy: null
      };
    }
    return {
      read: true,
      write: true,
      mode: modeGuess,
      policy: null
    };
  }
}
async function action$2({
  request
}) {
  const session = await getSession(request.headers.get("Cookie"));
  if (!session.has("hsApiKey")) {
    return send({
      success: false,
      error: null
    }, 401);
  }
  try {
    const {
      acl
    } = await request.json();
    const {
      policy
    } = await put("v1/policy", session.get("hsApiKey"), {
      policy: acl
    });
    return {
      success: true,
      policy,
      error: null
    };
  } catch (error) {
    log.debug("APIC", "Failed to update ACL policy with error %s", error);
    const text = JSON.parse(error.message);
    return send({
      success: false,
      error: text.message
    }, {
      status: error instanceof HeadscaleError ? error.status : 500
    });
  }
  return {
    success: true,
    error: null
  };
}
const editor = withComponentProps(function Page5() {
  var _a;
  const data2 = useLoaderData();
  const fetcher = useFetcher();
  const revalidator = useRevalidator();
  const [acl, setAcl] = useState(data2.policy ?? "");
  const [toasted, setToasted] = useState(false);
  useEffect(() => {
    if (!fetcher.data || toasted) {
      return;
    }
    if (fetcher.data.success) {
      toast("Updated tailnet ACL policy");
    } else {
      toast("Failed to update tailnet ACL policy");
    }
    setToasted(true);
    if (revalidator.state === "idle") {
      revalidator.revalidate();
    }
  }, [fetcher.data, toasted, data2.policy]);
  const disabled = useMemo(() => {
    var _a2;
    if (!data2.read || !data2.write) {
      return true;
    }
    if (fetcher.state === "loading") {
      return true;
    }
    if (revalidator.state === "loading") {
      return true;
    }
    if (((_a2 = fetcher.data) == null ? void 0 : _a2.success) === false) {
      return false;
    }
    return data2.policy === acl;
  }, [data2, revalidator.state, fetcher.state, fetcher.data, data2.policy, acl]);
  return /* @__PURE__ */ jsxs("div", {
    children: [
      data2.read && !data2.write ? /* @__PURE__ */ jsx("div", {
        className: "mb-4",
        children: /* @__PURE__ */ jsxs(Notice, {
          className: "w-fit",
          children: ["The ACL policy is read-only. You can view the current policy but you cannot make changes to it.", /* @__PURE__ */ jsx("br", {}), "To resolve this, you need to set the ACL policy mode to database in your Headscale configuration."]
        })
      }) : void 0,
      /* @__PURE__ */ jsx("h1", {
        className: "text-2xl font-medium mb-4",
        children: "Access Control List (ACL)"
      }),
      /* @__PURE__ */ jsxs("p", {
        className: "mb-4 max-w-prose",
        children: ["The ACL file is used to define the access control rules for your network. You can find more information about the ACL file in the", " ", /* @__PURE__ */ jsx(Link, {
          to: "https://tailscale.com/kb/1018/acls",
          name: "Tailscale ACL documentation",
          children: "Tailscale ACL guide"
        }), " ", "and the", " ", /* @__PURE__ */ jsx(Link, {
          to: "https://headscale.net/stable/ref/acls/",
          name: "Headscale ACL documentation",
          children: "Headscale docs"
        }), "."]
      }),
      // @ts-ignore: useDebounceFetcher is not typed correctly
      ((_a = fetcher.data) == null ? void 0 : _a.success) === false ? (
        // @ts-ignore: useDebounceFetcher is not typed correctly
        /* @__PURE__ */ jsx(ErrorView, {
          message: fetcher.data.error
        })
      ) : void 0,
      data2.read ? /* @__PURE__ */ jsxs(Fragment, {
        children: [/* @__PURE__ */ jsxs(Tabs, {
          children: [/* @__PURE__ */ jsxs(TabList, {
            className: cn("flex border-t border-gray-200 dark:border-gray-700", "w-fit rounded-t-lg overflow-hidden", "text-gray-400 dark:text-gray-500"),
            children: [/* @__PURE__ */ jsxs(Tab, {
              id: "edit",
              className: ({
                isSelected
              }) => cn("px-4 py-2 rounded-tl-lg", "focus:outline-none flex items-center gap-2", "border-x border-gray-200 dark:border-gray-700", isSelected ? "text-gray-900 dark:text-gray-100" : ""),
              children: [/* @__PURE__ */ jsx(PencilIcon, {
                className: "w-5 h-5"
              }), /* @__PURE__ */ jsx("p", {
                children: "Edit file"
              })]
            }), /* @__PURE__ */ jsxs(Tab, {
              id: "diff",
              className: ({
                isSelected
              }) => cn("px-4 py-2", "focus:outline-none flex items-center gap-2", "border-x border-gray-200 dark:border-gray-700", isSelected ? "text-gray-900 dark:text-gray-100" : ""),
              children: [/* @__PURE__ */ jsx(EyeIcon, {
                className: "w-5 h-5"
              }), /* @__PURE__ */ jsx("p", {
                children: "Preview changes"
              })]
            }), /* @__PURE__ */ jsxs(Tab, {
              id: "preview",
              className: ({
                isSelected
              }) => cn("px-4 py-2 rounded-tr-lg", "focus:outline-none flex items-center gap-2", "border-x border-gray-200 dark:border-gray-700", isSelected ? "text-gray-900 dark:text-gray-100" : ""),
              children: [/* @__PURE__ */ jsx(BeakerIcon, {
                className: "w-5 h-5"
              }), /* @__PURE__ */ jsx("p", {
                children: "Preview rules"
              })]
            })]
          }), /* @__PURE__ */ jsx(TabPanel, {
            id: "edit",
            children: /* @__PURE__ */ jsx(Editor, {
              isDisabled: !data2.write,
              value: acl,
              onChange: setAcl
            })
          }), /* @__PURE__ */ jsx(TabPanel, {
            id: "diff",
            children: /* @__PURE__ */ jsx(Differ, {
              left: (data2 == null ? void 0 : data2.policy) ?? "",
              right: acl
            })
          }), /* @__PURE__ */ jsx(TabPanel, {
            id: "preview",
            children: /* @__PURE__ */ jsxs("div", {
              className: cn("border border-gray-200 dark:border-gray-700", "rounded-b-lg rounded-tr-lg mb-4 overflow-hidden", "p-16 flex flex-col items-center justify-center"),
              children: [/* @__PURE__ */ jsx(IssueDraftIcon, {
                className: "w-24 h-24 text-gray-300 dark:text-gray-500"
              }), /* @__PURE__ */ jsx("p", {
                className: "w-1/2 text-center mt-4",
                children: "The Preview rules is very much still a work in progress. It is a bit complicated to implement right now but hopefully it will be available soon."
              })]
            })
          })]
        }), /* @__PURE__ */ jsxs(Button$1, {
          variant: "heavy",
          className: "mr-2",
          isDisabled: disabled,
          onPress: () => {
            setToasted(false);
            fetcher.submit({
              acl
            }, {
              method: "PATCH",
              encType: "application/json"
            });
          },
          children: [fetcher.state === "idle" ? void 0 : /* @__PURE__ */ jsx(Spinner, {
            className: "w-3 h-3"
          }), "Save"]
        }), /* @__PURE__ */ jsx(Button$1, {
          isDisabled: disabled,
          onPress: () => {
            setAcl((data2 == null ? void 0 : data2.policy) ?? "");
          },
          children: "Discard Changes"
        })]
      }) : /* @__PURE__ */ jsx(Unavailable, {
        mode: data2.mode
      })
    ]
  });
});
const route12 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action: action$2,
  default: editor,
  loader: loader$2
}, Symbol.toStringTag, { value: "Module" }));
function TableList(props) {
  return /* @__PURE__ */ jsx(
    "div",
    {
      ...props,
      className: clsx$1(
        "border border-gray-300 rounded-lg overflow-clip",
        "dark:border-zinc-700 dark:text-gray-300",
        // 'dark:bg-zinc-800',
        props.className
      ),
      children: props.children
    }
  );
}
function Item(props) {
  return /* @__PURE__ */ jsx(
    "div",
    {
      ...props,
      className: clsx$1(
        "flex items-center justify-between px-3 py-2",
        "border-b border-gray-200 last:border-b-0",
        "dark:border-zinc-800",
        props.className
      ),
      children: props.children
    }
  );
}
const TableList$1 = Object.assign(TableList, { Item });
function AddDNS({ records }) {
  const submit = useSubmit();
  const [name, setName] = useState("");
  const [ip, setIp] = useState("");
  const isDuplicate = useMemo(() => {
    if (name.length === 0 || ip.length === 0) return false;
    const lookup = records.find((record) => record.name === name);
    if (!lookup) return false;
    return lookup.value === ip;
  }, [records, name, ip]);
  return /* @__PURE__ */ jsxs(Dialog$1, { children: [
    /* @__PURE__ */ jsx(Dialog$1.Button, { children: "Add DNS record" }),
    /* @__PURE__ */ jsx(Dialog$1.Panel, { children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsx(Dialog$1.Title, { children: "Add DNS record" }),
      /* @__PURE__ */ jsx(Dialog$1.Text, { children: "Enter the domain and IP address for the new DNS record." }),
      /* @__PURE__ */ jsxs(
        Form,
        {
          method: "POST",
          onSubmit: (event) => {
            event.preventDefault();
            if (!name || !ip) return;
            setName("");
            setIp("");
            submit(
              {
                "dns.extra_records": [
                  ...records,
                  {
                    name,
                    type: "A",
                    value: ip
                  }
                ]
              },
              {
                method: "PATCH",
                encType: "application/json"
              }
            );
            close();
          },
          children: [
            /* @__PURE__ */ jsx(
              TextField,
              {
                label: "Domain",
                placeholder: "test.example.com",
                name: "domain",
                state: [name, setName],
                className: cn("mt-2", isDuplicate && "outline outline-red-500")
              }
            ),
            /* @__PURE__ */ jsx(
              TextField,
              {
                label: "IP Address",
                placeholder: "101.101.101.101",
                name: "ip",
                state: [ip, setIp],
                className: cn(isDuplicate && "outline outline-red-500")
              }
            ),
            isDuplicate ? /* @__PURE__ */ jsxs("p", { className: "text-sm opacity-50", children: [
              "A record with the domain name ",
              /* @__PURE__ */ jsx(Code, { children: name }),
              " and IP address ",
              /* @__PURE__ */ jsx(Code, { children: ip }),
              " already exists."
            ] }) : void 0,
            /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsx(
                Dialog$1.Action,
                {
                  variant: "confirm",
                  onPress: close,
                  isDisabled: isDuplicate,
                  children: "Add"
                }
              )
            ] })
          ]
        }
      )
    ] }) })
  ] });
}
function DNS({ records, isDisabled }) {
  const submit = useSubmit();
  return /* @__PURE__ */ jsxs("div", { className: "flex flex-col w-2/3", children: [
    /* @__PURE__ */ jsx("h1", { className: "text-2xl font-medium mb-4", children: "DNS Records" }),
    /* @__PURE__ */ jsxs("p", { className: "text-gray-700 dark:text-gray-300", children: [
      "Headscale supports adding custom DNS records to your Tailnet. As of now, only ",
      /* @__PURE__ */ jsx(Code, { children: "A" }),
      " records are supported.",
      " ",
      /* @__PURE__ */ jsx(
        Link,
        {
          to: "https://headscale.net/stable/ref/dns",
          name: "Headscale DNS Records documentation",
          children: "Learn More"
        }
      )
    ] }),
    /* @__PURE__ */ jsxs("div", { className: "mt-4", children: [
      /* @__PURE__ */ jsx(TableList$1, { className: "mb-8", children: records.length === 0 ? /* @__PURE__ */ jsx(TableList$1.Item, { children: /* @__PURE__ */ jsx("p", { className: "opacity-50 text-sm mx-auto", children: "No DNS records found" }) }) : records.map((record, index) => /* @__PURE__ */ jsxs(TableList$1.Item, { children: [
        /* @__PURE__ */ jsxs("div", { className: "flex gap-24", children: [
          /* @__PURE__ */ jsxs("div", { className: "flex gap-2", children: [
            /* @__PURE__ */ jsx("p", { className: "font-mono text-sm font-bold", children: record.type }),
            /* @__PURE__ */ jsx("p", { className: "font-mono text-sm", children: record.name })
          ] }),
          /* @__PURE__ */ jsx("p", { className: "font-mono text-sm", children: record.value })
        ] }),
        /* @__PURE__ */ jsx(
          Button$2,
          {
            className: cn(
              "text-sm",
              "text-red-600 dark:text-red-400",
              "hover:text-red-700 dark:hover:text-red-300",
              isDisabled && "opacity-50 cursor-not-allowed"
            ),
            isDisabled,
            onPress: () => {
              submit(
                {
                  "dns.extra_records": records.filter(
                    (_, i) => i !== index
                  )
                },
                {
                  method: "PATCH",
                  encType: "application/json"
                }
              );
            },
            children: "Remove"
          }
        )
      ] }, index)) }),
      isDisabled ? void 0 : /* @__PURE__ */ jsx(AddDNS, { records })
    ] })
  ] });
}
function Domains({
  baseDomain,
  searchDomains,
  disabled
}) {
  const [activeId, setActiveId] = useState(null);
  const [localDomains, setLocalDomains] = useState(searchDomains);
  const [newDomain, setNewDomain] = useState("");
  const fetcher = useFetcher();
  useEffect(() => {
    setLocalDomains(searchDomains);
  }, [searchDomains]);
  return /* @__PURE__ */ jsxs("div", { className: "flex flex-col w-2/3", children: [
    /* @__PURE__ */ jsx("h1", { className: "text-2xl font-medium mb-4", children: "Search Domains" }),
    /* @__PURE__ */ jsx("p", { className: "text-gray-700 dark:text-gray-300 mb-2", children: "Set custom DNS search domains for your Tailnet. When using Magic DNS, your tailnet domain is used as the first search domain." }),
    /* @__PURE__ */ jsx(
      DndContext,
      {
        modifiers: [restrictToVerticalAxis, restrictToParentElement],
        collisionDetection: closestCorners,
        onDragStart: (event) => {
          setActiveId(event.active.id);
        },
        onDragEnd: (event) => {
          setActiveId(null);
          const { active, over } = event;
          if (!over) {
            return;
          }
          const activeItem = localDomains[active.id - 1];
          const overItem = localDomains[over.id - 1];
          if (!activeItem || !overItem) {
            return;
          }
          const oldIndex = localDomains.indexOf(activeItem);
          const newIndex = localDomains.indexOf(overItem);
          if (oldIndex !== newIndex) {
            setLocalDomains(arrayMove(localDomains, oldIndex, newIndex));
          }
        },
        children: /* @__PURE__ */ jsxs(TableList$1, { children: [
          baseDomain ? /* @__PURE__ */ jsxs(TableList$1.Item, { children: [
            /* @__PURE__ */ jsx("p", { className: "font-mono text-sm", children: baseDomain }),
            /* @__PURE__ */ jsx(LockIcon, { className: "h-4 w-4" })
          ] }, "magic-dns-sd") : void 0,
          /* @__PURE__ */ jsxs(
            SortableContext,
            {
              items: localDomains,
              strategy: verticalListSortingStrategy,
              children: [
                localDomains.map((sd, index) => /* @__PURE__ */ jsx(
                  Domain,
                  {
                    domain: sd,
                    id: index + 1,
                    localDomains,
                    disabled,
                    fetcher
                  },
                  index
                )),
                /* @__PURE__ */ jsx(DragOverlay, { adjustScale: true, children: activeId ? /* @__PURE__ */ jsx(
                  Domain,
                  {
                    isDrag: true,
                    domain: localDomains[activeId - 1],
                    localDomains,
                    id: activeId - 1,
                    disabled,
                    fetcher
                  }
                ) : void 0 })
              ]
            }
          ),
          disabled ? void 0 : /* @__PURE__ */ jsxs(TableList$1.Item, { children: [
            /* @__PURE__ */ jsx(
              Input,
              {
                type: "text",
                className: "font-mono text-sm bg-transparent w-full mr-2",
                placeholder: "Search Domain",
                value: newDomain,
                onChange: (event) => {
                  setNewDomain(event.target.value);
                }
              }
            ),
            fetcher.state === "idle" ? /* @__PURE__ */ jsx(
              Button$2,
              {
                className: cn(
                  "text-sm font-semibold",
                  "text-blue-600 dark:text-blue-400",
                  "hover:text-blue-700 dark:hover:text-blue-300",
                  newDomain.length === 0 && "opacity-50 cursor-not-allowed"
                ),
                isDisabled: newDomain.length === 0,
                onPress: () => {
                  fetcher.submit(
                    {
                      // eslint-disable-next-line @typescript-eslint/naming-convention
                      "dns.search_domains": [...localDomains, newDomain]
                    },
                    {
                      method: "PATCH",
                      encType: "application/json"
                    }
                  );
                  setNewDomain("");
                },
                children: "Add"
              }
            ) : /* @__PURE__ */ jsx(Spinner, { className: "w-3 h-3 mr-0" })
          ] }, "add-sd")
        ] })
      }
    )
  ] });
}
function Domain({
  domain,
  id,
  localDomains,
  isDrag,
  disabled,
  fetcher
}) {
  const {
    attributes,
    listeners,
    setNodeRef,
    transform,
    transition,
    isDragging
  } = useSortable({ id });
  return /* @__PURE__ */ jsxs(
    "div",
    {
      ref: setNodeRef,
      className: cn(
        "flex items-center justify-between px-3 py-2",
        "border-b border-gray-200 last:border-b-0 dark:border-zinc-800",
        isDragging ? "text-gray-400" : "",
        isDrag ? "outline outline-1 outline-gray-500 bg-gray-200 dark:bg-zinc-800" : ""
      ),
      style: {
        transform: CSS.Transform.toString(transform),
        transition
      },
      children: [
        /* @__PURE__ */ jsxs("p", { className: "font-mono text-sm flex items-center gap-4", children: [
          disabled ? void 0 : /* @__PURE__ */ jsx(
            ThreeBarsIcon,
            {
              className: "h-4 w-4 text-gray-400 focus:outline-none",
              ...attributes,
              ...listeners
            }
          ),
          domain
        ] }),
        isDrag ? void 0 : /* @__PURE__ */ jsx(
          Button$2,
          {
            className: cn(
              "text-sm",
              "text-red-600 dark:text-red-400",
              "hover:text-red-700 dark:hover:text-red-300",
              disabled && "opacity-50 cursor-not-allowed"
            ),
            isDisabled: disabled,
            onPress: () => {
              fetcher.submit(
                {
                  "dns.search_domains": localDomains.filter(
                    (_, index) => index !== id - 1
                  )
                },
                {
                  method: "PATCH",
                  encType: "application/json"
                }
              );
            },
            children: "Remove"
          }
        )
      ]
    }
  );
}
function Modal$1({ isEnabled, disabled }) {
  const fetcher = useFetcher();
  return /* @__PURE__ */ jsxs(Dialog$1, { children: [
    /* @__PURE__ */ jsxs(Dialog$1.Button, { isDisabled: disabled, children: [
      fetcher.state === "idle" ? void 0 : /* @__PURE__ */ jsx(Spinner, { className: "w-3 h-3" }),
      isEnabled ? "Disable" : "Enable",
      " Magic DNS"
    ] }),
    /* @__PURE__ */ jsx(Dialog$1.Panel, { children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsxs(Dialog$1.Title, { children: [
        isEnabled ? "Disable" : "Enable",
        " Magic DNS"
      ] }),
      /* @__PURE__ */ jsx(Dialog$1.Text, { children: "Devices will no longer be accessible via your tailnet domain. The search domain will also be disabled." }),
      /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
        /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
        /* @__PURE__ */ jsxs(
          Dialog$1.Action,
          {
            variant: "confirm",
            onPress: () => {
              fetcher.submit(
                {
                  // eslint-disable-next-line @typescript-eslint/naming-convention
                  "dns.magic_dns": !isEnabled
                },
                {
                  method: "PATCH",
                  encType: "application/json"
                }
              );
              close();
            },
            children: [
              isEnabled ? "Disable" : "Enable",
              " Magic DNS"
            ]
          }
        )
      ] })
    ] }) })
  ] });
}
function AddNameserver({ nameservers }) {
  const submit = useSubmit();
  const [split, setSplit] = useState(false);
  const [ns, setNs] = useState("");
  const [domain, setDomain] = useState("");
  return /* @__PURE__ */ jsxs(Dialog$1, { children: [
    /* @__PURE__ */ jsx(Dialog$1.Button, { children: "Add nameserver" }),
    /* @__PURE__ */ jsx(Dialog$1.Panel, { children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsx(Dialog$1.Title, { children: "Add nameserver" }),
      /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-semibold", children: "Nameserver" }),
      /* @__PURE__ */ jsx(Dialog$1.Text, { className: "text-sm", children: "Use this IPv4 or IPv6 address to resolve names." }),
      /* @__PURE__ */ jsxs(
        Form,
        {
          method: "POST",
          onSubmit: (event) => {
            event.preventDefault();
            if (!ns) return;
            if (split) {
              const splitNs = {};
              for (const [key, value] of Object.entries(nameservers)) {
                if (key === "global") continue;
                splitNs[key] = value;
              }
              if (Object.keys(splitNs).includes(domain)) {
                splitNs[domain].push(ns);
              } else {
                splitNs[domain] = [ns];
              }
              submit(
                {
                  "dns.nameservers.split": splitNs
                },
                {
                  method: "PATCH",
                  encType: "application/json"
                }
              );
            } else {
              const globalNs = nameservers.global;
              globalNs.push(ns);
              submit(
                {
                  "dns.nameservers.global": globalNs
                },
                {
                  method: "PATCH",
                  encType: "application/json"
                }
              );
            }
            setNs("");
            setDomain("");
            setSplit(false);
            close();
          },
          children: [
            /* @__PURE__ */ jsx(
              TextField,
              {
                label: "DNS Server",
                placeholder: "1.2.3.4",
                name: "ns",
                state: [ns, setNs],
                className: "mt-2 mb-8"
              }
            ),
            /* @__PURE__ */ jsxs("div", { className: "flex items-center justify-between", children: [
              /* @__PURE__ */ jsxs("div", { className: "block", children: [
                /* @__PURE__ */ jsxs("div", { className: "inline-flex items-center gap-2", children: [
                  /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-semibold", children: "Restrict to domain" }),
                  /* @__PURE__ */ jsxs(Tooltip$1, { children: [
                    /* @__PURE__ */ jsxs(
                      Tooltip$1.Button,
                      {
                        className: cn(
                          "text-xs rounded-md px-1.5 py-0.5",
                          "bg-ui-200 dark:bg-ui-800",
                          "text-ui-600 dark:text-ui-300"
                        ),
                        children: [
                          /* @__PURE__ */ jsx(RepoForkedIcon, { className: "w-4 h-4 mr-0.5" }),
                          "Split DNS"
                        ]
                      }
                    ),
                    /* @__PURE__ */ jsx(Tooltip$1.Body, { children: "Only clients that support split DNS (Tailscale v1.8 or later for most platforms) will use this nameserver. Older clients will ignore it." })
                  ] })
                ] }),
                /* @__PURE__ */ jsx(Dialog$1.Text, { className: "text-sm", children: "This nameserver will only be used for some domains." })
              ] }),
              /* @__PURE__ */ jsx(
                Switch,
                {
                  label: "Split DNS",
                  defaultSelected: split,
                  onChange: () => {
                    setSplit(!split);
                  }
                }
              )
            ] }),
            split ? /* @__PURE__ */ jsxs(Fragment, { children: [
              /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-semibold mt-8", children: "Domain" }),
              /* @__PURE__ */ jsx(
                TextField,
                {
                  label: "Domain",
                  placeholder: "example.com",
                  name: "domain",
                  state: [domain, setDomain],
                  className: "my-2"
                }
              ),
              /* @__PURE__ */ jsx(Dialog$1.Text, { className: "text-sm", children: "Only single-label or fully-qualified queries matching this suffix should use the nameserver." })
            ] }) : void 0,
            /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "confirm", onPress: close, children: "Add" })
            ] })
          ]
        }
      )
    ] }) })
  ] });
}
function Nameservers({ nameservers, isDisabled }) {
  return /* @__PURE__ */ jsxs("div", { className: "flex flex-col w-2/3", children: [
    /* @__PURE__ */ jsx("h1", { className: "text-2xl font-medium mb-4", children: "Nameservers" }),
    /* @__PURE__ */ jsxs("p", { className: "text-gray-700 dark:text-gray-300", children: [
      "Set the nameservers used by devices on the Tailnet to resolve DNS queries.",
      " ",
      /* @__PURE__ */ jsx(
        Link,
        {
          to: "https://tailscale.com/kb/1054/dns",
          name: "Tailscale DNS Documentation",
          children: "Learn more"
        }
      )
    ] }),
    /* @__PURE__ */ jsxs("div", { className: "mt-4", children: [
      Object.keys(nameservers).map((key) => /* @__PURE__ */ jsx(
        NameserverList,
        {
          isGlobal: key === "global",
          isDisabled,
          nameservers,
          name: key
        },
        key
      )),
      isDisabled ? void 0 : /* @__PURE__ */ jsx(AddNameserver, { nameservers })
    ] })
  ] });
}
function NameserverList({
  isGlobal,
  isDisabled,
  nameservers,
  name
}) {
  const submit = useSubmit();
  const list = isGlobal ? nameservers["global"] : nameservers[name];
  if (list.length === 0) {
    return null;
  }
  return /* @__PURE__ */ jsxs("div", { className: "mb-8", children: [
    /* @__PURE__ */ jsx("div", { className: "flex items-center justify-between mb-2", children: /* @__PURE__ */ jsx("h2", { className: "text-md font-medium opacity-80", children: isGlobal ? "Global Nameservers" : name }) }),
    /* @__PURE__ */ jsx(TableList$1, { children: list.length > 0 ? list.map((ns, index) => (
      // eslint-disable-next-line react/no-array-index-key
      /* @__PURE__ */ jsxs(TableList$1.Item, { children: [
        /* @__PURE__ */ jsx("p", { className: "font-mono text-sm", children: ns }),
        /* @__PURE__ */ jsx(
          Button$2,
          {
            className: cn(
              "text-sm",
              "text-red-600 dark:text-red-400",
              "hover:text-red-700 dark:hover:text-red-300",
              isDisabled && "opacity-50 cursor-not-allowed"
            ),
            isDisabled,
            onPress: () => {
              if (isGlobal) {
                submit(
                  {
                    "dns.nameservers.global": list.filter(
                      (_, i) => i !== index
                    )
                  },
                  {
                    method: "PATCH",
                    encType: "application/json"
                  }
                );
              } else {
                submit(
                  {
                    "dns.nameservers.split": {
                      ...nameservers,
                      [name]: list.filter((_, i) => i !== index)
                    }
                  },
                  {
                    method: "PATCH",
                    encType: "application/json"
                  }
                );
              }
            },
            children: "Remove"
          }
        )
      ] }, index)
    )) : void 0 })
  ] });
}
function Modal({ name, disabled }) {
  const [newName, setNewName] = useState(name);
  const fetcher = useFetcher();
  return /* @__PURE__ */ jsxs("div", { className: "flex flex-col w-2/3", children: [
    /* @__PURE__ */ jsx("h1", { className: "text-2xl font-medium mb-4", children: "Tailnet Name" }),
    /* @__PURE__ */ jsxs("p", { className: "text-gray-700 dark:text-gray-300", children: [
      "This is the base domain name of your Tailnet. Devices are accessible at",
      " ",
      /* @__PURE__ */ jsxs(Code, { children: [
        "[device].",
        name
      ] }),
      " when Magic DNS is enabled."
    ] }),
    /* @__PURE__ */ jsx(
      Input,
      {
        readOnly: true,
        className: cn(
          "block px-2.5 py-1.5 w-1/2 rounded-lg my-4",
          "border border-ui-200 dark:border-ui-600",
          "dark:bg-ui-800 dark:text-ui-300 text-sm",
          "outline-none"
        ),
        type: "text",
        value: name,
        onFocus: (event) => {
          event.target.select();
        }
      }
    ),
    /* @__PURE__ */ jsxs(Dialog$1, { children: [
      /* @__PURE__ */ jsxs(Dialog$1.Button, { isDisabled: disabled, children: [
        fetcher.state === "idle" ? void 0 : /* @__PURE__ */ jsx(Spinner, { className: "w-3 h-3" }),
        "Rename Tailnet"
      ] }),
      /* @__PURE__ */ jsx(Dialog$1.Panel, { children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
        /* @__PURE__ */ jsx(Dialog$1.Title, { children: "Rename Tailnet" }),
        /* @__PURE__ */ jsx(Dialog$1.Text, { children: "Keep in mind that changing this can lead to all sorts of unexpected behavior and may break existing devices in your tailnet." }),
        /* @__PURE__ */ jsx(
          TextField,
          {
            label: "Tailnet name",
            placeholder: "ts.net",
            state: [newName, setNewName],
            className: "my-2"
          }
        ),
        /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
          /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
          /* @__PURE__ */ jsx(
            Dialog$1.Action,
            {
              variant: "confirm",
              onPress: () => {
                fetcher.submit(
                  {
                    "dns.base_domain": newName
                  },
                  {
                    method: "PATCH",
                    encType: "application/json"
                  }
                );
                close();
              },
              children: "Rename"
            }
          )
        ] })
      ] }) })
    ] })
  ] });
}
async function loader$1() {
  const context2 = await loadContext();
  if (!context2.config.read) {
    throw new Error("No configuration is available");
  }
  const config2 = await loadConfig();
  const dns = {
    prefixes: config2.prefixes,
    magicDns: config2.dns.magic_dns,
    baseDomain: config2.dns.base_domain,
    nameservers: config2.dns.nameservers.global,
    splitDns: config2.dns.nameservers.split,
    searchDomains: config2.dns.search_domains,
    extraRecords: config2.dns.extra_records
  };
  return {
    ...dns,
    ...context2
  };
}
async function action$1({
  request
}) {
  var _a;
  const session = await getSession(request.headers.get("Cookie"));
  if (!session.has("hsApiKey")) {
    return data({
      success: false
    }, {
      status: 401
    });
  }
  const context2 = await loadContext();
  if (!context2.config.write) {
    return data({
      success: false
    }, {
      status: 403
    });
  }
  const patch = await request.json();
  await patchConfig(patch);
  if ((_a = context2.integration) == null ? void 0 : _a.onConfigChange) {
    await context2.integration.onConfigChange(context2.integration.context);
  }
  return data({
    success: true
  });
}
const overview$1 = withComponentProps(function Page6() {
  useLiveData({
    interval: 5e3
  });
  const data2 = useLoaderData();
  const allNs = {};
  for (const key of Object.keys(data2.splitDns)) {
    allNs[key] = data2.splitDns[key];
  }
  allNs.global = data2.nameservers;
  return /* @__PURE__ */ jsxs("div", {
    className: "flex flex-col gap-16 max-w-screen-lg",
    children: [data2.config.write ? void 0 : /* @__PURE__ */ jsx(Notice, {
      children: "The Headscale configuration is read-only. You cannot make changes to the configuration"
    }), /* @__PURE__ */ jsx(Modal, {
      name: data2.baseDomain,
      disabled: !data2.config.write
    }), /* @__PURE__ */ jsx(Nameservers, {
      nameservers: allNs,
      isDisabled: !data2.config.write
    }), /* @__PURE__ */ jsx(DNS, {
      records: data2.extraRecords,
      isDisabled: !data2.config.write
    }), /* @__PURE__ */ jsx(Domains, {
      baseDomain: data2.magicDns ? data2.baseDomain : void 0,
      searchDomains: data2.searchDomains,
      disabled: !data2.config.write
    }), /* @__PURE__ */ jsxs("div", {
      className: "flex flex-col w-2/3",
      children: [/* @__PURE__ */ jsx("h1", {
        className: "text-2xl font-medium mb-4",
        children: "Magic DNS"
      }), /* @__PURE__ */ jsxs("p", {
        className: "text-gray-700 dark:text-gray-300 mb-4",
        children: ["Automatically register domain names for each device on the tailnet. Devices will be accessible at", " ", /* @__PURE__ */ jsxs(Code, {
          children: ["[device].", data2.baseDomain]
        }), " ", "when Magic DNS is enabled."]
      }), /* @__PURE__ */ jsx(Modal$1, {
        isEnabled: data2.magicDns,
        disabled: !data2.config.write
      })]
    })]
  });
});
const route13 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action: action$1,
  default: overview$1,
  loader: loader$1
}, Symbol.toStringTag, { value: "Module" }));
const overview = withComponentProps(function Page7() {
  return /* @__PURE__ */ jsxs("div", {
    className: "flex flex-col gap-8 max-w-screen-lg",
    children: [/* @__PURE__ */ jsxs("div", {
      className: "flex flex-col w-2/3",
      children: [/* @__PURE__ */ jsx("h1", {
        className: "text-2xl font-medium mb-4",
        children: "Settings"
      }), /* @__PURE__ */ jsx("p", {
        className: "text-gray-700 dark:text-gray-300",
        children: "The settings page is still under construction. As I'm able to add more features, I'll be adding them here. If you require any features, feel free to open an issue on the GitHub repository."
      })]
    }), /* @__PURE__ */ jsxs("div", {
      className: "flex flex-col w-2/3",
      children: [/* @__PURE__ */ jsx("h1", {
        className: "text-2xl font-medium mb-4",
        children: "Pre-Auth Keys"
      }), /* @__PURE__ */ jsxs("p", {
        className: "text-gray-700 dark:text-gray-300",
        children: ["Headscale fully supports pre-authentication keys in order to easily add devices to your Tailnet. To learn more about using pre-authentication keys, visit the", " ", /* @__PURE__ */ jsx(Link, {
          to: "https://tailscale.com/kb/1085/auth-keys/",
          name: "Tailscale Auth Keys documentation",
          children: "Tailscale documentation"
        })]
      })]
    }), /* @__PURE__ */ jsx(Link$2, {
      to: "/settings/auth-keys",
      children: /* @__PURE__ */ jsxs("div", {
        className: cn("text-lg font-medium flex items-center", "text-gray-700 dark:text-gray-300"),
        children: ["Manage Auth Keys", /* @__PURE__ */ jsx(ArrowRightIcon, {
          className: "w-5 h-5 ml-2"
        })]
      })
    })]
  });
});
const route14 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  default: overview
}, Symbol.toStringTag, { value: "Module" }));
function NumberField(props) {
  var _a;
  return /* @__PURE__ */ jsx(
    NumberField$1,
    {
      ...props,
      "aria-label": props.label,
      className: "w-full",
      value: (_a = props.state) == null ? void 0 : _a[0],
      onChange: (value) => {
        var _a2;
        (_a2 = props.state) == null ? void 0 : _a2[1](value);
      },
      children: /* @__PURE__ */ jsxs(
        Group,
        {
          className: cn(
            "flex px-2.5 py-1.5 w-full rounded-lg my-1",
            "border border-ui-200 dark:border-ui-600",
            "dark:bg-ui-800 dark:text-ui-300 gap-2",
            "focus-within:ring-2 focus-within:ring-blue-600",
            props.className
          ),
          children: [
            /* @__PURE__ */ jsx(Input, { className: "w-full bg-transparent focus:outline-none" }),
            /* @__PURE__ */ jsx(Button$2, { slot: "decrement", children: /* @__PURE__ */ jsx(DashIcon, { className: "w-4 h-4" }) }),
            /* @__PURE__ */ jsx(Button$2, { slot: "increment", children: /* @__PURE__ */ jsx(PlusIcon, { className: "w-4 h-4" }) })
          ]
        }
      )
    }
  );
}
function AddPreAuthKey(data2) {
  const fetcher = useFetcher();
  const [user, setUser] = useState("");
  const [reusable, setReusable] = useState(false);
  const [ephemeral, setEphemeral] = useState(false);
  useState([]);
  const [expiry, setExpiry] = useState(90);
  return /* @__PURE__ */ jsxs(Dialog$1, { children: [
    /* @__PURE__ */ jsx(Dialog$1.Button, { className: "my-4", children: "Create pre-auth key" }),
    /* @__PURE__ */ jsx(Dialog$1.Panel, { children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsx(Dialog$1.Title, { children: "Generate auth key" }),
      /* @__PURE__ */ jsxs(
        fetcher.Form,
        {
          method: "POST",
          onSubmit: (e) => {
            fetcher.submit(e.currentTarget);
            close();
          },
          children: [
            /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-semibold", children: "User" }),
            /* @__PURE__ */ jsx(Dialog$1.Text, { className: "text-sm", children: "Attach this key to a user" }),
            /* @__PURE__ */ jsx(
              Select$1,
              {
                label: "Owner",
                name: "user",
                placeholder: "Select a user",
                state: [user, setUser],
                children: data2.users.map((user2) => /* @__PURE__ */ jsx(Select$1.Item, { id: user2.name, children: user2.name }, user2.id))
              }
            ),
            /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-semibold mt-4", children: "Key Expiration" }),
            /* @__PURE__ */ jsx(Dialog$1.Text, { className: "text-sm", children: "Set this key to expire after a certain number of days." }),
            /* @__PURE__ */ jsx(
              NumberField,
              {
                label: "Expiry",
                name: "expiry",
                minValue: 1,
                maxValue: 365e3,
                state: [expiry, setExpiry],
                formatOptions: {
                  style: "unit",
                  unit: "day",
                  unitDisplay: "short"
                }
              }
            ),
            /* @__PURE__ */ jsxs("div", { className: "flex justify-between items-center mt-6", children: [
              /* @__PURE__ */ jsxs("div", { children: [
                /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-semibold", children: "Reusable" }),
                /* @__PURE__ */ jsx(Dialog$1.Text, { className: "text-sm", children: "Use this key to authenticate more than one device." })
              ] }),
              /* @__PURE__ */ jsx(
                Switch,
                {
                  label: "Reusable",
                  name: "reusable",
                  defaultSelected: reusable,
                  onChange: () => {
                    setReusable(!reusable);
                  }
                }
              )
            ] }),
            /* @__PURE__ */ jsx(
              "input",
              {
                type: "hidden",
                name: "reusable",
                value: reusable.toString()
              }
            ),
            /* @__PURE__ */ jsxs("div", { className: "flex justify-between items-center mt-6", children: [
              /* @__PURE__ */ jsxs("div", { children: [
                /* @__PURE__ */ jsx(Dialog$1.Text, { className: "font-semibold", children: "Ephemeral" }),
                /* @__PURE__ */ jsxs(Dialog$1.Text, { className: "text-sm", children: [
                  "Devices authenticated with this key will be automatically removed once they go offline.",
                  " ",
                  /* @__PURE__ */ jsx(
                    Link,
                    {
                      to: "https://tailscale.com/kb/1111/ephemeral-nodes",
                      name: "Tailscale Ephemeral Nodes Documentation",
                      children: "Learn more"
                    }
                  )
                ] })
              ] }),
              /* @__PURE__ */ jsx(
                Switch,
                {
                  label: "Ephemeral",
                  name: "ephemeral",
                  defaultSelected: ephemeral,
                  onChange: () => {
                    setEphemeral(!ephemeral);
                  }
                }
              )
            ] }),
            /* @__PURE__ */ jsx(
              "input",
              {
                type: "hidden",
                name: "ephemeral",
                value: ephemeral.toString()
              }
            ),
            /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsxs(
                Dialog$1.Action,
                {
                  variant: "confirm",
                  onPress: close,
                  isDisabled: !user || !expiry,
                  children: [
                    fetcher.state === "idle" ? void 0 : /* @__PURE__ */ jsx(Spinner, { className: "w-3 h-3" }),
                    "Generate"
                  ]
                }
              )
            ] })
          ]
        }
      )
    ] }) })
  ] });
}
function ExpireKey({ authKey }) {
  const fetcher = useFetcher();
  return /* @__PURE__ */ jsxs(Dialog$1, { children: [
    /* @__PURE__ */ jsx(Dialog$1.Button, { className: "my-4", children: "Expire Key" }),
    /* @__PURE__ */ jsx(Dialog$1.Panel, { children: (close) => /* @__PURE__ */ jsxs(Fragment, { children: [
      /* @__PURE__ */ jsx(Dialog$1.Title, { children: "Expire auth key?" }),
      /* @__PURE__ */ jsxs(
        fetcher.Form,
        {
          method: "DELETE",
          onSubmit: (e) => {
            fetcher.submit(e.currentTarget);
            close();
          },
          children: [
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "user", value: authKey.user }),
            /* @__PURE__ */ jsx("input", { type: "hidden", name: "key", value: authKey.key }),
            /* @__PURE__ */ jsx(Dialog$1.Text, { children: "Expiring this authentication key will immediately prevent it from being used to authenticate new devices. This action cannot be undone." }),
            /* @__PURE__ */ jsxs(Dialog$1.Gutter, { children: [
              /* @__PURE__ */ jsx(Dialog$1.Action, { variant: "cancel", onPress: close, children: "Cancel" }),
              /* @__PURE__ */ jsxs(
                Dialog$1.Action,
                {
                  variant: "confirm",
                  className: cn(
                    "bg-red-500 hover:border-red-700",
                    "dark:bg-red-600 dark:hover:border-red-700",
                    "pressed:bg-red-600 hover:bg-red-600",
                    "text-white dark:text-white"
                  ),
                  onPress: close,
                  children: [
                    fetcher.state === "idle" ? void 0 : /* @__PURE__ */ jsx(Spinner, { className: "w-3 h-3" }),
                    "Expire"
                  ]
                }
              )
            ] })
          ]
        }
      )
    ] }) })
  ] });
}
function AuthKeyRow({ authKey, server }) {
  const createdAt = new Date(authKey.createdAt).toLocaleString();
  const expiration = new Date(authKey.expiration).toLocaleString();
  return /* @__PURE__ */ jsxs("div", { className: "w-full", children: [
    /* @__PURE__ */ jsx(Attribute, { name: "Key", value: authKey.key, isCopyable: true }),
    /* @__PURE__ */ jsx(Attribute, { name: "User", value: authKey.user, isCopyable: true }),
    /* @__PURE__ */ jsx(Attribute, { name: "Reusable", value: authKey.reusable ? "Yes" : "No" }),
    /* @__PURE__ */ jsx(Attribute, { name: "Ephemeral", value: authKey.ephemeral ? "Yes" : "No" }),
    /* @__PURE__ */ jsx(Attribute, { name: "Used", value: authKey.used ? "Yes" : "No" }),
    /* @__PURE__ */ jsx(Attribute, { name: "Created", value: createdAt }),
    /* @__PURE__ */ jsx(Attribute, { name: "Expiration", value: expiration }),
    /* @__PURE__ */ jsx("p", { className: "mb-1 mt-4", children: "To use this key, run the following command on your device:" }),
    /* @__PURE__ */ jsxs(Code, { className: "text-sm", children: [
      "tailscale up --login-server ",
      server,
      " --authkey ",
      authKey.key
    ] }),
    /* @__PURE__ */ jsxs("div", { className: "flex gap-4 items-center", children: [
      authKey.used && !authKey.reusable || new Date(authKey.expiration) < /* @__PURE__ */ new Date() ? void 0 : /* @__PURE__ */ jsx(ExpireKey, { authKey }),
      /* @__PURE__ */ jsx(
        Button$1,
        {
          variant: "light",
          className: "my-4",
          onPress: async () => {
            await navigator.clipboard.writeText(
              `tailscale up --login-server ${server} --authkey ${authKey.key}`
            );
            toast("Copied command to clipboard");
          },
          children: "Copy Tailscale Command"
        }
      )
    ] })
  ] });
}
async function action({
  request
}) {
  const session = await getSession(request.headers.get("Cookie"));
  if (!session.has("hsApiKey")) {
    return send({
      message: "Unauthorized"
    }, {
      status: 401
    });
  }
  const data2 = await request.formData();
  if (request.method === "DELETE") {
    const key = data2.get("key");
    const user = data2.get("user");
    if (!key || !user) {
      return send({
        message: "Missing parameters"
      }, {
        status: 400
      });
    }
    await post("v1/preauthkey/expire", session.get("hsApiKey"), {
      user,
      key
    });
    return {
      message: "Pre-auth key expired"
    };
  }
  if (request.method === "POST") {
    const user = data2.get("user");
    const expiry = data2.get("expiry");
    const reusable = data2.get("reusable");
    const ephemeral = data2.get("ephemeral");
    if (!user || !expiry || !reusable || !ephemeral) {
      return send({
        message: "Missing parameters"
      }, {
        status: 400
      });
    }
    const day = Number(expiry.toString().split(" ")[0]);
    const date = /* @__PURE__ */ new Date();
    date.setDate(date.getDate() + day);
    const key = await post("v1/preauthkey", session.get("hsApiKey"), {
      user,
      ephemeral: ephemeral === "on",
      reusable: reusable === "on",
      expiration: date.toISOString(),
      aclTags: []
      // TODO
    });
    return {
      message: "Pre-auth key created",
      key
    };
  }
}
async function loader({
  request
}) {
  const context2 = await loadContext();
  const session = await getSession(request.headers.get("Cookie"));
  const users = await pull("v1/user", session.get("hsApiKey"));
  const preAuthKeys = await Promise.all(users.users.map((user) => {
    const qp = new URLSearchParams();
    qp.set("user", user.name);
    return pull(`v1/preauthkey?${qp.toString()}`, session.get("hsApiKey"));
  }));
  return {
    keys: preAuthKeys.flatMap((keys) => keys.preAuthKeys),
    users: users.users,
    server: context2.headscalePublicUrl ?? context2.headscaleUrl
  };
}
const authKeys = withComponentProps(function Page8() {
  const {
    keys,
    users,
    server
  } = useLoaderData();
  const [user, setUser] = useState("All");
  const [status, setStatus] = useState("Active");
  useLiveData({
    interval: 3e3
  });
  const filteredKeys = keys.filter((key) => {
    if (user !== "All" && key.user !== user) {
      return false;
    }
    if (status !== "All") {
      const now = /* @__PURE__ */ new Date();
      const expiry = new Date(key.expiration);
      if (status === "Active") {
        return !(expiry < now) && (!key.used || key.reusable);
      }
      if (status === "Used/Expired") {
        return key.used || expiry < now;
      }
      if (status === "Reusable") {
        return key.reusable;
      }
      if (status === "Ephemeral") {
        return key.ephemeral;
      }
    }
    return true;
  });
  return /* @__PURE__ */ jsxs("div", {
    className: "flex flex-col w-2/3",
    children: [/* @__PURE__ */ jsxs("p", {
      className: "mb-8 text-md",
      children: [/* @__PURE__ */ jsx(Link$2, {
        to: "/settings",
        className: "font-medium",
        children: "Settings"
      }), /* @__PURE__ */ jsx("span", {
        className: "mx-2",
        children: "/"
      }), " Pre-Auth Keys"]
    }), /* @__PURE__ */ jsx("h1", {
      className: "text-2xl font-medium mb-4",
      children: "Pre-Auth Keys"
    }), /* @__PURE__ */ jsxs("p", {
      className: "text-gray-700 dark:text-gray-300 mb-4",
      children: ["Headscale fully supports pre-authentication keys in order to easily add devices to your Tailnet. To learn more about using pre-authentication keys, visit the", " ", /* @__PURE__ */ jsx(Link, {
        to: "https://tailscale.com/kb/1085/auth-keys/",
        name: "Tailscale Auth Keys documentation",
        children: "Tailscale documentation"
      })]
    }), /* @__PURE__ */ jsx(AddPreAuthKey, {
      users
    }), /* @__PURE__ */ jsxs("div", {
      className: "flex justify-between gap-4 mt-4",
      children: [/* @__PURE__ */ jsxs("div", {
        className: "w-full",
        children: [/* @__PURE__ */ jsx("p", {
          className: "text-sm text-gray-500 dark:text-gray-300",
          children: "Filter by user"
        }), /* @__PURE__ */ jsxs(Select$1, {
          label: "Filter by User",
          placeholder: "Select a user",
          state: [user, setUser],
          children: [/* @__PURE__ */ jsx(Select$1.Item, {
            id: "All",
            children: "All"
          }), users.map((user2) => /* @__PURE__ */ jsx(Select$1.Item, {
            id: user2.name,
            children: user2.name
          }, user2.id))]
        })]
      }), /* @__PURE__ */ jsxs("div", {
        className: "w-full",
        children: [/* @__PURE__ */ jsx("p", {
          className: "text-sm text-gray-500 dark:text-gray-300",
          children: "Filter by status"
        }), /* @__PURE__ */ jsxs(Select$1, {
          label: "Filter by status",
          placeholder: "Select a status",
          state: [status, setStatus],
          children: [/* @__PURE__ */ jsx(Select$1.Item, {
            id: "All",
            children: "All"
          }), /* @__PURE__ */ jsx(Select$1.Item, {
            id: "Active",
            children: "Active"
          }), /* @__PURE__ */ jsx(Select$1.Item, {
            id: "Used/Expired",
            children: "Used/Expired"
          }), /* @__PURE__ */ jsx(Select$1.Item, {
            id: "Reusable",
            children: "Reusable"
          }), /* @__PURE__ */ jsx(Select$1.Item, {
            id: "Ephemeral",
            children: "Ephemeral"
          })]
        })]
      })]
    }), /* @__PURE__ */ jsx(TableList$1, {
      className: "mt-4",
      children: filteredKeys.length === 0 ? /* @__PURE__ */ jsx(TableList$1.Item, {
        children: /* @__PURE__ */ jsx("p", {
          className: "opacity-50 text-sm mx-auto",
          children: "No pre-auth keys"
        })
      }) : filteredKeys.map((key) => /* @__PURE__ */ jsx(TableList$1.Item, {
        children: /* @__PURE__ */ jsx(AuthKeyRow, {
          authKey: key,
          server
        })
      }, key.id))
    })]
  });
});
const route15 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  action,
  default: authKeys,
  loader
}, Symbol.toStringTag, { value: "Module" }));
const serverManifest = { "entry": { "module": "/admin/assets/entry.client-Dao3Jsot.js", "imports": ["/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/index-CvxxPot_.js"], "css": [] }, "routes": { "root": { "id": "root", "parentId": void 0, "path": "", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": false, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": true, "module": "/admin/assets/root-C86gFSjW.js", "imports": ["/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/index-CvxxPot_.js", "/admin/assets/cn-VsVy4J8M.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/Error-C8nYQ1hf.js", "/admin/assets/Code-BE-O7oW7.js"], "css": ["/admin/assets/root-SrLRHBlc.css"] }, "routes/util/redirect": { "id": "routes/util/redirect", "parentId": "root", "path": void 0, "index": true, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/redirect-l0sNRNKZ.js", "imports": [], "css": [] }, "routes/util/healthz": { "id": "routes/util/healthz", "parentId": "root", "path": "/healthz", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/healthz-l0sNRNKZ.js", "imports": [], "css": [] }, "routes/auth/login": { "id": "routes/auth/login", "parentId": "root", "path": "/login", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/login-BFGZEGgx.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Code-BE-O7oW7.js", "/admin/assets/TextField-n2lyebNt.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/index-CvxxPot_.js", "/admin/assets/Input-BzKBHab9.js", "/admin/assets/Text-BnfAbTt7.js"], "css": [] }, "routes/auth/logout": { "id": "routes/auth/logout", "parentId": "root", "path": "/logout", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/logout-l0sNRNKZ.js", "imports": [], "css": [] }, "routes/auth/oidc-callback": { "id": "routes/auth/oidc-callback", "parentId": "root", "path": "/oidc/callback", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/oidc-callback-l0sNRNKZ.js", "imports": [], "css": [] }, "routes/auth/oidc-start": { "id": "routes/auth/oidc-start", "parentId": "root", "path": "/oidc/start", "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/oidc-start-l0sNRNKZ.js", "imports": [], "css": [] }, "layouts/shell": { "id": "layouts/shell", "parentId": "root", "path": void 0, "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/shell-kINY0S9d.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/Menu-BWMQzk5t.js", "/admin/assets/createLucideIcon-CykHWK-v.js", "/admin/assets/Link-XhjJGpcI.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/index-CvxxPot_.js", "/admin/assets/IconButton-CyeMul7P.js", "/admin/assets/Dialog-DslcoE_8.js", "/admin/assets/Collection-DwYTm13m.js", "/admin/assets/Text-BnfAbTt7.js"], "css": [] }, "layouts/dashboard": { "id": "layouts/dashboard", "parentId": "layouts/shell", "path": void 0, "index": void 0, "caseSensitive": void 0, "hasAction": false, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/dashboard-BGfxux2P.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/useLiveData-CKmO0CEr.js"], "css": [] }, "routes/machines/overview": { "id": "routes/machines/overview", "parentId": "layouts/dashboard", "path": "/machines", "index": true, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": true, "module": "/admin/assets/overview-Dd2GSMw5.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/Tooltip-BQVN181r.js", "/admin/assets/Code-BE-O7oW7.js", "/admin/assets/Link-XhjJGpcI.js", "/admin/assets/useLiveData-CKmO0CEr.js", "/admin/assets/Error-C8nYQ1hf.js", "/admin/assets/Menu-BWMQzk5t.js", "/admin/assets/StatusCircle-49Z_BV9j.js", "/admin/assets/menu-OD8pO8b_.js", "/admin/assets/Dialog-CRhhKFhD.js", "/admin/assets/TextField-n2lyebNt.js", "/admin/assets/Select-BBclLOul.js", "/admin/assets/Spinner-MEi31bTb.js", "/admin/assets/index-CvxxPot_.js", "/admin/assets/Dialog-DslcoE_8.js", "/admin/assets/Collection-DwYTm13m.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Text-BnfAbTt7.js", "/admin/assets/IconButton-CyeMul7P.js", "/admin/assets/Switch-DwshbNs_.js", "/admin/assets/Input-BzKBHab9.js", "/admin/assets/useSingleSelectListState-BGNOUnLu.js"], "css": [] }, "routes/machines/machine": { "id": "routes/machines/machine", "parentId": "layouts/dashboard", "path": "/machines/:id", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/machine-A5XzSrOO.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/Attribute-Ba6sf95R.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Code-BE-O7oW7.js", "/admin/assets/Menu-BWMQzk5t.js", "/admin/assets/Tooltip-Dp5Ji34B.js", "/admin/assets/StatusCircle-49Z_BV9j.js", "/admin/assets/useLiveData-CKmO0CEr.js", "/admin/assets/Link-XhjJGpcI.js", "/admin/assets/menu-OD8pO8b_.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/index-CvxxPot_.js", "/admin/assets/IconButton-CyeMul7P.js", "/admin/assets/Dialog-DslcoE_8.js", "/admin/assets/Collection-DwYTm13m.js", "/admin/assets/Text-BnfAbTt7.js", "/admin/assets/Tooltip-BQVN181r.js", "/admin/assets/Dialog-CRhhKFhD.js", "/admin/assets/Select-BBclLOul.js", "/admin/assets/useSingleSelectListState-BGNOUnLu.js", "/admin/assets/Input-BzKBHab9.js", "/admin/assets/TextField-n2lyebNt.js", "/admin/assets/Switch-DwshbNs_.js"], "css": [] }, "routes/users/overview": { "id": "routes/users/overview", "parentId": "layouts/dashboard", "path": "/users", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": true, "module": "/admin/assets/overview-MrFz78VH.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/core.esm-CMsR7_ME.js", "/admin/assets/Code-BE-O7oW7.js", "/admin/assets/Attribute-Ba6sf95R.js", "/admin/assets/StatusCircle-49Z_BV9j.js", "/admin/assets/Error-C8nYQ1hf.js", "/admin/assets/useLiveData-CKmO0CEr.js", "/admin/assets/Link-XhjJGpcI.js", "/admin/assets/Dialog-CRhhKFhD.js", "/admin/assets/TextField-n2lyebNt.js", "/admin/assets/IconButton-CyeMul7P.js", "/admin/assets/createLucideIcon-CykHWK-v.js", "/admin/assets/index-CvxxPot_.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Dialog-DslcoE_8.js", "/admin/assets/Collection-DwYTm13m.js", "/admin/assets/Text-BnfAbTt7.js", "/admin/assets/Input-BzKBHab9.js"], "css": [] }, "routes/acls/editor": { "id": "routes/acls/editor", "parentId": "layouts/dashboard", "path": "/acls", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/editor-DRahyYpl.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/Collection-DwYTm13m.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/useSingleSelectListState-BGNOUnLu.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Link-XhjJGpcI.js", "/admin/assets/Notice-BDiUaoHI.js", "/admin/assets/Spinner-MEi31bTb.js", "/admin/assets/Code-BE-O7oW7.js", "/admin/assets/index-CvxxPot_.js"], "css": [] }, "routes/dns/overview": { "id": "routes/dns/overview", "parentId": "layouts/dashboard", "path": "/dns", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/overview-DHXIJWzi.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/Code-BE-O7oW7.js", "/admin/assets/Notice-BDiUaoHI.js", "/admin/assets/useLiveData-CKmO0CEr.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/Link-XhjJGpcI.js", "/admin/assets/TableList-88FQbnA8.js", "/admin/assets/Dialog-CRhhKFhD.js", "/admin/assets/TextField-n2lyebNt.js", "/admin/assets/core.esm-CMsR7_ME.js", "/admin/assets/Input-BzKBHab9.js", "/admin/assets/Spinner-MEi31bTb.js", "/admin/assets/Switch-DwshbNs_.js", "/admin/assets/Tooltip-Dp5Ji34B.js", "/admin/assets/index-CvxxPot_.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Dialog-DslcoE_8.js", "/admin/assets/Collection-DwYTm13m.js", "/admin/assets/Text-BnfAbTt7.js", "/admin/assets/Tooltip-BQVN181r.js"], "css": [] }, "routes/settings/overview": { "id": "routes/settings/overview", "parentId": "layouts/dashboard", "path": "/settings", "index": true, "caseSensitive": void 0, "hasAction": false, "hasLoader": false, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/overview-KQEUjXEL.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/Link-XhjJGpcI.js"], "css": [] }, "routes/settings/auth-keys": { "id": "routes/settings/auth-keys", "parentId": "layouts/dashboard", "path": "/settings/auth-keys", "index": void 0, "caseSensitive": void 0, "hasAction": true, "hasLoader": true, "hasClientAction": false, "hasClientLoader": false, "hasErrorBoundary": false, "module": "/admin/assets/auth-keys-B6YT3Lvu.js", "imports": ["/admin/assets/cn-VsVy4J8M.js", "/admin/assets/chunk-K6AXKMTT-CWg7ZNd5.js", "/admin/assets/useLiveData-CKmO0CEr.js", "/admin/assets/Link-XhjJGpcI.js", "/admin/assets/TableList-88FQbnA8.js", "/admin/assets/Select-BBclLOul.js", "/admin/assets/Dialog-CRhhKFhD.js", "/admin/assets/Button-Dx95HexB.js", "/admin/assets/Input-BzKBHab9.js", "/admin/assets/Text-BnfAbTt7.js", "/admin/assets/Button-DzC2f2zN.js", "/admin/assets/Collection-DwYTm13m.js", "/admin/assets/Dialog-DslcoE_8.js", "/admin/assets/Switch-DwshbNs_.js", "/admin/assets/Spinner-MEi31bTb.js", "/admin/assets/Code-BE-O7oW7.js", "/admin/assets/Attribute-Ba6sf95R.js", "/admin/assets/useSingleSelectListState-BGNOUnLu.js", "/admin/assets/index-CvxxPot_.js"], "css": [] } }, "url": "/admin/assets/manifest-75238be7.js", "version": "75238be7" };
const assetsBuildDirectory = "build/client";
const basename = "/admin/";
const future = { "unstable_optimizeDeps": false };
const isSpaMode = false;
const publicPath = "/admin/";
const entry = { module: entryServer };
const routes = {
  "root": {
    id: "root",
    parentId: void 0,
    path: "",
    index: void 0,
    caseSensitive: void 0,
    module: route0
  },
  "routes/util/redirect": {
    id: "routes/util/redirect",
    parentId: "root",
    path: void 0,
    index: true,
    caseSensitive: void 0,
    module: route1
  },
  "routes/util/healthz": {
    id: "routes/util/healthz",
    parentId: "root",
    path: "/healthz",
    index: void 0,
    caseSensitive: void 0,
    module: route2
  },
  "routes/auth/login": {
    id: "routes/auth/login",
    parentId: "root",
    path: "/login",
    index: void 0,
    caseSensitive: void 0,
    module: route3
  },
  "routes/auth/logout": {
    id: "routes/auth/logout",
    parentId: "root",
    path: "/logout",
    index: void 0,
    caseSensitive: void 0,
    module: route4
  },
  "routes/auth/oidc-callback": {
    id: "routes/auth/oidc-callback",
    parentId: "root",
    path: "/oidc/callback",
    index: void 0,
    caseSensitive: void 0,
    module: route5
  },
  "routes/auth/oidc-start": {
    id: "routes/auth/oidc-start",
    parentId: "root",
    path: "/oidc/start",
    index: void 0,
    caseSensitive: void 0,
    module: route6
  },
  "layouts/shell": {
    id: "layouts/shell",
    parentId: "root",
    path: void 0,
    index: void 0,
    caseSensitive: void 0,
    module: route7
  },
  "layouts/dashboard": {
    id: "layouts/dashboard",
    parentId: "layouts/shell",
    path: void 0,
    index: void 0,
    caseSensitive: void 0,
    module: route8
  },
  "routes/machines/overview": {
    id: "routes/machines/overview",
    parentId: "layouts/dashboard",
    path: "/machines",
    index: true,
    caseSensitive: void 0,
    module: route9
  },
  "routes/machines/machine": {
    id: "routes/machines/machine",
    parentId: "layouts/dashboard",
    path: "/machines/:id",
    index: void 0,
    caseSensitive: void 0,
    module: route10
  },
  "routes/users/overview": {
    id: "routes/users/overview",
    parentId: "layouts/dashboard",
    path: "/users",
    index: void 0,
    caseSensitive: void 0,
    module: route11
  },
  "routes/acls/editor": {
    id: "routes/acls/editor",
    parentId: "layouts/dashboard",
    path: "/acls",
    index: void 0,
    caseSensitive: void 0,
    module: route12
  },
  "routes/dns/overview": {
    id: "routes/dns/overview",
    parentId: "layouts/dashboard",
    path: "/dns",
    index: void 0,
    caseSensitive: void 0,
    module: route13
  },
  "routes/settings/overview": {
    id: "routes/settings/overview",
    parentId: "layouts/dashboard",
    path: "/settings",
    index: true,
    caseSensitive: void 0,
    module: route14
  },
  "routes/settings/auth-keys": {
    id: "routes/settings/auth-keys",
    parentId: "layouts/dashboard",
    path: "/settings/auth-keys",
    index: void 0,
    caseSensitive: void 0,
    module: route15
  }
};
export {
  serverManifest as assets,
  assetsBuildDirectory,
  basename,
  entry,
  future,
  isSpaMode,
  publicPath,
  routes
};
